CREATE TABLE `prodbatch` (
	`batch_id_num` INT(11) NOT NULL AUTO_INCREMENT COMMENT 'Identifikan slo are',
	`prod_code` CHAR(15) NOT NULL COMMENT 'Kd produktu',
	`supplier_code` CHAR(8) NOT NULL COMMENT 'Dodavatel dodvky',
	`production_date` DATE NULL DEFAULT NULL COMMENT 'Datum vroby',
	`expire_date` DATE NULL DEFAULT NULL COMMENT 'Datum trvanlivosti',
	`vend_batch_code` CHAR(20) NULL DEFAULT NULL COMMENT 'are vrobce',
	`supplier_type` CHAR(1) NOT NULL COMMENT 'Typ dodavatele\\nHodnoty: \\nE = extern\\nV = vlastn',
	`mnf_batch_ind` CHAR(1) NOT NULL COMMENT 'Typ vrobn are \\nHodnoty:D=datum vroby ve tvaru RRnnn (nnn=poadov slo dne v roce)\\nT = textov informace',
	`bar_code` CHAR(15) NULL DEFAULT NULL COMMENT 'rov kd are',
	`valid_flag` BIT(1) NOT NULL COMMENT 'Platnost zznamu',
	PRIMARY KEY (`batch_id_num`),
	INDEX `FK_prodbatch_product` (`prod_code`),
	INDEX `FK_prodbatch_vendor` (`supplier_code`),
	CONSTRAINT `FK_prodbatch_product` FOREIGN KEY (`prod_code`) REFERENCES `product` (`prod_code`),
	CONSTRAINT `FK_prodbatch_vendor` FOREIGN KEY (`supplier_code`) REFERENCES `vendor` (`vend_code`)
)
COMMENT='Karta are produktu '
COLLATE='utf8mb4_general_ci'
ENGINE=InnoDB;
;
CREATE TABLE `prodledgbatch` (
	`batch_seq_num` INT(11) NOT NULL AUTO_INCREMENT COMMENT 'poadov slo pohybu zsoby are',
	`batch_id_num` INT(11) NOT NULL COMMENT 'ID are',
	`batch_stat_num` INT(11) NOT NULL COMMENT 'Po.slo arov zsoby',
	`prod_code` CHAR(15) NOT NULL COMMENT 'kd produktu',
	`ware_code` CHAR(3) NOT NULL COMMENT 'kd skladu',
	`place_code` CHAR(3) NOT NULL COMMENT 'kd umstn',
	`seq_num` INT(11) NOT NULL COMMENT 'Poadov slo skladovho pohybu',
	`desc_text` VARCHAR(80) NULL DEFAULT NULL COMMENT 'Popis pohybu',
	`trantype_ind` CHAR(1) NOT NULL COMMENT 'indiktor pohybu a=Inicializace ar\\nb=Pevod ar mezi dvma umstnmi v jednom skladu\\n c=Zmna arov identifikace (pevod mezi aremi) v rmci skladu a umstn\\nd=Korekce stavu are beze zmny stavu skladu\\n e=Deaktivace arov evidence ',
	`kind_code` CHAR(1) NOT NULL COMMENT 'typ pohybu P/V (pjem/vdej)',
	`source_num` INT(11) NOT NULL COMMENT 'slo dokladu',
	`line_num` SMALLINT(6) NOT NULL COMMENT 'dka dokladu',
	`ship_date` DATE NULL DEFAULT NULL COMMENT 'datum expedice',
	`tran_date` DATE NOT NULL COMMENT 'datum transakce',
	`tran_qty` DECIMAL(16,4) NULL COMMENT 'mnostv pohybu',
	`entry_date` DATE NULL COMMENT 'datum zpisu',
	`entry_time` DATETIME NULL COMMENT 'as zpisu',
	`entry_code` CHAR(8) NULL COMMENT 'Zapsal',
	`valid_flag` BIT NOT NULL COMMENT 'Zapsal',
	PRIMARY KEY (`batch_seq_num`),
	CONSTRAINT `FK_prodledgbatch_prodbatch` FOREIGN KEY (`batch_id_num`) REFERENCES `prodbatch` (`batch_id_num`) ON DELETE CASCADE,
	CONSTRAINT `FK_prodledgbatch_product` FOREIGN KEY (`prod_code`) REFERENCES `product` (`prod_code`),
	CONSTRAINT `FK_prodledgbatch_warehouse` FOREIGN KEY (`ware_code`) REFERENCES `warehouse` (`ware_code`),
	CONSTRAINT `FK_prodledgbatch_prodledg` FOREIGN KEY (`seq_num`) REFERENCES `prodledg` (`id_num`)
)
COLLATE='utf8mb4_general_ci'
ENGINE=InnoDB;
ALTER TABLE `typzav`
	ADD CONSTRAINT `FK_typzav_coa` FOREIGN KEY (`pay_acct_code`) REFERENCES `coa` (`acct_code`),
	ADD CONSTRAINT `FK_typzav_apkind` FOREIGN KEY (`kind_code`) REFERENCES `apkind` (`kind_code`)
;
CREATE TABLE `prodstatbatch` (
	`prod_code` CHAR(15) NOT NULL COMMENT 'kd produktu',
	`ware_code` CHAR(3) NOT NULL COMMENT 'kd skladu',
	`batch_id_num` INT(11) NOT NULL COMMENT 'Identifikan slo are ',
	`place_code` CHAR(3) NOT NULL COMMENT 'kd umstn',
	`batch_stat_num` INT(11) NOT NULL DEFAULT '0' COMMENT 'Poadov slo arov zsoby . Jen pro FIFO pro ostan 0',
	`onbatch_qty` DECIMAL(16,4) NOT NULL DEFAULT '0' COMMENT 'Aktuln stav mnostv are',
	`zero_flag` CHAR(1) NOT NULL DEFAULT 'N' COMMENT 'Nulov stav karty A/N',
	`bar_code` CHAR(15) NULL DEFAULT NULL COMMENT 'rov kd are',
	`valid_flag` BIT NULL DEFAULT NULL COMMENT 'Platnost zznamu',
	PRIMARY KEY (`prod_code`, `ware_code`, `batch_id_num`),
	CONSTRAINT `FK_prodstatbatch_product` FOREIGN KEY (`prod_code`) REFERENCES `product` (`prod_code`),
	CONSTRAINT `FK_prodstatbatch_warehouse` FOREIGN KEY (`ware_code`) REFERENCES `warehouse` (`ware_code`)
)
COMMENT='prodstatusbatch '
COLLATE='utf8mb4_general_ci'
ENGINE=InnoDB
;
CREATE TABLE `borhead` (
	`id_norm` INT(11) NOT NULL AUTO_INCREMENT COMMENT 'Poloka-RODI (vrcholov poloka NS)',
	`parent_item_code` CHAR(15) NOT NULL COMMENT 'Poadov slo normy',
	`type_ind` CHAR(2) NOT NULL COMMENT 'Typ normy spoteby',
	`price_conv` DECIMAL(12,4) NOT NULL DEFAULT '0' COMMENT 'Mnostv mrn jednotky, pro kter je norma spoteby vytvoena',
	`cost_rollup_amt` DECIMAL(16,4) NOT NULL DEFAULT '0' COMMENT 'Kalkulovan nklady',
	`loss_qty` DECIMAL(12,4) NULL DEFAULT NULL COMMENT 'Normovan ztrta',
	`loss_uom_code` CHAR(4) NULL DEFAULT NULL COMMENT 'MJ normovan ztrty. Jsou povoleny pouze hodnoty % nebo MJ produktu.',
	`loss_ind` CHAR(1) NULL DEFAULT NULL COMMENT 'Indiktor ztrty.\\nHodnoty:\\n 0=ztrty nejsou zahrnuty v NS\\n 1=ztrty jsou zahrnuty v NS',
	`start_date` DATE NULL DEFAULT NULL COMMENT 'Zatek platnosti',
	`end_date` DATE NULL DEFAULT NULL COMMENT 'Konec platnosti',
	`entry_date` DATE NULL DEFAULT NULL COMMENT 'Datum zpisu',
	`entry_code` CHAR(8) NULL DEFAULT NULL COMMENT 'Uivatel, kter provedl zpis',
	`valid_flag` BIT NULL DEFAULT NULL COMMENT 'Platnost zznamu',
	PRIMARY KEY (`id_norm`),
	CONSTRAINT `FK_borhead_product` FOREIGN KEY (`parent_item_code`) REFERENCES `product` (`prod_code`),
	CONSTRAINT `FK_borhead_uom` FOREIGN KEY (`loss_uom_code`) REFERENCES `uom` (`uom_code`) ON UPDATE NO ACTION ON DELETE NO ACTION
)
COMMENT='Hlavika normy spoteby '
COLLATE='utf8mb4_general_ci'
ENGINE=InnoDB
;
CREATE TABLE `bordetl` (
	`id_norm_detl` INT(11) NOT NULL AUTO_INCREMENT COMMENT 'ID dky NS',
	`id_norm` INT(11) NOT NULL COMMENT 'ID hlaviky NS',
	`parent_item_code` CHAR(15) NOT NULL COMMENT 'Vrcholov poloka normy (RODI)',
	`child_item_code` CHAR(15) NOT NULL COMMENT 'Kd poloky normy (DT)\\nPro druh dky I-instrukce je ve sloupci uveden implicitn kd "INSTRUKCE"',
	`type_ind` CHAR(2) NOT NULL DEFAULT '00' COMMENT 'Typ normy spoteby',
	`sort_num` INT(11) NOT NULL DEFAULT '10' COMMENT 'Tdc slo dky normy v rmci RODIE',
	`required_qty` DOUBLE NOT NULL DEFAULT '1' COMMENT 'Mnostv poloky-dt poadovan pro poloku-rodi',
	`resource_code` CHAR(1) NOT NULL DEFAULT 'C' COMMENT 'Typ vztahu RODI-DT\\nHodnoty\\n C=komponenta\\n F=fantom\\n G=generick poloka\\n I=instrukce\\n P=Podskupina\\n S=nklady',
	`cost_amt` DECIMAL(16,4) NOT NULL DEFAULT '0' COMMENT 'Nklady na poloku normy',
	`entry_date` DATE NULL DEFAULT NULL COMMENT 'Datum zpisy  ',
	`entry_code` CHAR(8) NULL DEFAULT NULL COMMENT 'Kd uivatele',
	`work_place_code` CHAR(8) NULL DEFAULT NULL COMMENT 'Kd pracovit',
	`ware_code` CHAR(3) NULL DEFAULT NULL COMMENT 'Implicitn sklad vdeje   ',
	`back_flush` CHAR(1) NULL DEFAULT NULL COMMENT 'Zptn vdej\\nHodnoty\\n A = Provd se automatick vdej ze skladu\\n N = Vdej se automatick neprovd',
	`start_date` DATE NULL DEFAULT NULL COMMENT 'Zatek platnosti vazby RODI-DT',
	`end_date` DATE NULL DEFAULT NULL COMMENT 'Konec platnosti vazby RODI-DT',
	`valid_flag` INT(11) NOT NULL COMMENT 'Platnost zznamu',
	PRIMARY KEY (`id_norm_detl`),
	CONSTRAINT `FK_bordetl_borhead` FOREIGN KEY (`id_norm`) REFERENCES `borhead` (`id_norm`) ON DELETE CASCADE,
	CONSTRAINT `FK_bordetl_product` FOREIGN KEY (`parent_item_code`) REFERENCES `product` (`prod_code`),
	CONSTRAINT `FK_bordetl_product_2` FOREIGN KEY (`child_item_code`) REFERENCES `product` (`prod_code`),
	CONSTRAINT `FK_bordetl_warehouse` FOREIGN KEY (`ware_code`) REFERENCES `warehouse` (`ware_code`)
)
COMMENT='dky normy spoteby'
COLLATE='utf8mb4_general_ci'
ENGINE=InnoDB
;
ALTER TABLE `custaudit`
	COMMENT='Pohyby odbratele'
;
CREATE TABLE `ingredhead` (
	`id_ingred` INT(11) NOT NULL AUTO_INCREMENT COMMENT 'slo vpotu sloen vrobku',
	`nsvalid_date` DATE NOT NULL COMMENT 'Datum platnosti NS, pro kter se provedl',
	`type_ind` CHAR(2) NOT NULL DEFAULT '00' COMMENT 'Typ normy spoteby',
	`primary_item_code` CHAR(15) NOT NULL COMMENT 'Kd karty vrobku ',
	`tot_iss_weight` DOUBLE NOT NULL DEFAULT '0' COMMENT 'Hmotnost v gramech dle NS (MJ vr.)\\nNEUPEEN VROBEK. \\n Celkov potebn mnostv suroviny v gramech na jeden vrobeknebo\\n Celkov potebn mnostv suroviny v Kg na 1000 MJ vrobk',
	`tot_iss100_weight` DOUBLE NOT NULL DEFAULT '0' COMMENT 'Hmotnost v gramech dle NS (100 g vr.) \\n NEUPEEN VROBEK (100 g) \\n Celkov poadovan mnostv surovin v greamech na 100 g vrobku',
	`vypek_g` DOUBLE NOT NULL DEFAULT '0' COMMENT 'Vpek v gramech',
	`vypek_per` DOUBLE NOT NULL DEFAULT '0' COMMENT 'Vpek %',
	`vypek_tot` DOUBLE NOT NULL DEFAULT '0' COMMENT 'Celkem vpek',
	`reduct_weight` DOUBLE NOT NULL DEFAULT '0' COMMENT 'Po zpracovn',
	`entry_date` DATE NULL DEFAULT NULL COMMENT 'Datum zpisu',
	`entry_time` CHAR(5) NULL DEFAULT NULL COMMENT 'as zpisu',
	`entry_code` CHAR(8) NULL DEFAULT NULL COMMENT 'Uivatel',
	`ingred_text` VARCHAR(3000) NULL DEFAULT NULL COMMENT 'Text Sloen ',
	`allergen_text` VARCHAR(1000) NULL DEFAULT NULL COMMENT 'Text Alergeny',
	`valid_record` BIT NULL DEFAULT NULL COMMENT 'Platnost zznamu',
	PRIMARY KEY (`id_ingred`),
	CONSTRAINT `FK_ingredhead_prodstatbatch` FOREIGN KEY (`primary_item_code`) REFERENCES `prodstatbatch` (`prod_code`)
)
COMMENT='Hlavika sloen vrobku '
COLLATE='utf8mb4_general_ci'
ENGINE=InnoDB
;
drop  TABLE `filter_data`;
CREATE TABLE `filter_data` (
	`user` CHAR(20) NULL DEFAULT NULL COMMENT 'Uivatel',
	`form_id` CHAR(20) NULL DEFAULT NULL COMMENT 'ID formule v XML souboru',
	`tabname` VARCHAR(30) NULL DEFAULT NULL COMMENT 'Nzev DB tabulky',
	`colname` VARCHAR(30) NULL DEFAULT NULL COMMENT 'Nzev sloupce DB tabulky',
	`value` VARCHAR(500) NULL DEFAULT NULL COMMENT 'Zadan vbrov kriterium uivatele',
	`dbtype` CHAR(20) NULL DEFAULT NULL COMMENT 'Databzov typ',
	`exact` BIT(1) NULL DEFAULT NULL COMMENT 'Povinost exaktn hodnoty',
	`required` BIT(1) NULL DEFAULT NULL COMMENT 'Mus bt zadan vbrov podmnka',
	`negation` BIT(1) NULL DEFAULT NULL COMMENT 'Negace zadan podmnky',
	`caseSensitive` BIT(1) NULL DEFAULT NULL COMMENT 'Rozliovat velikost psmen u etzc',
	CONSTRAINT `FK_filter_data_user` FOREIGN KEY (`user`) REFERENCES `user` (`user_code`)
)
COMMENT='Tbulka se zadanmi vbrovmi podmnkami uivatele pro jednotliv fole.'
COLLATE='utf8mb4_general_ci'
ENGINE=InnoDB
;
CREATE TABLE `ingreddetl` (
	`id_ingred_detl` INT(11) NOT NULL AUTO_INCREMENT COMMENT 'slo dky vpotu',
	`id_ingred` INT(11) NOT NULL COMMENT 'slo vpotu sloen vrobku',
	`parent_num` INT(11) NULL DEFAULT NULL COMMENT 'Primrn sekvenn slo ',
	`nsvalid_date` DATE NOT NULL COMMENT 'Datum platnosti vpotu ',
	`parent_id_norm` INT(11) NOT NULL COMMENT 'slo nadazen NS ',
	`id_norm` INT(11) NOT NULL COMMENT 'slo NS polotovaru ',
	`id_norm_detl` INT(11) NOT NULL COMMENT 'slo dky NS ',
	`type_ind` CHAR(2) NOT NULL DEFAULT '00' COMMENT 'Typ normy spoteby ',
	`primary_item_code` CHAR(15) NOT NULL COMMENT 'Kd produktu, pro kter bylo vypoteno sloen surovin. ',
	`parent_item_code` CHAR(15) NOT NULL COMMENT 'Kd vrobku/polotovaru ',
	`child_item_code` CHAR(15) NOT NULL COMMENT 'Kd poloky NS ',
	`subst_prod_code` CHAR(15) NULL DEFAULT NULL COMMENT 'Kd zmnn poloky ',
	`required_qty` DOUBLE NOT NULL DEFAULT '0' COMMENT 'Poadovan mnostv vrobku v MJ na 1000 MJ primrnho vrobku. ',
	`required_weight` DOUBLE NOT NULL DEFAULT '0' COMMENT 'Poadovan mnostv vrobku v KG na 1000 MJ primrnho vrobku. ',
	`required100_weight` DOUBLE NOT NULL DEFAULT '0' COMMENT 'Poadovan mnostv vrobku v MJ na 100 Kg primrnho vrobku. ',
	`iss_qty` DOUBLE NOT NULL DEFAULT '0' COMMENT 'Poadovan mnostv suroviny na 1000 MJ primrnho vrobku. ',
	`iss_weight` DOUBLE NOT NULL DEFAULT '0' COMMENT 'Poadovan mnostv suroviny v KG 1000 MJ primrnho vrobku. ',
	`iss100_weight` DOUBLE NOT NULL DEFAULT '0' COMMENT 'Poadovan mnostv suroviny na 100 KG primrnho vrobku. ',
	`sub_iss_qty` DOUBLE NOT NULL DEFAULT '0' COMMENT 'Poadovan mnostv zmnnho produktu v MJ na 1000 MJ primrnho vrobku. ',
	`sub_iss_weight` DOUBLE NOT NULL DEFAULT '0' COMMENT 'Poadovan mnostv zmnnho produktu v KG na 1000 MJ primrnho vrobku. ',
	`sub_iss100_weight` DOUBLE NOT NULL DEFAULT '0' COMMENT 'Poadovan mnostv zmnnho produktu v KG na 100 KG primrnho vrobku. ',
	`parent_res_code` CHAR(1) NOT NULL COMMENT 'Druh dky nadazen NS\\nHodnoty\\n0 = Vygenerovan zznam pro primrn produkt\\nC = Komponenta\\nD = Podskupina\\nF = Fantom\\nG = Zstupn poloka ',
	`resource_code` CHAR(1) NOT NULL COMMENT 'Druh bn dky NS \\nHodnoty\\nC = Komponenta\\nF = Fantom\\nG = Zstupn poloka\\nP = Podkupina\\n ',
	`allergen_ind` CHAR(1) NOT NULL COMMENT 'Mra existence alergen ve sloce \\nHodnoty\\n0 = Neobsahuje1 = Obsahuje2 = Obsahuje mon ',
	`ingred_ind` CHAR(1) NOT NULL COMMENT 'Typ zznamu \\nHodnoty\\nL = Sloky primrn suroviny\\nP = Primrn surovina\\nS = Surovina\\nV = Vrobek\\nX = Ostatn\\nY = Ignorovan suroviny ',
	`level_num` SMALLINT(6) NOT NULL DEFAULT '1' COMMENT 'slo rovn NS ',
	`group_num` INT(11) NULL DEFAULT NULL COMMENT 'slo skupiny pro zstupnou poloku ',
	`entry_date` DATE NULL DEFAULT NULL COMMENT 'Datum zpisu ',
	`entry_time` CHAR(5) NULL DEFAULT NULL COMMENT 'as zpisu ',
	`entry_code` CHAR(8) NULL DEFAULT NULL COMMENT 'Kd uivatele ',
	`group_prim_ingred` INT(11) NULL DEFAULT NULL COMMENT 'Seskupen, do kter pat sloka primrn siroviny. Udaj je uren k seskupen udaj pro tisku sloen vrobku. Nesouvis se skupinama sloek.',
	`valid_flag` BIT(1) NULL DEFAULT NULL COMMENT 'Platnost zznamu',
	PRIMARY KEY (`id_ingred_detl`),
	CONSTRAINT `FK_ingreddetl_ingredhead` FOREIGN KEY (`id_ingred`) REFERENCES `ingredhead` (`id_ingred`) ON DELETE CASCADE,
	CONSTRAINT `FK_ingreddetl_ingreddetl` FOREIGN KEY (`parent_num`) REFERENCES `ingreddetl` (`id_ingred_detl`),
	CONSTRAINT `FK_ingreddetl_borhead` FOREIGN KEY (`parent_id_norm`) REFERENCES `borhead` (`id_norm`),
	CONSTRAINT `FK_ingreddetl_bordetl_2` FOREIGN KEY (`id_norm`) REFERENCES `bordetl` (`id_norm`),
	CONSTRAINT `FK_ingreddetl_bordetl` FOREIGN KEY (`id_norm_detl`) REFERENCES `bordetl` (`id_norm_detl`),
	CONSTRAINT `FK_ingreddetl_product` FOREIGN KEY (`primary_item_code`) REFERENCES `product` (`prod_code`),
	CONSTRAINT `FK_ingreddetl_product_2` FOREIGN KEY (`parent_item_code`) REFERENCES `product` (`prod_code`),
	CONSTRAINT `FK_ingreddetl_product_3` FOREIGN KEY (`child_item_code`) REFERENCES `product` (`prod_code`),
	CONSTRAINT `FK_ingreddetl_product_4` FOREIGN KEY (`subst_prod_code`) REFERENCES `product` (`prod_code`)
)
COMMENT='Sloen vrobku dky'
COLLATE='utf8mb4_general_ci'
ENGINE=InnoDB
;
ALTER TABLE `shipcategory`
	ADD PRIMARY KEY (`cat_code`)
;
ALTER TABLE `shipcategory`
	CHANGE COLUMN `valid_flag` `valid_flag` BIT(1) NOT NULL COMMENT 'TRUE - Platn zznam FALSE - Zruen zznam' AFTER `desc_text`
;
ALTER TABLE `custship`
	COLLATE='utf8mb4_general_ci'
;
ALTER TABLE `custship`
	DROP FOREIGN KEY `FK_custship_category`
;
ALTER TABLE `custship`
	DROP INDEX `FK_custship_category`
;
ALTER TABLE `custship`
	ADD CONSTRAINT `FK_custship_shipcategory` FOREIGN KEY (`cat_code`) REFERENCES `shipcategory` (`cat_code`)
;
CREATE TABLE `nutritionbill` (
	`nutri_id` CHAR(4) NOT NULL COMMENT 'Kd nutrinho daje',
	`desc_text` VARCHAR(80) NULL DEFAULT NULL COMMENT 'Nzev nutrinho daje',
	`uom_code` CHAR(4) NULL DEFAULT NULL COMMENT 'MJ nutrinho daje',
	`valid_flag` BIT NOT NULL COMMENT 'Platn zznam',
	PRIMARY KEY (`nutri_id`),
	INDEX `FK_nutritionbill_uom` (`uom_code`),
	CONSTRAINT `FK_nutritionbill_uom` FOREIGN KEY (`uom_code`) REFERENCES `uom` (`uom_code`)
)
COMMENT='Poloky nutrinch daj '
COLLATE='utf8mb4_general_ci'
ENGINE=InnoDB
;
ALTER TABLE `vendor`
	DROP COLUMN `next_seq_num`
	;
ALTER TABLE `prodstatbatch`
	COMMENT='are produktu'
;
CREATE TABLE `quality` (
	`id_num` INT(11) NOT NULL DEFAULT '0' COMMENT 'Uniktn slo zznamu',
	`test_date` DATE NOT NULL COMMENT 'Datum men',
	`test_code` CHAR(2) NOT NULL COMMENT 'Kd testu \\nHodnoty\\nO1-=-Obil - po prvnm nakropen\\nO2-=-Obil - po druhm nakropen\\nJB-=-Jedl balen\\nJP-=-Jedl pytlovan\\nJV-=-Jedl voln\\nKV-=-Krmn voln\\nOS-=-Obil - vstup ze sila\\nPM-=-Obil - produkty mlet\\nST-=-Obil - STOP zkouka\\n',
	`id_silolist` INT(11) NOT NULL COMMENT 'ID pazen sila k produktu',
	`silo_code` CHAR(2) NOT NULL COMMENT 'Kd zsobnku',
	`prod_code` CHAR(15) NOT NULL COMMENT 'Kd obil',
	`item_code` CHAR(15) NULL DEFAULT NULL COMMENT 'Kd produktu mlet z obil. Pro O1,O2 a OS nevyplnno (NULL)',
	`vlhkost` DECIMAL(3,1) NULL DEFAULT NULL COMMENT 'Procento vlhkosti',
	`popel` DECIMAL(5,2) NULL DEFAULT NULL COMMENT 'Procento popele',
	`lepek` DECIMAL(3,1) NULL DEFAULT NULL COMMENT 'Procento lepku',
	`granulace_1` DECIMAL(4,1) NULL DEFAULT NULL COMMENT 'slo granulace 1',
	`granulace_2` DECIMAL(3,1) NULL DEFAULT NULL COMMENT 'slo granulace 2',
	`pokles` SMALLINT(6) NULL DEFAULT NULL COMMENT 'slo poklesu v sekundch',
	`skrob` DECIMAL(5,1) NULL DEFAULT NULL COMMENT 'krob g/Kg',
	`vlaknina` DECIMAL(5,1) NULL DEFAULT NULL COMMENT 'Vlknina g/Kg',
	`ockovitost` DECIMAL(2,0) NULL DEFAULT NULL COMMENT 'Okovitost',
	`n_latky` DECIMAL(5,1) NULL DEFAULT NULL COMMENT 'N ltky g/Kg',
	`pach` CHAR(1) NULL DEFAULT NULL COMMENT 'Prach',
	`skudci` CHAR(1) NULL DEFAULT NULL COMMENT 'kudci',
	`stop_num` INT(11) NULL DEFAULT NULL COMMENT 'slo stop zkouky',
	`gluten_index` DECIMAL(5,1) NULL DEFAULT NULL COMMENT 'Procento gluten indexu',
	`maltoza` DECIMAL(5,1) NULL DEFAULT NULL COMMENT 'Procento maltzy',
	`tuk` DECIMAL(4,1) NULL DEFAULT NULL COMMENT 'Tuk g/Kg',
	`entry_date` DATE NULL DEFAULT NULL COMMENT 'Datum zpisu',
	`entry_code` CHAR(8) NULL DEFAULT NULL COMMENT 'Kd autora zpisu',
	`valid_flag` BIT(1) NOT NULL COMMENT 'Platnost zznamu',
	PRIMARY KEY (`id_num`),
	INDEX `FK_quality_product` (`prod_code`),
	INDEX `FK_quality_product_2` (`item_code`),
	CONSTRAINT `FK_quality_product_2` FOREIGN KEY (`item_code`) REFERENCES `product` (`prod_code`),
	CONSTRAINT `FK_quality_product` FOREIGN KEY (`prod_code`) REFERENCES `product` (`prod_code`),
	CONSTRAINT `FK_quality_silo` FOREIGN KEY (`silo_code`) REFERENCES `silo` (`silo_code`),
	CONSTRAINT `FK_quality_silolist` FOREIGN KEY (`id_silolist`) REFERENCES `silolist` (`id_num`)
)
COMMENT='Jakost obil nebo MOUK'
COLLATE='utf8mb4_general_ci'
ENGINE=InnoDB
;
ALTER TABLE `orderhead`
	COMMENT='Hlavika objednvky',
	CHANGE COLUMN `ord_id` `ord_id` INT(11) NOT NULL DEFAULT '0' COMMENT 'ID zznamu' FIRST
	;
CREATE TABLE `orderhead` (
	`ord_id` INT(11) NOT NULL DEFAULT '0' COMMENT 'ID zznamu (slo objednvky)',
	`cust_code` VARCHAR(8) NOT NULL COMMENT 'Kd odbratele',
	`ship_code` VARCHAR(8) NOT NULL COMMENT 'Kd odbrnho msta',
	`order_date` DATE NOT NULL COMMENT 'Poadovan datum dodn',
	`ord_text` VARCHAR(20) NULL DEFAULT NULL COMMENT 'slo objednvky odbratele ',
	`ware_code` VARCHAR(8) NULL DEFAULT NULL COMMENT 'Kd skladu vdeje zbo',
	`term_code` VARCHAR(3) NOT NULL COMMENT 'Kd splatnosti',
	`tax_code` VARCHAR(3) NOT NULL COMMENT 'Implicitn kd DPH ',
	`tax_amt` DECIMAL(16,2) NOT NULL COMMENT 'Celkov stka DPH',
	`currency_code` VARCHAR(3) NOT NULL DEFAULT 'CZK' COMMENT 'Mna',
	`goods_amt` DECIMAL(16,2) NOT NULL DEFAULT '0.00' COMMENT 'Celkov cena zbo bez DPH',
	`total_amt` DECIMAL(16,2) NOT NULL DEFAULT '0.00' COMMENT 'Celkov stka objednvky',
	`cost_amt` DECIMAL(16,2) NOT NULL DEFAULT '0.00' COMMENT 'Celkov nklady',
	`hand_amt` DECIMAL(16,2) NOT NULL DEFAULT '0.00' COMMENT 'stka za potovn',
	`hand_tax_code` VARCHAR(3) NULL DEFAULT NULL COMMENT 'Kd dan pro potovn',
	`hand_tax_amt` DECIMAL(16,4) NULL DEFAULT NULL COMMENT 'stka DPH za potovn',
	`freight_amt` DECIMAL(16,2) NOT NULL DEFAULT '0.00' COMMENT 'stka za dopravu',
	`freight_tax_code` VARCHAR(3) NULL DEFAULT NULL COMMENT 'Kd dan pro dopravu',
	`freight_tax_amt` DECIMAL(16,4) NULL DEFAULT NULL COMMENT 'stka DPH za dopravu',
	`pack_amt` DECIMAL(16,2) NOT NULL DEFAULT '0.00' COMMENT 'stka za baln',
	`pack_tax_code` VARCHAR(3) NULL DEFAULT NULL COMMENT 'DPH na baln',
	`pack_tax_amt` DECIMAL(16,4) NULL DEFAULT NULL COMMENT 'stka BPH za baln',
	`status_ind` VARCHAR(1) NULL DEFAULT NULL COMMENT 'Stav objednvky ',
	`line_num` SMALLINT(6) NULL DEFAULT NULL COMMENT 'Poet dek objednvky',
	`com1_text` VARCHAR(30) NULL DEFAULT NULL COMMENT 'Koment 1',
	`com2_text` VARCHAR(30) NULL DEFAULT NULL COMMENT 'Koment 2',
	`ship_name_text` VARCHAR(80) NULL DEFAULT NULL COMMENT 'Jmno odbrnho msta',
	`ship_addr1_text` VARCHAR(80) NULL DEFAULT NULL COMMENT '1.dka adresy OM',
	`ship_addr2_text` VARCHAR(80) NULL DEFAULT NULL COMMENT '2.dka adresy OM',
	`ship_city_text` VARCHAR(80) NULL DEFAULT NULL COMMENT '3.dka adresy OM',
	`state_code` VARCHAR(6) NULL DEFAULT NULL COMMENT 'Region OM',
	`post_code` VARCHAR(10) NULL DEFAULT NULL COMMENT 'PS na dodac adrese',
	`country_text` VARCHAR(30) NULL DEFAULT NULL COMMENT 'Stt z dodac adresy',
	`ship1_text` VARCHAR(60) NULL DEFAULT NULL COMMENT 'Kd poznmky do zpat faktury ',
	`ship2_text` VARCHAR(60) NULL DEFAULT NULL COMMENT 'Zpsob zachzen s poznmkou ',
	`ship_date` DATE NOT NULL COMMENT 'Datum skutenho dodn (Datum DPH)',
	`fob_text` VARCHAR(20) NULL DEFAULT NULL COMMENT 'Dodac podmnky',
	`prepaid_flag` VARCHAR(1) NOT NULL COMMENT 'Forma hrady ',
	`conv_qty` DOUBLE NOT NULL DEFAULT '1' COMMENT 'Smnn kurs',
	`contact_text` VARCHAR(30) NULL DEFAULT NULL COMMENT 'Jmno nebo kontakt na Dodac Adrese',
	`tele_text` VARCHAR(20) NULL DEFAULT NULL COMMENT 'Telefonn slo kontaktu na dodac adres',
	`ord_ind` VARCHAR(1) NULL DEFAULT NULL COMMENT 'Pvod objednvky ',
	`ship_type` VARCHAR(1) NULL DEFAULT NULL COMMENT 'Zpsob dopravy (0,1,2,3,9,N) ',
	`order_time` DECIMAL(2,0) NULL DEFAULT NULL COMMENT 'as dodn (a na msto)',
	`ship_time` DECIMAL(2,0) NULL DEFAULT NULL COMMENT 'Poadovan as dodn v rozmez 0 a 24 ',
	`tot_netto` DECIMAL(12,3) NOT NULL DEFAULT '0.000' COMMENT 'Celkov ist hmotnost',
	`tot_brutto` DECIMAL(12,3) NOT NULL DEFAULT '0.000' COMMENT 'Celkov hrub hmotnost',
	`print_flag` VARCHAR(1) NULL DEFAULT NULL COMMENT 'Pznak vytitn DL ',
	`ship_ind` VARCHAR(1) NULL DEFAULT NULL COMMENT 'Pznak stavu DL ',
	`last_inv_num` INT(11) NULL DEFAULT NULL COMMENT 'slo posledn faktury ',
	`entry_code` VARCHAR(8) NULL DEFAULT NULL COMMENT 'Kd uivatele, kter zapsal objednvku',
	`entry_date` DATE NULL DEFAULT NULL COMMENT 'Datum, kdy byla objednvka zapsna',
	`valid_flag` BIT(1) NOT NULL,
	PRIMARY KEY (`ord_id`),
	INDEX `FK_orderhead_customer` (`cust_code`),
	INDEX `FK_orderhead_custship` (`ship_code`),
	INDEX `FK_orderhead_tax` (`tax_code`),
	INDEX `FK_orderhead_tax_2` (`hand_tax_code`),
	CONSTRAINT `FK_orderhead_tax_2` FOREIGN KEY (`hand_tax_code`) REFERENCES `tax` (`tax_code`),
	CONSTRAINT `FK_orderhead_customer` FOREIGN KEY (`cust_code`) REFERENCES `customer` (`cust_code`),
	CONSTRAINT `FK_orderhead_custship` FOREIGN KEY (`ship_code`) REFERENCES `custship` (`ship_code`),
	CONSTRAINT `FK_orderhead_tax` FOREIGN KEY (`tax_code`) REFERENCES `tax` (`tax_code`),
	CONSTRAINT `FK_orderhead_tax_3` FOREIGN KEY (`freight_tax_code`) REFERENCES `tax` (`tax_code`),
	CONSTRAINT `FK_orderhead_tax_4` FOREIGN KEY (`pack_tax_code`) REFERENCES `tax` (`tax_code`),
	CONSTRAINT `FK_orderhead_shipstate` FOREIGN KEY (`state_code`) REFERENCES `shipstate` (`state_code`),
	CONSTRAINT `FK_orderhead_currency` FOREIGN KEY (`currency_code`) REFERENCES `currency` (`currency_code`),
	CONSTRAINT `FK_orderhead_warehouse` FOREIGN KEY (`ware_code`) REFERENCES `warehouse` (`ware_code`)
)
COMMENT='Hlavika objednvky'
COLLATE='utf8mb4_general_ci'
ENGINE=InnoDB
;
CREATE TABLE `orderdetl` (
	`ord_id_detl` INT(11) NOT NULL AUTO_INCREMENT,
	`ord_id` INT(11) NOT NULL,
	`line_num` SMALLINT(6) NULL DEFAULT '0' COMMENT 'slo dky objednvky',
	`prod_code` CHAR(15) NOT NULL COMMENT 'Kd produktu z dky objednvky',
	`ware_code` CHAR(3) NOT NULL COMMENT 'Kd skladu zbo-pebj skl. v hlavice',
	`desc_text` VARCHAR(80) NULL DEFAULT NULL COMMENT 'Popis dky ',
	`cat_code` VARCHAR(3) NULL DEFAULT NULL COMMENT 'Kd kategorie produktu',
	`tax_code` CHAR(3) NULL DEFAULT NULL COMMENT 'Kd DPH',
	`acct_code` VARCHAR(18) NULL DEFAULT NULL COMMENT 'et treb',
	`uom_code` VARCHAR(4) NOT NULL COMMENT 'Mrn jednotka',
	`order_qty` DECIMAL(8,2) NOT NULL COMMENT 'Objednan mnostv',
	`sched_qty` DECIMAL(8,2) NOT NULL COMMENT 'Rezervovan mnostv',
	`inv_qty` DECIMAL(8,2) NOT NULL COMMENT 'Fakturovan mnostv',
	`back_qty` DECIMAL(8,2) NOT NULL COMMENT 'Nekryt mnostv dky objednvky',
	`picked_qty` DECIMAL(8,2) NOT NULL COMMENT 'Mnostv, kter je ureno k vdeji',
	`conf_qty` DECIMAL(8,2) NOT NULL COMMENT 'Mnostv potvrzen jako dodan',
	`unit_price_amt` DECIMAL(16,4) NOT NULL COMMENT 'JC produktu za mnostevn koeficient ',
	`ext_price_amt` DECIMAL(16,2) NOT NULL COMMENT 'Celkov prodejn cena v mn',
	`unit_tax_amt` DECIMAL(16,4) NOT NULL COMMENT 'Jednotkov da',
	`ext_tax_amt` DECIMAL(16,4) NOT NULL COMMENT 'Celkov da (nezaokrouhlen)',
	`line_tot_amt` DECIMAL(16,2) NOT NULL COMMENT 'dka celkem vetn dan',
	`unit_cost_amt` DECIMAL(16,4) NOT NULL COMMENT 'Jednotkov nkladov cena v mn ',
	`ext_cost_amt` DECIMAL(16,2) NULL DEFAULT NULL COMMENT 'Celkov nkladov cena (skladov cena)',
	`package_qty` SMALLINT(6) NULL DEFAULT NULL COMMENT 'Poet obal/palet ',
	`valid_flag` BIT(1) NOT NULL,
	PRIMARY KEY (`ord_id_detl`),
	INDEX `FK_orderdetl_product` (`prod_code`),
	INDEX `FK_orderdetl_warehouse` (`ware_code`),
	INDEX `FK_orderdetl_category` (`cat_code`),
	INDEX `FK_orderdetl_coa` (`acct_code`),
	INDEX `FK_orderdetl_tax` (`tax_code`),
	INDEX `FK_orderdetl_uom` (`uom_code`),
	INDEX `FK_orderdetl_orderhead` (`ord_id`),
	CONSTRAINT `FK_orderdetl_orderhead` FOREIGN KEY (`ord_id`) REFERENCES `orderhead` (`ord_id`) ON DELETE CASCADE,
	CONSTRAINT `FK_orderdetl_category` FOREIGN KEY (`cat_code`) REFERENCES `category` (`cat_code`),
	CONSTRAINT `FK_orderdetl_coa` FOREIGN KEY (`acct_code`) REFERENCES `coa` (`acct_code`),
	CONSTRAINT `FK_orderdetl_product` FOREIGN KEY (`prod_code`) REFERENCES `product` (`prod_code`),
	CONSTRAINT `FK_orderdetl_tax` FOREIGN KEY (`tax_code`) REFERENCES `tax` (`tax_code`),
	CONSTRAINT `FK_orderdetl_uom` FOREIGN KEY (`uom_code`) REFERENCES `uom` (`uom_code`),
	CONSTRAINT `FK_orderdetl_warehouse` FOREIGN KEY (`ware_code`) REFERENCES `warehouse` (`ware_code`)
)
COLLATE='utf8mb4_general_ci'
ENGINE=InnoDB;
;
drop TABLE `invdetl;
drop TABLE `invhead;
CREATE TABLE `invhead` (
	`inv_id` INT(11) NOT NULL DEFAULT '0' COMMENT 'slo faktury',
	`cust_code` CHAR(8) NULL DEFAULT NULL COMMENT 'Kd odbratele',
	`ship_code` CHAR(8) NULL DEFAULT NULL COMMENT 'kd dodac adresy (pjemce) ',
	`ord_num` INT(11) NULL DEFAULT NULL COMMENT 'Intern slo fakturovan objednvky',
	`purchase_code` CHAR(20) NULL DEFAULT NULL COMMENT 'slo objednvky odbratele',
	`inv_date` DATE NULL DEFAULT NULL COMMENT 'Datum vystaven faktury',
	`sale_code` CHAR(8) NULL DEFAULT NULL COMMENT 'Kd prodejce',
	`kind_code` CHAR(3) NULL DEFAULT NULL COMMENT 'Druh dokladu',
	`typ_pohl` CHAR(8) NULL DEFAULT NULL COMMENT 'Typ pohledvky',
	`currency_code` CHAR(3) NULL DEFAULT NULL COMMENT 'Mna',
	`conv_qty` DOUBLE NULL DEFAULT NULL COMMENT 'Smnn kurz ',
	`term_num` INT(11) NULL DEFAULT NULL COMMENT 'Implicitn poet dn splatnosti     ',
	`tax_code` CHAR(3) NULL DEFAULT NULL COMMENT 'Implicitn kd DPH ',
	`tax_per` DECIMAL(5,3) NULL DEFAULT NULL COMMENT 'Procento dan',
	`goods_amt` DECIMAL(16,2) NULL DEFAULT NULL COMMENT 'Celkov stka faktury bez DPH v mn',
	`hand_amt` DECIMAL(16,2) NULL DEFAULT NULL COMMENT 'Potovn - stka v mn',
	`hand_tax_code` CHAR(3) NULL DEFAULT NULL COMMENT 'Potovn - Kd dan',
	`hand_tax_amt` DECIMAL(16,4) NULL DEFAULT NULL COMMENT 'Potovn - stka dan v mn',
	`freight_amt` DECIMAL(16,2) NULL DEFAULT NULL COMMENT 'Doprava - stka v mn',
	`freight_tax_code` CHAR(3) NULL DEFAULT NULL COMMENT 'Doprava - Kd dan',
	`freight_tax_amt` DECIMAL(16,4) NULL DEFAULT NULL COMMENT 'Doprava - stka dan v mn',
	`tax_amt` DECIMAL(16,2) NULL DEFAULT NULL COMMENT 'Celkov stka za dan v mn',
	`total_amt` DECIMAL(16,2) NOT NULL COMMENT 'Celkov fakturovan stka v mn',
	`cost_amt` DECIMAL(16,2) NULL DEFAULT NULL COMMENT 'Celkov stka nklad v mn',
	`paid_amt` DECIMAL(16,2) NULL DEFAULT NULL COMMENT 'Zaplacen stka v mn',
	`paid_date` DATE NULL DEFAULT NULL COMMENT 'Datum plnho zaplacen faktury',
	`due_date` DATE NULL DEFAULT NULL COMMENT 'Datum splatnosti',
	`year_num` SMALLINT(6) NULL DEFAULT NULL COMMENT 'etn rok',
	`period_num` SMALLINT(6) NULL DEFAULT NULL COMMENT 'etn obdob',
	`ship_year_num` SMALLINT(6) NULL DEFAULT NULL COMMENT 'Daov rok',
	`ship_period_num` SMALLINT(6) NULL DEFAULT NULL COMMENT 'Daov obdob',
	`line_num` SMALLINT(6) NULL DEFAULT NULL COMMENT 'Poet dek FA',
	`printed_num` SMALLINT(6) NULL DEFAULT NULL COMMENT 'Pznak vytitn FA ',
	`name_text` CHAR(30) NULL DEFAULT NULL COMMENT 'Jmno pjemce',
	`addr1_text` CHAR(30) NULL DEFAULT NULL COMMENT '1. dka adresy',
	`addr2_text` CHAR(30) NULL DEFAULT NULL COMMENT '2. dka adresy',
	`city_text` CHAR(20) NULL DEFAULT NULL COMMENT '3. dka dodac adresy',
	`state_code` CHAR(6) NULL DEFAULT NULL COMMENT 'Region',
	`post_code` CHAR(10) NULL DEFAULT NULL COMMENT 'PS',
	`country_text` CHAR(20) NULL DEFAULT NULL COMMENT 'Stt',
	`ship_date` DATE NULL DEFAULT NULL COMMENT 'Datum zdanitelnho plnn (datum dodvky)',
	`prepaid_flag` CHAR(1) NULL DEFAULT NULL COMMENT 'Forma hrady (P-PLatebn pkaz, H-Hotov, I-Ihned) ',
	`com1_text` CHAR(30) NULL DEFAULT NULL COMMENT 'Koment 1 k faktue ',
	`com2_text` CHAR(30) NULL DEFAULT NULL COMMENT 'Komenta 2 k faktue',
	`acct_override_code` CHAR(18) NULL DEFAULT NULL COMMENT 'Maska t',
	`price_tax_flag` CHAR(1) NULL DEFAULT NULL COMMENT 'Zadvat cenu vetn DPH ? Y/N',
	`contact_text` CHAR(30) NULL DEFAULT NULL COMMENT 'Kontaktn osoba v mst dodn',
	`tele_text` CHAR(20) NULL DEFAULT NULL COMMENT 'Telefonn slo kontaktu v mst dodn',
	`ship_num` INT(11) NULL DEFAULT NULL COMMENT 'slo dodacho listu ',
	`zaok_dph` CHAR(1) NULL DEFAULT NULL COMMENT 'M se provst zaokrouhlen DPH ? Y/N',
	`tot_netto` DECIMAL(12,3) NULL DEFAULT NULL COMMENT 'Celkov hmotnost NETTO',
	`tot_brutto` DECIMAL(12,3) NULL DEFAULT NULL COMMENT 'Celkov hmotnost BRUTTO',
	`entry_code` CHAR(8) NULL DEFAULT NULL COMMENT 'Kd uivatele, kter zapsal fakturu',
	`entry_date` DATE NULL DEFAULT NULL COMMENT 'Datum zpisu faktury',
	`valid_flag` BIT(1) NOT NULL,
	PRIMARY KEY (`inv_id`),
	INDEX `FK_invhead_customer` (`cust_code`),
	INDEX `FK_invhead_tax` (`tax_code`),
	INDEX `FK_invhead_tax_2` (`hand_tax_code`),
	INDEX `FK_invhead_tax_3` (`freight_tax_code`),
	INDEX `FK_invhead_custship` (`ship_code`),
	INDEX `FK_invhead_shipstate` (`state_code`),
	INDEX `FK_invhead_currency` (`currency_code`),
	INDEX `FK_invhead_typpohl` (`typ_pohl`),
	INDEX `FK_invhead_arkind` (`kind_code`),
	CONSTRAINT `FK_invhead_arkind` FOREIGN KEY (`kind_code`) REFERENCES `arkind` (`kind_code`),
	CONSTRAINT `FK_invhead_currency` FOREIGN KEY (`currency_code`) REFERENCES `currency` (`currency_code`),
	CONSTRAINT `FK_invhead_customer` FOREIGN KEY (`cust_code`) REFERENCES `customer` (`cust_code`),
	CONSTRAINT `FK_invhead_custship` FOREIGN KEY (`ship_code`) REFERENCES `custship` (`ship_code`),
	CONSTRAINT `FK_invhead_shipstate` FOREIGN KEY (`state_code`) REFERENCES `shipstate` (`state_code`),
	CONSTRAINT `FK_invhead_tax` FOREIGN KEY (`tax_code`) REFERENCES `tax` (`tax_code`),
	CONSTRAINT `FK_invhead_tax_2` FOREIGN KEY (`hand_tax_code`) REFERENCES `tax` (`tax_code`),
	CONSTRAINT `FK_invhead_tax_3` FOREIGN KEY (`freight_tax_code`) REFERENCES `tax` (`tax_code`),
	CONSTRAINT `FK_invhead_typpohl` FOREIGN KEY (`typ_pohl`) REFERENCES `typpohl` (`typ_pohl`)
)
COMMENT='Pohledvka-hlavika '
COLLATE='utf8mb4_general_ci'
ENGINE=InnoDB
;
CREATE TABLE `invdetl` (
	`inv_id_detl` INT(11) NOT NULL AUTO_INCREMENT,
	`inv_id` INT(11) NULL DEFAULT NULL COMMENT 'slo faktury',
	`cust_code` CHAR(8) NULL DEFAULT NULL COMMENT 'Kd odbratele',
	`line_num` SMALLINT(6) NULL DEFAULT NULL COMMENT 'slo dky faktury',
	`prod_code` CHAR(15) NULL DEFAULT NULL COMMENT 'Kd produktu ',
	`ware_code` CHAR(3) NULL DEFAULT NULL COMMENT 'Kd skladu',
	`cat_code` CHAR(3) NULL DEFAULT NULL COMMENT 'Kategorie produktu',
	`ord_qty` DECIMAL(10,2) NULL DEFAULT NULL COMMENT 'Objednan mnostv fakturovan objednvky',
	`ship_qty` DECIMAL(10,2) NULL DEFAULT NULL COMMENT 'Dodan mnostv fakturovan objednvky',
	`line_text` CHAR(40) NULL DEFAULT NULL COMMENT 'Popis dky faktury',
	`uom_code` CHAR(4) NULL DEFAULT NULL COMMENT 'Prodejn MJ',
	`unit_cost_amt` DECIMAL(16,4) NULL DEFAULT NULL COMMENT 'Jednotkov nkladov cena v mn',
	`ext_cost_amt` DECIMAL(16,2) NULL DEFAULT NULL COMMENT 'Celkov nkladov cena',
	`unit_sale_amt` DECIMAL(16,4) NULL DEFAULT NULL COMMENT 'Jednotkov prodejn cena bez DPH ',
	`ext_sale_amt` DECIMAL(16,4) NULL DEFAULT NULL COMMENT 'Celkov prodejn cena bez DPH ',
	`unit_tax_amt` DECIMAL(16,4) NULL DEFAULT NULL COMMENT 'Jednotkov da',
	`ext_tax_amt` DECIMAL(16,4) NULL DEFAULT NULL COMMENT 'Celkov da',
	`line_total_amt` DECIMAL(16,4) NULL DEFAULT NULL COMMENT 'Celkov cena dky vetn dan',
	`line_acct_code` CHAR(18) NULL DEFAULT NULL COMMENT 'et kontace',
	`tax_code` CHAR(3) NULL DEFAULT NULL COMMENT 'Kd dan',
	`analysis_text` CHAR(30) NULL DEFAULT NULL COMMENT 'Doplkov informace',
	`valid_flag` BIT(1) NOT NULL,
	PRIMARY KEY (`inv_id_detl`),
	INDEX `FK_invdetl_customer` (`cust_code`),
	INDEX `FK_invdetl_invhead` (`inv_id`),
	INDEX `FK_invdetl_product` (`prod_code`),
	INDEX `FK_invdetl_warehouse` (`ware_code`),
	INDEX `FK_invdetl_category` (`cat_code`),
	INDEX `FK_invdetl_uom` (`uom_code`),
	INDEX `FK_invdetl_coa` (`line_acct_code`),
	INDEX `FK_invdetl_tax` (`tax_code`),
	CONSTRAINT `FK_invdetl_category` FOREIGN KEY (`cat_code`) REFERENCES `category` (`cat_code`),
	CONSTRAINT `FK_invdetl_coa` FOREIGN KEY (`line_acct_code`) REFERENCES `coa` (`acct_code`),
	CONSTRAINT `FK_invdetl_customer` FOREIGN KEY (`cust_code`) REFERENCES `customer` (`cust_code`),
	CONSTRAINT `FK_invdetl_invhead` FOREIGN KEY (`inv_id`) REFERENCES `invhead` (`inv_id`),
	CONSTRAINT `FK_invdetl_product` FOREIGN KEY (`prod_code`) REFERENCES `product` (`prod_code`),
	CONSTRAINT `FK_invdetl_tax` FOREIGN KEY (`tax_code`) REFERENCES `tax` (`tax_code`),
	CONSTRAINT `FK_invdetl_uom` FOREIGN KEY (`uom_code`) REFERENCES `uom` (`uom_code`),
	CONSTRAINT `FK_invdetl_warehouse` FOREIGN KEY (`ware_code`) REFERENCES `warehouse` (`ware_code`)
)
COMMENT='dky pohledvky'
COLLATE='utf8mb4_general_ci'
ENGINE=InnoDB;
;
ALTER TABLE `apkind`
	COMMENT='Druhy doklad-zvazky'
	;
ALTER TABLE `class`
	COMMENT='Skladov tda'
	;
ALTER TABLE `product`
	COMMENT='Produkt (Vrobek, zbo, materil atd.)';
ALTER TABLE `stockdetl`
	COMMENT='dka skladovho dokladu';
ALTER TABLE `typzav`
	COMMENT='Typ zvazku';
ALTER TABLE `vendor`
	COMMENT='Dodavatel';
ALTER TABLE `vendortype`
	COMMENT='Typ dodavatele';
ALTER TABLE `orderhead`
	CHANGE COLUMN `tax_amt` `tax_amt` DECIMAL(16,2) NOT NULL DEFAULT '0' COMMENT 'Celkov stka DPH' AFTER `tax_code`;
ALTER TABLE `orderdetl`
	CHANGE COLUMN `order_qty` `order_qty` DECIMAL(8,2) NOT NULL DEFAULT '0' COMMENT 'Objednan mnostv' AFTER `uom_code`,
	CHANGE COLUMN `sched_qty` `sched_qty` DECIMAL(8,2) NOT NULL DEFAULT '0' COMMENT 'Rezervovan mnostv' AFTER `order_qty`,
	CHANGE COLUMN `inv_qty` `inv_qty` DECIMAL(8,2) NOT NULL DEFAULT '0' COMMENT 'Fakturovan mnostv' AFTER `sched_qty`,
	CHANGE COLUMN `picked_qty` `picked_qty` DECIMAL(8,2) NOT NULL DEFAULT '0' COMMENT 'Mnostv, kter je ureno k vdeji' AFTER `back_qty`,
	CHANGE COLUMN `conf_qty` `conf_qty` DECIMAL(8,2) NOT NULL DEFAULT '0' COMMENT 'Mnostv potvrzen jako dodan' AFTER `picked_qty`,
	CHANGE COLUMN `unit_price_amt` `unit_price_amt` DECIMAL(16,4) NOT NULL DEFAULT '0' COMMENT 'JC produktu za mnostevn koeficient ' AFTER `conf_qty`,
	CHANGE COLUMN `ext_price_amt` `ext_price_amt` DECIMAL(16,2) NOT NULL DEFAULT '0' COMMENT 'Celkov prodejn cena v mn' AFTER `unit_price_amt`,
	CHANGE COLUMN `unit_tax_amt` `unit_tax_amt` DECIMAL(16,4) NOT NULL DEFAULT '0' COMMENT 'Jednotkov da' AFTER `ext_price_amt`,
	CHANGE COLUMN `ext_tax_amt` `ext_tax_amt` DECIMAL(16,4) NOT NULL DEFAULT '0' COMMENT 'Celkov da (nezaokrouhlen)' AFTER `unit_tax_amt`,
	CHANGE COLUMN `line_tot_amt` `line_tot_amt` DECIMAL(16,2) NOT NULL DEFAULT '0' COMMENT 'dka celkem vetn dan' AFTER `ext_tax_amt`,
	CHANGE COLUMN `unit_cost_amt` `unit_cost_amt` DECIMAL(16,4) NOT NULL DEFAULT '0' COMMENT 'Jednotkov nkladov cena v mn ' AFTER `line_tot_amt`;
ALTER TABLE `orderdetl`
	CHANGE COLUMN `back_qty` `back_qty` DECIMAL(8,2) NOT NULL DEFAULT '0' COMMENT 'Nekryt mnostv dky objednvky' AFTER `inv_qty`;
ALTER TABLE `orderhead`
	CHANGE COLUMN `ord_id` `ord_id` INT(11) NOT NULL AUTO_INCREMENT COMMENT 'ID zznamu (slo objednvky)' FIRST;