<?php
/**
 * @author Petr Ruttkay
 *
 */


require_once "./_class/formXmlRead.php";

/**
 * 
 * Třída vytvoří XML definici dle DB shamatu zadané databázové tabulky 
 *
 */
class CrtForm4XML
{
    private $pdo;
    private $formTable;
    private $htmlTable;
    
    const ACTION_SAVE_LINES = "save_lines";
    const ACTION_DELETE_TABLE_ROWS = "delete_rows";
    const ACTION_GOTO_DETIAL = "edit_detail";
    const ACTION_INSERT_ROW = "insert_row_to_table";
    const ACTION_NEW_FILTER = "new_form_filter_data";
    const ACTION_CLEAR_FILTER = "clear_form_filter_data";
    
    
    public function __construct(isPDO $pdo, $tabName)
    {
        
        $this->pdo = $pdo;
       
       
        $sql = " SELECT  * FROM INFORMATION_SCHEMA.COLUMNS
                WHERE TABLE_NAME = :TABLE_NAME";
        $pdo->setNamedParam("TABLE_NAME", $tabName);
        

        $xml = new DOMDocument("1.0", 'UTF-8');
        
        $xml->formatOutput=true;
        $layout=$xml->createElement(FormStructure::LAYOUT);
        $xml->appendChild($layout);
        $layout->setAttribute('ID', 'XXX');
        $layout->setAttribute('title', 'XXX');
        $layout->setAttribute('direct_fill_data', 'false');
        $layout->setAttribute('show_button', 'true');
        $vbox=$xml->createElement(FormStructure::VBOX);
        $layout->appendChild($vbox);
        $vbox->setAttribute('ID', 'XXX');
        $grid=$xml->createElement(FormStructure::GRID);
        $vbox->appendChild($grid);
        $grid->setAttribute('ID', $tabName);
        $grid->setAttribute('db_primary_key', 'xxx');
        $grid->setAttribute('show_button', 'false');
        $grid->setAttribute('detail_flag', 'Y');
        $grid->setAttribute('insert_flag', 'Y');
        
        foreach ($this->pdo->query($sql) as $data)
        {
            $colName = $data["COLUMN_NAME"]; 
            if ($colName == "valid_flag") {
                continue;
            }
            
            
            $colDataType = $data["DATA_TYPE"];
            $colComment = $data["COLUMN_COMMENT"];
            $isNullAble = $data["IS_NULLABLE"];
            
            
            switch ($colDataType){
                case 'char':
                    $colDataSize = $data["CHARACTER_MAXIMUM_LENGTH"];
                    break;
                case 'varchar':
                    $colDataSize = $data["CHARACTER_MAXIMUM_LENGTH"];
                    break;
                case 'decimal':
                    $colDataSize = $data["NUMERIC_PRECISION"];
                    break;
                case 'int':
                    $colDataSize = $data["NUMERIC_PRECISION"];
                    break;
                case 'smallint':
                    $colDataSize = $data["NUMERIC_PRECISION"];
                    break;
                case 'date':
                    $colDataSize = 10;
                    break;
                default:
                    $colDataSize = 10;
                    break;
            }
            
            
                        
            $item=$xml->createElement(FormStructure::ITEM);
            $grid->appendChild($item);
            $item->setAttribute('ID', $colName);
            $i_name=$xml->createElement(FormStructure::NAME, $colComment);
            $item->appendChild($i_name);
            $db_name=$xml->createElement(FormStructure::DB_TABLE, $tabName);
            $item->appendChild($db_name);
            $db_column=$xml->createElement(FormStructure::DB_COLUMN, $colName);
            $item->appendChild($db_column);
            if ($colDataType == "varchar") {
                $data_type=$xml->createElement(FormStructure::TYPE,'char');
                $item->appendChild($data_type);
            } 
            else {
            $data_type=$xml->createElement(FormStructure::TYPE, $colDataType);
            $item->appendChild($data_type);
            }
            if ($colDataSize > 40) {
                $colDataSize = 40;
            }
            $data_size=$xml->createElement(FormStructure::SIZE, $colDataSize);
            $item->appendChild($data_size);
            $data_upsift=$xml->createElement(FormStructure::UPSIFT, 'N');
            $item->appendChild($data_upsift);
            $data_pos=$xml->createElement(FormStructure::POSITION, 'left');
            $item->appendChild($data_pos);
            $data_def=$xml->createElement(FormStructure::DEFAUL_VALUE, 'XYX');
            $item->appendChild($data_def);
            $data_comment=$xml->createElement(FormStructure::COMMENT, $colComment);
            $item->appendChild($data_comment);
            $data_mode=$xml->createElement(FormStructure::MODE, 'EDIT');
            $item->appendChild($data_mode);
            
            
            if ($isNullAble == "NO") {
                $data_req=$xml->createElement(FormStructure::REQUIRED, 'Y');                
            } else {
                $data_req=$xml->createElement(FormStructure::REQUIRED, 'N');                
            }
            $item->appendChild($data_req);
            $data_read=$xml->createElement(FormStructure::READONLY, 'N');
            $item->appendChild($data_read);
           
            
            $sql2 = "SELECT   REFERENCED_TABLE_NAME,REFERENCED_COLUMN_NAME FROM
  INFORMATION_SCHEMA.KEY_COLUMN_USAGE
WHERE
  TABLE_NAME = :TABLE_NAME
  AND COLUMN_NAME = :COLUMN_NAME";
            
            $pdo->setNamedParam("TABLE_NAME", $tabName);
            $pdo->setNamedParam("COLUMN_NAME", $colName);
            $outage = $pdo->fetchRow($sql2);
            
            $exitsRef = false;
            if ($outage != null)
            {
                $exitsRef = true;
                $ref_table = $outage["REFERENCED_TABLE_NAME"];
                $ref_column = $outage["REFERENCED_COLUMN_NAME"];
                
                if ($ref_table != null) {
                    $dbref_name=$xml->createElement(FormStructure::DB_REF_TABLE, $ref_table);
                    $item->appendChild($dbref_name);
                    $dbref_column=$xml->createElement(FormStructure::DB_REF_COLUMN, $ref_column);
                    $item->appendChild($dbref_column);
                    
                    $combo=$xml->createElement(FormStructure::COMBO);
                    $combo->setAttribute("db_table", $ref_table);
                    
                    $cItem=$xml->createElement(FormStructure::C_ITEM);
                    $cItem->setAttribute(FormStructure::CHECKED, true);
                    
                    $cValue=$xml->createElement(FormStructure::VALUE, $ref_column);
                    $cText=$xml->createElement(FormStructure::TEXT, $ref_column);
                    $cItem->appendChild($cValue);
                    $cItem->appendChild($cText);
                    
                    $combo->appendChild($cItem);
                    
                    $item->appendChild($combo);
                }                
            }          
            
            if ($exitsRef) {
//                 <MODE>COMBO_EDIT</MODE>
//                 <COMBO db_table="shipstate">
//                 <C_ITEM checked="true">
//                 <VALUE>state_code</VALUE>
//                 <TEXT>name_text</TEXT>
//                 </C_ITEM>
//                 </COMBO>
                
            } else {
//                 <MODE>EDIT</MODE>
            }

     
         }
         
         echo "<xmp>".$xml->saveXML()."</xmp>";
//          $xml->save("xxxxxxx.xml");
         
//          $writer->endElement();
//          $writer->endElement();
//          $writer->endElement();
//          $writer->endDocument();
//          $xml= $writer->flush();
//          echo "<xmp>".$xml . "</xmp>";
//          echo "<xmp>".$writer->saveXML()."</xmp>";
//          $xml->save("report.xml");
    }
    
   
}

