<?php
/**
 * @author Petr Ruttkay
 *
 */

require_once "./_class/formPostDataLib.php";

/**
 * Třída je určená k validaci formuláře  
 *
 */
class FormCheck
{
   private $pdo;
   private $formStructure;
   private $new_flag;
   private $name;
   private $msg;
   private $primaryKey;
   private $referTables= array();
   private $descColumns= array();


   public function __construct(isPDO $pdo, $name, FormStructure $formStructure, $new_flag)
   {
      $this->pdo = $pdo;
      $this->formStructure = $formStructure;

      $this->name = $name;
      $this->new_flag = $new_flag;
   }


/**
 * Funkce provede základní kontrolu zadaných údajů ve formuláři.
 * 
 * @return boolean
 */
   public function checForm()
   {
       
       $postData =  new FormPostDataLib($this->new_flag);
       $key_code = $postData->getPrimaryKey();
       $this->primaryKey = $key_code;
       
       if ($this->new_flag) {
           if ($key_code == null){
               $this->msg = $this->name." musí být vyplněn";
               return false;
           }
           $sql = "select distinct ".$postData->getPrimaryColumn()." from " . $postData->getTable() .
           " where ". $postData->getPrimaryColumn()." = :". $postData->getPrimaryColumn();
           
           $this->pdo->setNamedParam($postData->getPrimaryColumn(), $key_code);
           $this->pdo->fetchRow($sql);
           if (!$this->pdo->isNotFound()) {
               $this->msg = $this->name." ".$key_code." již existuje";
               return false;
           }
       }
       
       $this->fillReferTables();
       
       foreach ($this->referTables as $column => $table)
       {
            
           if ($postData->getPrimaryColumn() == $column && $this->new_flag){
                continue;
           }
           $key_code = $postData->getValue4RefColumn($column);
           if ($key_code != null){
               $sql = "select distinct ".$column." from " . $table .
               " where ". $column." = :". $column;
               
               $this->pdo->setNamedParam($column, $key_code);
               $this->pdo->fetchRow($sql);
               if ($this->pdo->isNotFound()) {
                   
                   $this->msg = $this->descColumns[$column]." '".$key_code."' neexistuje";
                   return false;
               }
           }           
       }
       return true;
   }
   
   
   function fillReferTables(){
       
       $formLayout = $this->formStructure->getFormLayout();
       foreach($formLayout->getBoxList() as $formBox) {
           foreach($formBox->getBoxItems() as $boxItem) {
               if (is_a($boxItem, 'FormGrid')) {                   
                   foreach($boxItem->getItems() as $formGridItem) {
                       if (is_a($formGridItem, "FormGridItem")){
                           if ($formGridItem->getDbRefTable() != null){
                               $this->descColumns[$formGridItem->getDbRefColumn()] = $formGridItem->getColumnName();
                               if ($formGridItem->getDbRefColumn() != null){
                                   $this->referTables[$formGridItem->getDbRefColumn()] = $formGridItem->getDbRefTable();
                               } else {
                                   $this->referTables[$formGridItem->getDbColumn()] = $formGridItem->getDbRefTable();
                               }
                           }
                       }                       
                   }                   
               } 
           }
       }
   }
   
    /**
     * Funkce vrací chybovu nebo informační zprávu
     * 
     * @return string
     */
    public function getMsg()
    {
        return $this->msg;
    }
    /**
     * Funkce vrací hodnotu primárního klíče DB tabulky.
     * 
     * @return mixed
     */
    public function getPrimaryKey()
    {
        return $this->primaryKey;
    }




}