<?php

/**
 * @author Petr Ruttkay
 *
 */
require_once "./_func/isPdoFactory.php";
require_once "./_func/errorlib.php";
require_once "./_class/prHtmlForm.php";
require_once "./_class/prHtmlTable.php";
require_once "./_class/prProgress.php";
require_once "./_func/datetime_lib.php";
require_once "./_func/format.php";
require_once "./_class/formXmlRead.php";
require_once "./_class/formBoxCreator.php";
require_once "./_func/editFactory.php";
require_once "./_class/formCheck.php";

/**
 * 
 * Třída je určená k vytvoření hlavního bloku formuláře
 */
class FormCore
{
   private $pdo;
   private $updateSQL;
   private $formStructure;
   private $progressText = null;
   private $tempFlag = false;
   private $tableTop;
   private $csProgress;

   // formulář pro editaci
   private $formEditAction;
   private $keyName;
   private $noFiltred = true;

/**
 * Třída je určená k vytvoření HTML formuláře  
 * @param isPDO $pdo
 * @param string $keyName například Příjemka dle struktury XML souboru
 * @param FormStructure $formStructure - Třída definice struktury formuláře 
 */
   public function __construct(isPDO $pdo,  $keyName, FormStructure $formStructure) {
      $this->pdo = $pdo;
      $this->formStructure = $formStructure;
      $this->keyName = $keyName;
      
      $sql = "create table  if not exists filter_data (user char(20), form_id char(20), tabname varchar(30), colname varchar(30), value varchar(500), dbtype char(20), exact bit, required bit, negation bit, caseSensitive bit)";
      //       echo "<BR>".$sql;
      if ($pdo->exec($sql) === false){
          echo '<p>Selhalo vytvoření tabulky filter_data';
          echo '<p>' . $sql;
          die();
      }
      
      if (!isset($_SESSION["LAYOUT_ID"])){
          $_SESSION["LAYOUT_ID"] = $formStructure->getFormID();
      } else {
          if ($_SESSION["LAYOUT_ID"] != $formStructure->getFormID()){
              $_SESSION["LAYOUT_ID"] = $formStructure->getFormID();
              unset($_SESSION["_AreaKey_Table_detl_key"]);
              unset($_SESSION["_AreaKey_Table_detl_column"]);
              unset($_SESSION["_AreaKey_Table_head_key"]);
              unset($_SESSION["_AreaKey_Table_head_column"]);
              unset($_SESSION["_AreaKey_Grid_head_key"]);
              unset($_SESSION["_AreaKey_Grid_detl_key"]);
          }
      }
      initForm();  //Resetuje prmoměnné session      
   }

   /**
    *  Výkonná funkce, která vygeneruje HTML stránku
    */
   public function run() {
       $this->initFormCore();
       $this->actionForm();    
       
       if ($this->progressText == null){
           $this->progressText = "Probíhá načtení dat";
       }
       $this->genPage($this->progressText);       
   }
    
   /**
    * Funkce na Inicializaci Formuláře.
    * Dále funkce zkoumá, zdali byla vyvolaná akce pomocí tlačítek: Kopie, Reset filtru, Filtr, Insert řádky a OK při potvrzení filtru 
    */
   public function initFormCore() {       
       if (isset($_SESSION["updateSQL"])){
           $this->updateSQL = $_SESSION["updateSQL"];
       }
       
       $this->noFiltred = true;       
       $_SESSION["noFiltred"] = "A";
       $_SESSION["show_last_data"] = false;
       $_SESSION["insRow"] = "N";
       $_SESSION["tempFlag"] = $this->tempFlag;
       
       generateCancelButton();
       
       if ($this->tempFlag)
           generateInsertDoclButton("Zápis - " . $this->keyName);
           
           //Test na požadavek kopie záznamu v DB
           if (isset($_COOKIE['Copy_ID_row'])){
               if ($_COOKIE['Copy_ID_row'] != "null") {
                   //Má se udělat kopie DB záznamu na kód dle zadání uživatelem.
                   $idRow = $_COOKIE["Copy_ID_row"];
                   $value = $_COOKIE["Copy_db_row"];
                   echo '<script type="text/javascript"> document.cookie = "Copy_ID_row=null"; </script>';
                   //                echo "<BR>value = ". $value;
                   $formCheck = new FormCheck($this->pdo, $this->keyName, $this->formStructure, false);
                   
                   if ($formCheck->checForm()){
                       $msg = cloneDBRow($this->pdo, $idRow, $value);
                       if (isset($msg)) {
                           echo getErrorMsg($msg);
                       }
                   } else {
                       $msg =$formCheck->getMsg();
                       echo "<font color=red><b>".$msg."!</b></font>";
                       
                       $_SESSION["show_last_data"] = false;
                       $_SESSION["primaryKey"]     = $value;
                   }
                   
                   $this->noFiltred = false;
                   $_SESSION["noFiltred"] = "N";
               }
           }           
           
           $this->formEditAction = new PrHtmlForm("editAction", null);
           $this->formEditAction->setNoPrint();
           echo $this->formEditAction->publishStart();
                      
           if ($this->formEditAction->wasSentButton(FormTableCreator::ACTION_CLEAR_FILTER)){
               $msg = deleteFilter($this->pdo, $this->formStructure);               
               if (isset($msg)) {
                   echo getErrorMsg($msg);
               } else {
                   $this->noFiltred = false;
                   $_SESSION["noFiltred"] = "N";
               }
           }
           
           if (($this->formStructure->getDirectFillData() ||
               $this->formEditAction->wasSentButton(FormTableCreator::ACTION_INSERT_ROW)) &&
               !$this->formEditAction->wasSentButton(FormTableCreator::ACTION_NEW_FILTER)
               ){
                   //Data se načítají rovnou bez výběrového formuláře
                   $this->noFiltred = false;
                   $_SESSION["noFiltred"] = "N";
           }
           
           if ($this->formEditAction->wasSentButton(FormTableCreator::ACTION_INSERT_ROW)){
               //Vložení nového záznamu
               $_SESSION["insRow"] = "Y";
           }
           
           if ($this->formEditAction->wasSentButton(FormGridCreator::ACTION_GOTO_QUERY_OK)) {
               //Provádí se výběr dat
               
               $msg = createQuery($this->pdo, $this->formStructure);
               
               if (isset($msg)) {
                   echo getErrorMsg($msg);
               } else {
                   $this->noFiltred = false;
                   $_SESSION["noFiltred"] = "N";
               }
               
           }
           
           if ($this->formEditAction->wasSentButton(FormTableCreator::ACTION_DELETE_TABLE_ROWS)) {
               $msg = deleteRows($this->pdo);
               if (isset($msg)) {
                   echo getErrorMsg($msg);
               }
               $this->noFiltred = false;
               $_SESSION["noFiltred"] = "N";
           }
           
           if ($this->formEditAction->wasSentButton(FormTableCreator::ACTION_GOTO_DETIAL)) {
               setSesionPrimaryKeyFordetail();
               $this->noFiltred = false;
               $_SESSION["noFiltred"] = "N";
               
               $postData = new FormPostDataLib(false);
               $_SESSION["_AreaKey_Grid_".$postData->getArea()."_key"] = $postData->getIdDetail();
               if ($postData->getArea() == "head"){
                   $_SESSION["_AreaKey_Table_detl_key"] = $postData->getIdDetail();
                   $_SESSION["_AreaKey_Table_detl_column"] = $postData->getColumn4Detail();
                   $_SESSION["_AreaKey_Grid_detl_key"] = "NILL";                   
               }
           } 
           
   }
   
   /**
    * Inicializace pro tisk formuláře. Funkce nastaví začátek oblasti určené k tisku a vygeneruje začátek form.
    */
   public function initFormCore4Print()   {       
       echo '<input type="button" onclick="printDiv(\'printableArea\')" value="Tisk" />';
       echo '<div id="printableArea">';
       
       echo "\n";
       echo '<style type="text/css">';
       echo "\n";
       echo "\n";
       // potlačení objektu v tisku (class="noprint")
       echo '@media print';
       echo '{';
       echo '.noprint {display:none;}';
       echo '}';
       echo "\n";
       
       // odstránkování tisku - styl pomocného div
       echo '@media print';
       echo '{';
       echo '.page-break { display: block; page-break-before: always; }';
       echo '}';
       echo "\n";
       echo "\n";
       echo '</style>';
       echo "\n\n";
       
       $_SESSION["noFiltred"] = "N";
       $_SESSION["show_last_data"] = false;
       $_SESSION["insRow"] = "N";
       $_SESSION["tempFlag"] = $this->tempFlag;
       $_SESSION["print"] = true;
       $this->noFiltred = false;
   }
   
   /**
    * Funkce vytvoří HTML kód a zobrazí jej přes echo  
    * @param string $progressText - Text pro zobrazení jaké data se právě načítají
    */
   public function genPage($progressText){
       // tabulka pro rozvržení stránky
       $this->tableTop = new PrHtmlTable();
       
       $this->csProgress = new PrProgress();
       $this->csProgress->start($progressText);
       
       $this->genPageImpl($progressText);
       
       echo $this->tableTop->publish() . $this->formEditAction->publishEnd();

       $this->csProgress->finish(1);
       
   }

   /**
    * Funkce vytvoří tabulku určenou k rozvržení stránky. 
    * Volá se jen jednou před přidáváním řádek do hlavní tabulky.
    * Pak se zavolá funkce genPage4Print ta se může volat opakovaně. 
    * Dokud se nepoužije funkce na zveřejnění celého HTML kódu  
    * 
    * @param string $progressText - Text pro zobrazení jaké data se právě načítají
    */
   public function initPage4Print($progressText){       
       // tabulka pro rozvržení stránky
       $this->tableTop = new PrHtmlTable();
       $this->tableTop->setPageBreakAvoid();
       
       $this->csProgress = new PrProgress();
       $this->csProgress->start($progressText);
   }
   
   /**
    * Funkce připravuje HTML kód. Tento kód se zveřejní pomocí funkce publishPage4Print
    */
   public function genPage4Print(){
       $this->genPageImpl();      
   }
   
   public function pageBreak(){
       $this->tableTop->addRow();
       $cellText  =  '<p><div class="page-break">';
       $cellText .= '</div>';
       $this->tableTop->addRowCell("");
       $this->tableTop->addRowCell($cellText);
   }

   /**
    * Funkce zveřejňuje HTML kód pomocí echa a ukončuje progressbar a ukončuje DIV určený k definici oblasti určené k tisku
    */
   public function publishPage4Print(){
       echo $this->tableTop->publish() . $this->formEditAction->publishEnd();
       
       $this->csProgress->finish(1);
       $this->finishForm();
   }
   
   /**
    * Hlavní funkce na tvorbu HTML  
    */
   private function genPageImpl(){
       $this->tableTop->addRow();
       
       $cellFormID = $this->tableTop->addRowCell($this->formStructure->getFormID());
       $cellFormID->setFontSize(8);
       $cellTitle = $this->tableTop->addRowCell($this->formStructure->getFormTitle());
       $cellTitle->setAlignCentered();
       $cellTitle->setWidth(900);
       $cellTitle->setTextBold();
       
       $this->tableTop->addRow();
       
       $formLayout = $this->formStructure->getFormLayout();
       
       
       $lastBox = null;
       $firstGrid = true;
       $_SESSION["existsFilterBox"] = false;
       foreach($formLayout->getBoxList() as $formBox) {
           $typeBox = $formBox->getTypeBox();
           if ((!$formBox->isShowBox4Insert() && $_SESSION["insRow"] == "N" &&
               !$this->formEditAction->wasSentButton(FormTableCreator::ACTION_GOTO_DETIAL)) &&
               $_SESSION["print"] == false){
                   //BOX se zabrazuje jen při vkládaní
                   continue;
           }
           if (!$formBox->isShowBox4Detail() && $_SESSION["insRow"] == "Y" &&
               $this->formEditAction->wasSentButton(FormTableCreator::ACTION_GOTO_DETIAL)){
                   //BOX se zabrazuje jen při detailu
                   continue;
           }
           
           if ($formBox->getFilter() && $_SESSION["print"] == false){  //Při tisku se ikony filtru nezobrazují 
               //Existuje BOX s filtrem
               $_SESSION["existsFilterBox"] = true;
           }
           
           if (!$formBox->getFilter() && $this->noFiltred){
               //Neni filtr 
               continue;
           }
           if ($formBox->getFilter() && !$this->noFiltred){
               //Jen BOX typu filtr
               continue;
           }
           
           $this->tableTop->addRow();
           $this->tableTop->addRowCell("");
           //            }
           
           if ($lastBox != null && $lastBox->getTypeBox() == FormStructure::HBOX && $lastBox->isShowButton()) {
               $tableFooter = new PrHtmlTable();
               $tableFooter->setWidthPercent(100);
               $tableFooter->addRow();
               $tableFooter->addRowCell(generateFormButtons($this->noFiltred))->setAlignCentered();
               
               $this->tableTop->addRow();
               $this->tableTop->addRowCell("");
               $this->tableTop->addRowCell($tableFooter->publish());
           }
           
           $lastBox = $formBox;
           
           if ($typeBox == FormStructure::VBOX){
               
               $boxCrt = new FormBoxCreator($this->pdo, $this->formStructure->getFormID(), $formBox, $firstGrid);
               $this->tableTop->addRowCell($boxCrt->getHtml());//->setAlignCentered();
               $firstGrid = $boxCrt->getFirstGrid();
               
               if ($boxCrt->getUpdateSQL() != null ) {
                   $this->updateSQL = $boxCrt->getUpdateSQL();
               }
               
           } else {               
               $boxCrt = new FormBoxCreator($this->pdo, $this->formStructure->getFormID(), $formBox, $firstGrid);
               $firstGrid = $boxCrt->getFirstGrid();
               $this->tableTop->addRowCell($boxCrt->getHtml());//->setAlignCentered();
               if ($boxCrt->getUpdateSQL() != null ) {
                   $this->updateSQL = $boxCrt->getUpdateSQL();
               }
           }
           
       }
       
       if ($this->updateSQL != null){
           $_SESSION["updateSQL"] = $this->updateSQL;
       }
       
       if ($this->formStructure->isShowButton()) {
           $this->tableTop->addRow();
           $this->tableTop->addRowCell("");
           $this->tableTop->addRowCell(generateFormButtons($this->noFiltred));
       }       
   }
   
   /**
    * Funkce ukončí DIV určený k vymezení tiskové oblasti
    */
   private function finishForm(){
       echo '</div>'; //printableArea
       
       $js = '<script type="text/javascript" charset="UTF-8"">
        function printDiv(divName) {
         var printContents = document.getElementById(divName).innerHTML;
         var originalContents = document.body.innerHTML;           
         document.body.innerHTML = printContents;           
         window.print();           
         document.body.innerHTML = originalContents;
     }            </script>';
       echo $js;       
   }
   
   /**
    * Funkce zkoumá zdali byla vyvolaná akce pomocí tlačítka na stránce (Zapsat, Uložit, Storno atd.) 
    * @return string - Vrací případnou chybu
    */
   public function actionForm(){
       
       if ($this->formEditAction->wasSentButton(FormGridCreator::ACTION_GOTO_STORNO)) {
           //Bylo stisknuto tlačítko STORNO
           $this->noFiltred = true;
           $_SESSION["noFiltred"] = "A";
           $_SESSION["updateSQL"] = null;
           $_SESSION["primaryKey"] = null;
           
           $sql = "delete from filter_data where user = :user and form_id = :form_id";
           $this->pdo->setNamedParam("user", $_SESSION["is_user"]);
           $this->pdo->setNamedParam("form_id", $this->formStructure->getFormID());
           if ($this->pdo->exec($sql) === false){
               return "Chyba filtru dat";
           }
       }       
       
       if ($this->formEditAction->wasSentButton(FormTableCreator::ACTION_SAVE_LINES) ||
           $this->formEditAction->wasSentButton(FormGridCreator::ACTION_GOTO_EDITOR_UPD_SAVE)) {
           //Aktulazace dat
           $custCheck = new FormCheck($this->pdo, $this->keyName, $this->formStructure, false);
           
           if ($custCheck->checForm()){
               $msg = saveChanges($this->pdo);
               if (isset($msg)) {
                   echo getErrorMsg($msg);
               }
           } else {
               $msg =$custCheck->getMsg();
               echo "<font color=red><b>".$msg."!</b></font>";
               
               $_SESSION["show_last_data"] = true;
               $_SESSION["primaryKey"]     = $custCheck->getPrimaryKey();
           }
           
           $this->noFiltred = false;
           $_SESSION["noFiltred"] = "N";           
       }
       
       if ($this->formEditAction->wasSentButton(FormGridCreator::ACTION_GOTO_EDITOR_INS_SAVE)) {
           //Zápis nových dat
           $custCheck = new FormCheck($this->pdo, $this->keyName, $this->formStructure, true);
           if ($custCheck->checForm()) {
               $msg = InsertIntoDB("Zápis - " . $this->keyName, $this->pdo, false);
               if (isset($msg)) {
                   echo getErrorMsg($msg);
               }
           } else {
               $msg =$custCheck->getMsg();
               echo "<font color=red><b>".$msg."!</b></font>";
               $_SESSION["show_last_data"] = true;
               $_SESSION["primaryKey"]     = null;
               $_SESSION["insRow"] = "Y";
           }
           $this->noFiltred = false;
           $_SESSION["noFiltred"] = "N";
       }
   }
   
   /**
    * Funkce nastavuje text určrný k zobrazení v progressbaru
    * @param string $progressText - Popis jaké data se načítají
    */
   public function setPregressText($progressText) {
       if ($progressText == null){
           $progressText = "Probíhá načtení dat";
       }
   }
   
   /**
    * Nastavení pomocného režimu, kdy se data ukládají jako neplatná (valid_flag = false)
    * @param boolean $tempFlag
    */
   public function setTempFlag($tempFlag) {
       $this->tempFlag = $tempFlag;
   }
   
   /**
    * Statická funkce nastavuje pro editační políčko ($editText) regulární výraz, kterým se pak provádí validace zadaného údaje.
    * @param string $dbType - databázový typ: date, decimal2 - na 2 desetiny, integer, smallint
    * @param PrHtmlText $editText
    */
   public static function setPattern4EditText($dbType, PrHtmlText $editText) {

       switch ($dbType) {
           case FormStructure::TYPE_DATE:
               $editText->setPatternDate();
               break;
           case FormStructure::TYPE_DEC:
               $editText->setPatternDecimal4();
               break;
           case FormStructure::TYPE_DECIMAL:
               $editText->setPatternDecimal4();
               break;
           case FormStructure::TYPE_DEC2:
               $editText->setPatternDecimal2();
               break;
           case FormStructure::TYPE_DECIMAL2:
               $editText->setPatternDecimal2();
               break;
           case FormStructure::TYPE_INT:
               $editText->setPatternIntegerUnsign();
               break;
           case FormStructure::TYPE_INTEGER:
               $editText->setPatternIntegerUnsign();
               break;
           case FormStructure::TYPE_SMALLINT:
               $editText->setPatternIntegerUnsign();
               break;
       }
       
   }
   
    /**
     * Vrací třídu s formulářem 
     * @return PrHtmlForm
     */
    public function getFormEditAction() {
        return $this->formEditAction;
    }

    /**
     * Vrací TRUE pokud nebyl ještě zobrazený filtr pro zadání výběrové podmínky 
     * @return boolean
     */
    public function getNoFiltred() {
        return $this->noFiltred;
    }

    /**
     * @param boolean $noFiltred
     */
    public function setNoFiltred($noFiltred) {
        $this->noFiltred = $noFiltred;
    }  
}
