<?php
/**
 * @author Petr Ruttkay
 *
 */

require_once "./_class/formXmlRead.php";
require_once "./_class/prHtmlTable.php";
require_once "./_class/prHtmlText.php";
require_once "./_class/prHtmlCheck.php";
require_once "./_class/prHtmlRadio.php";
require_once "./_class/prHtmlCombo.php";
require_once "./_func/editFactory.php";

/**
* Třída přípravuje TABULKU pro jeho náslené zveřejnění
*
*/
class FormTableCreator
{
    private $pdo;
    private $updateSQL;
    private $formTable;
    private $htmlTable;
    private $area;
    private $fontSize = 14;
    
    const ACTION_SAVE_LINES = "save_lines";
    const ACTION_DELETE_TABLE_ROWS = "delete_rows";
    const ACTION_GOTO_DETIAL = "edit_detail";
    const ACTION_INSERT_ROW = "insert_row_to_table";
    const ACTION_NEW_FILTER = "new_form_filter_data";
    const ACTION_CLEAR_FILTER = "clear_form_filter_data";
    
    
    public function __construct(isPDO $pdo, FormTable $formTable, $area)
    {
        
        $this->pdo = $pdo;
        $this->formTable = $formTable;
        $this->area = $area;
        $this->formInsertAction = new PrHtmlForm("editAction", null);
        $this->formInsertAction->setNoPrint();
        
        $tableHead = new PrHtmlTable();
        
     
        if ($formTable->getFontSize() != null)
            $this->fontSize = $formTable->getFontSize();
        
        if ($_SESSION["existsFilterBox"]) {
            $FilterButton = $this->formInsertAction->publishSendButtonNamedImage(self::ACTION_NEW_FILTER,
                "Filter" . "_#_". "new", "Zadání filtru pro výběr dat", "./_img/small/filter.png");
            $FilterClearButton = $this->formInsertAction->publishSendButtonNamedImage(self::ACTION_CLEAR_FILTER,
                "Filter" . "_#_". "clear", "Zrušení filtru",  "./_img/small/filter_remove.png");            
        } else {
            $FilterButton = "";
            $FilterClearButton = "";
        }
        if ($formTable->getIns_row_flag()){
            $InsButton = $this->formInsertAction->publishSendButtonNamedImage(self::ACTION_INSERT_ROW,
                "insert" . "_#_". "row", "Vložení nového záznamu", "./_img/small/add.png");
        } else {
            $InsButton = "";
        }
        
        $tableHead->addRowCell($InsButton . $FilterButton . $FilterClearButton)->setNoWrap(true);
        
        $table2 = new PrHtmlTable();
        $table2->setStyleBorder();
        
        $sql = "select ";
        $join = "";
        if (isset($_SESSION["wherePartRow"])) {
            $wherePart = $_SESSION["wherePartRow"];                
        } else {
            $keyTable = getIDKey4FormTable($area, $formTable->getTableID());
            if ($keyTable != null) {
                //Nastavení pro výber řádek tabulky 
                $wherePart = " " . $formTable->getColumns()[0]->getDbTable() . "." . getColumn4TableDetail($area) . " = " . $keyTable; // POdmínka pro načtení řádek dokladu
            } else {
                $wherePart = " 1=1";
            }
        }
        
        
        $setCol = "";
        $idx = 0;
        $first_flag = true;
        $dbTable = null;
        
               
        foreach($formTable->getColumns() as $formTableColumn) {
            $idx++;
            
            $colHead = $table2->addHeaderCell(str_replace("\\n", "<BR>", $formTableColumn->getColumnName()))->setValignCentered();  
            
            if ($formTableColumn->getPosition() == "center") {
                $colHead->setAlignCentered();
            } elseif ($formTableColumn->getPosition() == "right") {
                $colHead->setAlignRight();
            }
            
            $colHead->setWidth($formTableColumn->getSize() * 5);
            
            if ($formTableColumn->getDbTableJoin() != null) {
                if (strpos($join, $formTableColumn->getDbJoinOn()) == 0) {
                    $join .= " " . $formTableColumn->getDbTableJoin() . " " . $formTableColumn->getDbJoinOn() . 
                    " and ".$formTableColumn->getDbTable() . ".valid_flag = 1";
                }
            }
            
            if ($dbTable == null) {
                $dbTable = $formTableColumn->getDbTable();
            }
            
            
            if (strpos($formTableColumn->getDbColumn(), " _as_") > 0) {
                //Je zadaný alias názav tabulky se se před sloupcem neuvádí
                if ($idx == 1){
                    $sql .= str_replace("_as_", "as",  $formTableColumn->getDbColumn());
                } else {
                    $sql .= ", " . str_replace("_as_", "as",  $formTableColumn->getDbColumn());
                }
                
            } else {
                if ($idx == 1){
                    $sql .= $formTableColumn->getDbTable(). "." .$formTableColumn->getDbColumn();
                } else {
                    $sql .= ", " . $formTableColumn->getDbTable(). "." . $formTableColumn->getDbColumn();
                }
            }
            
            //Doplnění DB sloupce pro přednastavení hodnoty do sloupce položy COLUMN
            $defaultValueDBC = getDefaultValueDBC( $formTableColumn->getDefaultValue());
            if ($defaultValueDBC != null) {
                $sql .= ", " . $defaultValueDBC;
            }
            //Doplnění DB slopce pro přednastavení hodnoty do LABEL
            $labelSql = getDefaultValueDBC($formTableColumn->getLabel());
            if ($labelSql != null) {
                $sql .= ", " . $labelSql;
            }
            
            if ($formTableColumn->getMode() == "EDIT"){
                if ($first_flag){
                    $first_flag = false;
                    $setCol .= $formTableColumn->getDbColumn() . "= :" . $formTableColumn->getDbColumn();
                } else {
                    $setCol .= "," . $formTableColumn->getDbColumn() . "= :" . $formTableColumn->getDbColumn();
                }
            }
        }

        if (isset($_SESSION["whereSQL"])){
            $whereSQL = $_SESSION["whereSQL"];
        } else {
            $whereSQL = " 1=1";
        }
        if ($idx >=3) {
            $orderByText = " order by 1, 2, 3 ";
        } else {
            $orderByText = " order by 1, 2 ";
        }
        
        $validFlag = "1";
        if (isset($_SESSION["tempFlag"])){
            if ($_SESSION["tempFlag"]) {
                //Pomocný záznam pří zápisu dokladu
                $validFlag = "0";
            } else {
                $validFlag = "1";
            }
            
        }
        
        $sql .= " from " . $dbTable. " " . $join. " where " . $whereSQL . " and ".$dbTable.".valid_flag = ".$validFlag." and " . $wherePart. $orderByText;
//           echo "<BR>----------------------------------<BR>",$sql;
        
        $this->updateSQL = "update " . $dbTable . " set " . $setCol . " where " . $formTable->getDb_primary_key() . "= :" . $formTable->getDb_primary_key();
        
        $row_num = 0;
        $existEdit = false;
        
        foreach ($this->pdo->query($sql) as $data)
        {
            $row_num++;
            $tabRow = $table2->addRow();

            $key_code = null;
            foreach($formTable->getColumns() as $formTableColumn) {
                $value = null;
                $labelItem = null;
                
                $value = $data[geColumnAlias($formTableColumn->getDbColumn())];
                
                $dbc = getDefaultValueAliasDBC($formTableColumn->getLabel());
                if ($dbc != null){
                    $labelItem = $data[$dbc];  //label z databáze
                } else {
                    $labelItem = $formTableColumn->getLabel();
                }
                
                
                if ($key_code == null){
                    $key_code = $data[$formTable->getDb_primary_key()];
                }
                
                if ($formTableColumn->getDbType() == FormStructure::TYPE_DATE)
                {
                    if ($value != null) {
                        $value = getFormDate($value);
                    } 
                } 
                if ($formTableColumn->getReadonly() == "Y") {
                    //Když je readonly neprovádí se update
                    $updID = "noupdate_".$formTableColumn->getDbColumn()."readonly";
                } else {
                    $updID = getUpdateIdKey($dbTable, $formTable->getDb_primary_key(), $key_code,
                        $formTable->getTableID(), $formTableColumn->getDbColumn(), $value);
                }
                
                if ($formTableColumn->getMode() == "EDIT"){
                    if ($formTableColumn->getReadonly() == "N")
                        $existEdit = true;
                                        
                    if ($formTableColumn->getDefaultValue() != null && $formTableColumn->getReadonly() == "Y"){
                        //Když je readonly tak se přepisuje vždy jedná se např. o výpočet.
                        $dbc = getDefaultValueAliasDBC($formTableColumn->getDefaultValue());
                        if ($dbc != null){
                            $value = $data[$dbc];
                        }
                    } 
                    
                    $editText = new PrHtmlText($updID, $formTableColumn->getSize(), $value);
                    
                    setEditTextAttribute ($formTableColumn, $editText, false, false);
                    $editText->setBubbleText($formTableColumn->getComment());
                    
                    
                    if ($formTableColumn->getReadonly() == "Y"){
                        $editText->setTextBgColor(prColors::GREY_LIGHT);
                    }
                    elseif ($formTableColumn->getRequired() == "Y"){
                        $editText->setTextBgColor(prColors::LIGHTSKYBLUE);
                    }
                    $coldetl = $table2->addRowCell($this->getHTML4Label($formTableColumn->getDbType(), $editText, $labelItem));
                    //$editText->setPatternDecimal2();
                } elseif ($formTableColumn->getMode() == "COMBO_EDIT"){
                    if ($formTableColumn->getReadonly() == "N")
                        $existEdit = true;
                        
                    $comboType = new prHtmlCombo($updID);
                    $comboType->setFontSize($this->fontSize);
                    
                    
                    if ($formTableColumn->getComboDBTable() != null){
                        
                        $comboType->addOptionNone();
                        
                        $comboInfo = $formTableColumn->getItems()[0];
                        
                        $whereText = $comboInfo->getWhereText();
                        if ($whereText == null)
                            $whereText = "1=1";
                        $sql = "select ";
                        $sql .= $comboInfo->getValue() . ", ";
                        $sql .= $comboInfo->getText() . " ";
                        $sql .= " from " . $formTableColumn->getComboDBTable(). " where ".$whereText." and valid_flag = 1 order by 1, 2 ";
                        
                        $comboType->addListFromDB($this->pdo, $sql, $comboInfo->getValue(), $comboInfo->getText(), null, $value);
                        
                    } else {
                        foreach($formTableColumn->getItems() as $comboItem) {
                            $comboType->addOption($comboItem->getValue(),
                                $comboItem->getText(), $comboItem->getChecked());
                        }
                    }
                    
                     $comboType->setSelectedValue($value);
                     if ($formTableColumn->getReadonly() == "Y"){
                         $comboType->setDisabled();
                     }
                     $comboType->setRequired($formTableColumn->getRequired() == "Y"); 
                    $coldetl = $table2->addRowCell($comboType->publish());
                } elseif ($formTableColumn->getMode() == "RADIO_EDIT"){
                    if ($formTableColumn->getReadonly() == "N")
                        $existEdit = true;
                        
                    $radio = new PrHtmlRadio($updID);
                    
                    $radio->setBubbleText($formTableColumn->getComment());
                    
                    $table0 = new PrHtmlTable();
                    
                    foreach($formTableColumn->getItems() as $comboItem) {
                        $table0->addRow();
                        $table0->addRowCell($radio->publishVal($comboItem->getValue(),
                            $value, $comboItem->getText()))->setColSpan(2);
                            
                    }
                    $coldetl = $table2->addRowCell($table0->publish());
                } elseif ($formTableColumn->getMode() == "CHECK_EDIT"){
                    if ($formTableColumn->getReadonly() == "N")
                        $existEdit = true;
                        
                    $checkItem = $formTableColumn->getItems()[0];
                    
                    $check = new prHtmlCheck($updID, $value, ($value == $checkItem->getValue()));
                    
                    if ($formTableColumn->getReadOnly() == "Y")
                        $check->setDisabled();
                        
                        $check->setBubbleText($formTableColumn->getComment());
                        if ($formTableColumn->getReadOnly() == "Y")
                            $check->setDisabled();
                            $coldetl = $table2->addRowCell($check->publish());
                } else { // VIEW
                    if ($value == null){
                        $coldetl = $table2->addRowCell(getDefaultValue($formTableColumn->getDefaultValue()))->setValignCentered();
                    } else {
                        $value = $data[geColumnAlias($formTableColumn->getDbColumn())]; 
                        if ($formTableColumn->getDbType() == FormStructure::TYPE_DATE)
                        {
                                $value = getFormDate($value);
                        } 
                        $coldetl = $table2->addRowCell($value . " " . $labelItem)->setValignCentered();
                    }
                    $coldetl->setBubbleText($formTableColumn->getComment());
                }
                
                if ($formTableColumn->getPosition() == "center") {
                    $coldetl->setAlignCentered();
                } elseif ($formTableColumn->getPosition() == "right") {
                    $coldetl->setAlignRight();
                }
                
                $coldetl->setFontSize($this->fontSize);
                $coldetl->setWidth($formTableColumn->getSize() * 5);
                
            }
            if ($formTable->getDetail_flag()){  
                //Povoleno tlačítko detail
                $detailKeyName = "#Detailrow". $row_num."_#_".$dbTable."_#_".$formTable->getDb_primary_key()."_#_".$this->area."_#_".$formTable->getTableID();
                $table2->addRowCell($this->formInsertAction->publishSendButtonNamedImage(self::ACTION_GOTO_DETIAL,
                    $detailKeyName . "_#_". $key_code, "Zobrazit detail", "./_img/small/edit.png"))->setValignCentered()->setNoWrap(true);
            }
           
            if ($formTable->getDelete_row_flag()){      
                //Povoleno mazání řádek tabulky
                $checkDel = new prHtmlCheck(getEditUpdName("#delrow", $row_num."_#_".$dbTable."_#_".$formTable->getDb_primary_key()), $key_code, false);
                $checkDel->setBubbleText("Označit ke smazání");
                $table2->addRowCell("<img src='./_img/small/cross.png'>".$checkDel->publish())->setValignCentered()->setNoWrap(true);
            }
           
            if ($row_num >= $formTable->getLimit_row()){
                    echo "<font color=red><b>Omezeno na prvních " . $formTable->getLimit_row() . " záznamů</b></font>";
                    break;
            }
        }
        
        if ($row_num == 0 && $_SESSION["tempFlag"] == false){            
            echo "<font color=red><b>Nebyly vybráná žádna data!</b></font>";
            
        }
        
            $tableFooter = new PrHtmlTable();

            $tableFooter->setWidthPercent(100);
            $tableFooter->addRow();
            
            $deleteButton = "";
            if ($formTable->getDelete_row_flag()){      
                $deleteButton = $this->formInsertAction->publishSendButtonNamed(self::ACTION_DELETE_TABLE_ROWS, "Smazat označené");
            }
            if ($_SESSION["print"] == false) {
                if ($existEdit){
                    $tableFooter->addRowCell(
                        $this->formInsertAction->publishSendButtonNamed(self::ACTION_SAVE_LINES, "Uložit") .
                        $deleteButton)->setAlignCentered();
                        
                } else {
                    $back = '<input class="noprint" type=button onclick="history.back()" value="Zpět">';
                    $tableFooter->addRowCell($back)->setAlignCentered();
                }
            }

            $divPred =  '';
            $divPo   =  '';
                
            $table2->setTableFix($formTable->getHeight_px());
            $table2->setClass("content_table");
            
            $this->htmlTable =  $tableHead->publish() . $divPred .$table2->publish() . $divPo . "\n" .'<p>' . $tableFooter->publish() ;
    }
    
    
    /** Funkce vrací připravený SQL příkaz pro aktualizaci dat
     * @return string
     */
    public function getUpdateSQL()
    {
        return $this->updateSQL;
    }

    /**
     * Funkce vrací vytvořený HTML kód
     * @return string
     */
    public function getHtml()
    {
        return $this->htmlTable;
    }
    
    /**
     * Funkce za editovatelný text připojí poznámku (např. Kč, %, MJ atd.)
     * @return string
     */
    protected function getHTML4Label($dbType, $editText, $label) {

        $editText->setFontSize($this->fontSize);
        
        FormCore::setPattern4EditText($dbType, $editText);
        
        if ($label == null) {
            return $editText->publish();
        } else {
            $subtable = new PrHtmlTable();
            $subtable->addRow();
            $subtable->addRowCell($editText->publish())->setFontSize($this->fontSize);
            $subtable->addRowCell($label)->setFontSize($this->fontSize);
            return $subtable->publish();
        }
    }
    
}

