<?php
/**
 * @author Petr Ruttkay
 *
 */
/**
 * 
 * Třída načíta data z XML souboru s definicí jednotlivých prvků formuláře.
 * Například: "VBOX, HBOX, GRID, TABLE atd.
 */
class FormStructure {
                          
    const LAYOUT          = "LAYOUT";
    const VBOX            = "VBOX";
    const HBOX            = "HBOX";
    const TABLE           = "TABLE";
    const COLUMN          = "COLUMN";
    const NAME            = "NAME";
    const DB_TABLE        = "DB_TABLE";
    const DB_COLUMN       = "DB_COLUMN";
    const DB_REF_TABLE    = "DB_REF_TABLE";
    const DB_REF_COLUMN   = "DB_REF_COLUMN";
    const DB_TABLES_JOIN  = "DB_TABLES_JOIN";
    const DB_JOIN_ON      = "DB_JOIN_ON";
    const TYPE            = "TYPE";
    const SIZE            = "SIZE";
    const UPSIFT          = "UPSIFT";
    const POSITION        = "POSITION";
    const DEFAUL_VALUE    = "DEFAUL_VALUE";
    const COMMENT         = "COMMENT";
    const MODE            = "MODE";
    const GRID            = "GRID";
    const LABEL           = "LABEL";
    const ITEM            = "ITEM";
    const REQUIRED        = "REQUIRED";
    const READONLY        = "READONLY";
    const AREA            = "area";
    const HEAD            = "head";
    const DETL            = "detl";

    const FONT_SIZE       = "font_Size";
    const CLONE_BUTTON    = "clone_button";
    
    const COMBO           = "COMBO";
    const RADIO           = "RADIO";
    const CHECK           = "CHECK";
    const VALUE           = "VALUE";
    const TEXT            = "TEXT";
    const C_ITEM          = "C_ITEM";
    const CHECKED         = "checked";
    const R_ITEM          = "R_ITEM";
    const WHERE_TEXT      = "WHERE_TEXT";
    
    const TYPE_INTEGER = "integer";
    const TYPE_SMALLINT = "smallint";
    const TYPE_DECIMAL2 = "decimal2";
    const TYPE_DECIMAL = "decimal";
    const TYPE_INT  = "int";
    const TYPE_DEC2 = "dec2";
    const TYPE_DEC  = "dec";
    const TYPE_TEXT = "char";
    const TYPE_DATE = "date";
    const TYPE_DATETIME = "datetime";
   
    
    private $formID;
    private $formTitle;
    private $formLayout;
    private $directFillData;
    private $showButton = false;
    
    public function __construct($xmlFile) {
        
        
        $data = new XMLReader();
         
        $data->open($xmlFile);
       
        while($data->read()) {
            switch($data->name) {
                case FormStructure::LAYOUT:
                    $this->formID = $data->getAttribute('ID');
                    $this->formTitle = $data->getAttribute('title');
                    $this->directFillData = $data->getAttribute('direct_fill_data');
                    $this->showButton = $data->getAttribute('show_button');
                    if ($this->showButton == null)
                        $this->showButton = false;
                    $this->formLayout = new FormLayout($data);
                    break;
            }
        }
        
    }

    /**
     * @return string
     */
    public function getFormID()
    {
        return $this->formID;
    }

    /**
     * @return string
     */
    public function getFormTitle()
    {
        return $this->formTitle;
    }

    /**
     * @return mixed
     */
    public function getFormLayout()
    {
        return $this->formLayout;
    }
    /**
     * @return string
     */
    public function getDirectFillData()
    {
        return $this->directFillData;
    }

    /**
     * @return boolean
     */
    public function isShowButton()
    {
//         echo "<BR>". $this->formID ." - ".$this->showButton;
        if ($this->showButton == "true") {
            return true;
        } elseif ($this->showButton == "false") {
            return false;
        } else {
            return false;
        }
    }
    
    

        
}

class FormLayout {
    private $boxList = array();
    private $filter = false;
    private $showButton = false;
    
    public function __construct($data) {
        while($data->read()) {
           
            switch($data->name) {
                case FormStructure::VBOX:
                    if($data->nodeType == XMLReader::ELEMENT) {
                        $this->typeBox = FormStructure::VBOX;
                        $this->boxID = $data->getAttribute('ID');                        
                        $this->boxTitle = $data->getAttribute('title');
                        $this->filter = $data->getAttribute('filter');
                        $this->showButton = $data->getAttribute('show_button');
                        $showBox4Insert = $data->getAttribute('show_box4insert');
                        $showBox4Detail = $data->getAttribute('show_box4detail');
                        $area = $data->getAttribute(FormStructure::AREA);
                        $cloneButton = $data->getAttribute(FormStructure::CLONE_BUTTON);
                        
                        if ($this->showButton == null)
                            $this->showButton = false;
                        if ($this->filter == null)
                            $this->filter = false;
                        if ($showBox4Insert == null)
                            $showBox4Insert = true;
                        if ($showBox4Detail == null)
                            $showBox4Detail = true;
                        
                            $this->boxList[] = new FormBox($this->boxID, $this->boxTitle, $this->typeBox,
                                $this->filter, $this->showButton, $showBox4Insert, $showBox4Detail, $area, $cloneButton, $data);
                    }
                    break;
                    
                case FormStructure::HBOX:
                    if($data->nodeType == XMLReader::ELEMENT) {
                        $this->typeBox = FormStructure::HBOX;
                        $this->boxID = $data->getAttribute('ID');
                        $this->boxTitle = $data->getAttribute('title');
                        $this->filter = $data->getAttribute('filter');
                        $this->showButton = $data->getAttribute('show_button');
                        $showBox4Insert = $data->getAttribute('show_box4insert');
                        $showBox4Detail = $data->getAttribute('show_box4detail');
                        $area = $data->getAttribute(FormStructure::AREA);
                        $cloneButton = $data->getAttribute(FormStructure::CLONE_BUTTON);
                        
                        if ($this->showButton == null)
                            $this->showButton = false;
                        if ($showBox4Insert == null)
                            $showBox4Insert = true;
                        if ($showBox4Detail == null)
                            $showBox4Detail = true;
                        $this->boxList[] = new FormBox($this->boxID, $this->boxTitle, $this->typeBox, $this->filter, 
                            $this->showButton, $showBox4Insert, $showBox4Detail, $area, $cloneButton, $data);
                    }
                    break;
                case FormStructure::LAYOUT:
                    return;
            }
        }
    }
    

    /**
     * @return multitype:
     */
    public function getBoxList()
    {
        return $this->boxList;
    }
    
   
    /**
     * @return boolean
     */
    public function isShowButton()
    {
        if ($this->showButton == "true") {
            return true;
        } elseif ($this->showButton == "false") {
            return false;
        } else {
            return false;
        }
//         return $this->showButton;
    }

    public function __toString() {
        $out = array();
        foreach($this->boxList as $formBox) {
            $out[] = $formBox->__toString();
        }
        return implode("\n", $out);
    }
}

/**
 * 
 * Třída analýzuje elemnt BOX z definice formuláře v XML 
 *
 */
class FormBox {
    private $typeBox = FormStructure::VBOX;
    private $filter = false;
    private $boxID;
    private $boxTitle;
    private $showButton = false;
    private $detail_flag = false;
    private $grid_detail_flag = "N";
    private $insert_flag = "N";
    private $showBox4Insert = true;
    private $showBox4Detail = true;
    private $area;
    private $cloneButton;
    private $boxItems = array();
    


    public function __construct($boxID, $boxTitle, $typeBox, $filter, $showButton, $showBox4Insert, 
        $showBox4Detail, $area, $cloneButton, $data) {
        $this->typeBox = $typeBox;
        $this->filter = $filter;
        $this->boxID = $boxID;
        $this->boxTitle = $boxTitle;
        $this->showButton = $showButton;
        $this->showBox4Insert = $showBox4Insert;
        $this->showBox4Detail = $showBox4Detail;
        if ($area == null) $area = FormStructure::HEAD;
        $this->area = $area;
        if ($cloneButton == null) {
            $cloneButton = false;
        }
        if ($cloneButton == "true"){
            $cloneButton = true;
        } else {
            $cloneButton = false;            
        }
        $this->cloneButton = $cloneButton;
        
        while($data->read()) {
            $xxx = $data->name;
            switch($xxx) {
                case FormStructure::TABLE:
                    $this->tableID = $data->getAttribute('ID');
                    $this->db_primary_key = $data->getAttribute('db_primary_key');
                    $this->limit_row      = $data->getAttribute('limit_row');
                    $this->height_px      = $data->getAttribute('height_px');
                    $this->ins_row_flag   = ($data->getAttribute('ins_row_flag') == "true");
                    $this->delete_row_flag= ($data->getAttribute('delete_row_flag') == "true");
                    $this->detail_flag    = ($data->getAttribute('detail_flag') == "true");
                    $fontSize = $data->getAttribute(FormStructure::FONT_SIZE);
                    
                    if($data->nodeType == XMLReader::ELEMENT) {
                        $this->boxItems[] = new FormTable($this->tableID, $this->db_primary_key, 
                            $this->limit_row, $this->height_px, 
                            $this->ins_row_flag, $this->delete_row_flag, $this->detail_flag, $fontSize, $data);
                    }
                    break;
                    
                case FormStructure::GRID:
                    $this->gridID = $data->getAttribute('ID');
                    $this->db_primary_key = $data->getAttribute('db_primary_key');
                    $this->group = $data->getAttribute('group');
                    
                    $showButtonGrid = false;
                    $showButtonGrid = $data->getAttribute('show_button');
                    if ($showButtonGrid == null)
                        $showButtonGrid = false;
                        $this->grid_detail_flag = $data->getAttribute('detail_flag');
                        $this->insert_flag = $data->getAttribute('insert_flag');
                        $fontSize = $data->getAttribute(FormStructure::FONT_SIZE);
                    if($data->nodeType == XMLReader::ELEMENT) {
                        $this->boxItems[] = new FormGrid($this->gridID, $this->db_primary_key, $this->group, $showButtonGrid, 
                            $this->grid_detail_flag, $this->insert_flag, $fontSize, $data);
                    }
                    break;

                case '#text':
                    break;
                    
                case FormStructure::VBOX:
                    return;
                case FormStructure::HBOX:
                    return;
                    
                default:
                    return;
            }
        }
    }
    
    
    /**
     * @return string:
     */
    public function getTypeBox()
    {
        return $this->typeBox;
    }

    /**
     * @return multitype:
     */
    public function getBoxItems()
    {
        return $this->boxItems;
    }

    
    /**
     * @return boolean
     */
    public function getFilter()
    {
        if ($this->filter == "true") {
            return true;
        } elseif ($this->filter == "false") {
            return false;
        } else {
            return false;
        }
        
    }

    
    /**
     * @return mixed
     */
    public function getBoxID()
    {
        return $this->boxID;
    }

    /**
     * @return mixed
     */
    public function getBoxTitle()
    {
        return $this->boxTitle;
    }

    /**
     * @return boolean
     */
    public function isShowButton()
    {
        if ($this->showButton == "true") {
            
            return true;
        } elseif ($this->showButton == "false") {
            
            return false;
        } else {
            
            return false;
        }
    }
    
    /**
     * @return string
     */
    public function getArea()
    {
        return $this->area;
    }

    
    /**
     * @return boolean
     */
    public function getCloneButton()
    {
        return $this->cloneButton;
    }

    /**
     * @return boolean
     */
    public function isShowBox4Insert()
    {
        if ($this->showBox4Insert == "true") {
            return true;
        } elseif ($this->showBox4Insert == "false") {
            return false;
        } else {
            return true;
        }
    }

    /**
     * @return boolean
     */
    public function isShowBox4Detail()
    {
        if ($this->showBox4Detail == "true") {
            return true;
        } elseif ($this->showBox4Detail == "false") {
            return false;
        } else {
            return true;
        }
    }

    /**
     * @return boolean
     */
    public function getDetail_flag()
    {
        
        if ($this->detail_flag == "true") {
            return true;
        } elseif ($this->detail_flag == "false") {
            return false;
        } else {
            return false;
        }
    }
    
    /**
     * @return string
     */
    public function getGrid_detail_flag()
    {
        
        if ($this->grid_detail_flag == "Y") {
            return "Y";
        } elseif ($this->grid_detail_flag == "N") {
            return "N";
        } else {
            return "N";
        }
    }
    
    /**
     * @return string
     */
    public function getInsert_flag()
    {
        
        if ($this->insert_flag == "Y") {
            return "Y";
        } elseif ($this->insert_flag == "N") {
            return "N";
        } else {
            return "N";
        }
       
    }

    public function __toString() {
        $out = array();
        foreach($this->boxItems as $items) {
            $out[] = $items->__toString();
        }
        return implode("\n", $out);
    }
}

/**
 * 
 * Třída analýzuje elemnt TABLE z definice formuláře v XML 
 *
 */
class FormTable {
    private $columns = array();
    private $tableID;
    private $db_primary_key;
    private $limit_row=500; 
    private $height_px=400;
    private $ins_row_flag=false;
    private $delete_row_flag=false;
    private $detail_flag=false;
    private $fontSize = 12;
    
    
    public function __construct($tableID, $db_primary_key, $limit_row, $height_px, 
        $ins_row_flag, $delete_row_flag, $detail_flag, $fontSize, $data) {
        $this->tableID = $tableID;
        $this->db_primary_key = $db_primary_key;
        $this->limit_row      = $limit_row;
        $this->height_px      = $height_px; 
        $this->ins_row_flag   = $ins_row_flag; 
        $this->delete_row_flag= $delete_row_flag;
        $this->detail_flag = $detail_flag;
        $this->fontSize = $fontSize;
        
        
        while($data->read()) {
            switch($data->name) {
                case FormStructure::COLUMN:
                   
                    if($data->nodeType == XMLReader::ELEMENT) {
                        $this->columnID = $data->getAttribute('ID');
                        $this->columns[] = new FormTableColumn($this->columnID, $data);
                    }
                    break;     
                    
                case '#text':
                    break;
                    
                case FormStructure::TABLE:
                    return;
                    
            }
        }
    }
    
    
    
    /**
     * @return multitype:
     */
    public function getColumns()
    {
        return $this->columns;
    }

    
    /**
     * @return mixed
     */
    public function getTableID()
    {
        return $this->tableID;
    }

    
    /**
     * @return mixed
     */
    public function getDb_primary_key()
    {
        return $this->db_primary_key;
    }

    
    /**
     * @return number
     */
    public function getLimit_row()
    {
        return $this->limit_row;
    }

    /**
     * @return number
     */
    public function getHeight_px()
    {
        return $this->height_px;
    }

    /**
     * @return boolean
     */
    public function getIns_row_flag()
    {

        if ($this->ins_row_flag == "true") {
            return true;
        } elseif ($this->ins_row_flag == "false") {
            return false;
        } else {
            return false;
        }
    }

    /**
     * @return boolean
     */
    public function getDelete_row_flag()
    {
        
        if ($this->delete_row_flag == "true") {
            return true;
        } elseif ($this->delete_row_flag == "false") {
            return false;
        } else {
            return false;
        }
    }

    
    /**
     * @return boolean
     */
    public function getDetail_flag()
    {
        if ($this->detail_flag == "true") {
            return true;
        } elseif ($this->detail_flag == "false") {
            return false;
        } else {
            return false;
        }
    }
    
    /**
     * @return integer
     */
    public function getFontSize()
    {
        return $this->fontSize;
    }
    

    public function __toString() {
        $out = array();
        foreach($this->columns as $items) {
            $out[] = $items->__toString();
        }
        return implode("\n", $out);
    }
}

/**
 * 
 * Třída analýzuje elemnt GRID z definice formuláře v XML 
 *
 */
class FormGrid {
    private $items = array();
    private $gridID;
    private $db_primary_key;
    private $group;
    private $showButton;
    private $detail_flag;
    private $insert_flag;
    private $fontSize = 12;
    
    
    public function __construct($gridID, $db_primary_key, $group, $showButton, $detail_flag, $insert_flag, $fontSize, $data) {
        $this->gridID = $gridID;
        $this->db_primary_key = $db_primary_key;
        $this->group = $group;
        $this->showButton = $showButton;
        $this->detail_flag = $detail_flag;
        $this->insert_flag = $insert_flag;
        $this->fontSize = $fontSize;
        
        while($data->read()) {
            switch($data->name) {
                case FormStructure::ITEM:
                    
                    if($data->nodeType == XMLReader::ELEMENT) {
                        $this->itemID = $data->getAttribute('ID');
                        $this->items[] = new FormGridItem($this->itemID, $data);
                    }
                    break;
                    
                case FormStructure::LABEL:
                    if($data->nodeType == XMLReader::ELEMENT) {
                        $data->read();                        
                        $this->label = $data->value;
                        $this->items[] = strval( $this->label );
                    }
                    
                    break;
                    
                case '#text':
                    break;
                    
                case FormStructure::GRID:
                    return;
                    
            }
        }
    }

    
    /**
     * @return multitype:
     */
    public function getItems()
    {
        return $this->items;
    }

    /**
     * @return mixed
     */
    public function getGridID()
    {
        return $this->gridID;
    }
    
        /**
     * @return mixed
     */
    public function getDb_primary_key()
    {
        return $this->db_primary_key;
    }

    
    /**
     * @return mixed
     */
    public function getGroup()
    {
        return $this->group;
    }

    /**
     * @return boolean
     */
    public function isShowButton()
    {
        if ($this->showButton == "true") {
            return true;
        } elseif ($this->showButton == "false") {
            return false;
        } else {
            return false;
        }
//         return $this->showButton;
    }
    
    

    /**
     * @return mixed
     */
    public function getDetail_flag()
    {
        if ($this->detail_flag == "Y") {
            return "Y";
        } elseif ($this->detail_flag == "N") {
            return "N";
        } else {
            return "N";
        }
    }

    /**
     * @return integer
     */
    public function getFontSize()
    {
        return $this->fontSize;
    }
    /**
     * @return mixed
     */
    public function getInsert_flag()
    {
        return $this->insert_flag;
        if ($this->insert_flag == "Y") {
            return "Y";
        } elseif ($this->insert_flag == "N") {
            return "N";
        } else {
            return "N";
        }
    }

    public function __toString() {
        $out = array();
        foreach($this->items as $items) {
            $out[] = $items->__toString();
        }
        return implode("\n", $out);
    }
}

/**
 *
 * Inteface pro třídy FormGridItem a FormTableColumn
 *
 */

interface FormItem {
    
    public function parse($data);
    
    /**
     * @return mixed
     */
    public function getColumnName();
    
    /**
     * @return string
     */
    public function getDbTable();
    
    /**
     * @return string
     */
    public function getDbColumn();
    
    /**
     * @return mixed
     */
    public function getDbRefTable();
    
    /**
     * @return mixed
     */
    public function getDbRefColumn();

    /**
     * @return mixed
     */
    public function getDbTableJoin();
    
    /**
     * @return mixed
     */
    public function getDbJoinOn();
    
    /**
     * @return mixed
     */
    public function getDbType();
    
    /**
     * @return mixed
     */
    public function getSize();
    
    /**
     * @return mixed
     */
    public function getUpshift();
    
    /**
     * @return mixed
     */
    public function getPosition();
    
    
    /**
     * @return mixed
     */
    public function getDefaultValue();

    /**
     * @return mixed
     */
    public function getLabel();
    
    /**
     * @return string
     */
    public function getComment();
    
    /**
     * @return string
     */
    public function getMode();
    
    /**
     * @return mixed
     */
    public function getRequired();
   
    
    /**
     * @return mixed
     */
    public function getReadonly();
    
    /**
     * @return string
     */
    public function getComboDBTable();
    
    /**
     * @return multitype:
     */
    public function getItems();
   
   
}

/**
 *
 * Třída analýzuje elemnt ITEM z definice formuláře v XML
 *
 */

class FormGridItem implements FormItem {
    private $itemID;
    private $columnName;
    private $dbTable = null;
    private $dbColumn = null;
    private $dbRefTable = null;
    private $dbRefColumn = null;
    private $dbTableJoin = null;
    private $dbJoinOn = null;
    private $label = null;
    private $dbType;
    private $size;
    private $upshift;
    private $position;
    private $defaultValue;
    private $comment;
    private $mode;
    private $required;
    private $readonly;
    private $comboDBTable = null;
    private $items = array(); //Combo or Radio items
    
    public function __construct($itemID, $data) {
        
        $this->itemID = $itemID;
        $this->parse($data);       
        
    }
    
    public function parse($data){
        
        while($data->read()) {
            switch($data->name) {
                case FormStructure::NAME:
                    $data->read();
                    $this->columnName = $data->value;
                    $data->read();
                    break;
                    
                case FormStructure::DB_TABLE:
                    $data->read();
                    $this->dbTable = $data->value;
                    $data->read();
                    break;
                    
                case FormStructure::DB_COLUMN:
                    $data->read();
                    $this->dbColumn = $data->value;
                    $data->read();
                    break;
                    
                case FormStructure::DB_REF_TABLE:
                    $data->read();
                    $this->dbRefTable = $data->value;
                    $data->read();
                    break;
                    
                case FormStructure::DB_REF_COLUMN:
                    $data->read();
                    $this->dbRefColumn = $data->value;
                    $data->read();
                    break;
                    
                case FormStructure::DB_TABLES_JOIN:
                    $data->read();
                    $this->dbTableJoin = $data->value;
                    $data->read();
                    break;
                    
                case FormStructure::DB_JOIN_ON:
                    $data->read();
                    $this->dbJoinOn = $data->value;
                    $data->read();
                    break;

                case FormStructure::LABEL:
                    $data->read();
                    $this->label = $data->value;
                    $data->read();
                    break;
                    
                case FormStructure::TYPE:
                    $data->read();
                    $this->dbType = $data->value;
                    $data->read();
                    break;
                    
                case FormStructure::SIZE:
                    $data->read();
                    $this->size = $data->value;
                    $data->read();
                    break;
                    
                case FormStructure::UPSIFT:
                    $data->read();
                    $this->upshift = $data->value;
                    $data->read();
                    break;
                    
                case FormStructure::POSITION:
                    $data->read();
                    $this->position = $data->value;
                    $data->read();
                    break;
                    
                case FormStructure::DEFAUL_VALUE:
                    $data->read();
                    $this->defaultValue = $data->value;
                    $data->read();
                    break;
                    
                case FormStructure::MODE:
                    $data->read();
                    $this->mode = $data->value;
                    $data->read();
                    break;
                    
                case FormStructure::REQUIRED:
                    $data->read();
                    $this->required = $data->value;
                    $data->read();
                    break;
                    
                case FormStructure::READONLY:
                    $data->read();
                    $this->readonly = $data->value;
                    $data->read();
                    break;
                                 
                case FormStructure::COMMENT:
                    $data->read();
                    $this->comment = $data->value;
                    $data->read();
                    break;
                    
                case FormStructure::COMBO:
                    if($data->nodeType == XMLReader::ELEMENT) {
                        $this->comboDBTable = $data->getAttribute('db_table');
                        $formCRItems = new FormCRItems($data);
                        $this->items = $formCRItems->getItems();
                    }
                    break;
                    
                case FormStructure::RADIO:
                    if($data->nodeType == XMLReader::ELEMENT) {
                        $formCRItems = new FormCRItems($data);
                        $this->items = $formCRItems->getItems();
                    }
                    break;
                    
                case FormStructure::CHECK:
                    if($data->nodeType == XMLReader::ELEMENT) {
                        $checked = $data->getAttribute(FormStructure::CHECKED);
                        $this->items[] = new FormCRItem($checked,$data);
                    }
                    break;
                    

                case '#text':
                    break;
                    
                default:
                    return;
            }
        }
        
        
    }
    
    /**
     * @return mixed
     */
    public function getColumnName()
    {
        return $this->columnName;
    }

    /**
     * @return string
     */
    public function getDbTable()
    {
        return $this->dbTable;
    }
    
    /**
     * @return string
     */
    public function getDbColumn()
    {
        return $this->dbColumn;
    }
    
    
    /**
     * @return mixed
     */
    public function getDbRefTable()
    {
        return $this->dbRefTable;
    }

    /**
     * @return mixed
     */
    public function getDbRefColumn()
    {
        return $this->dbRefColumn;
    }

    /**
     * @return mixed
     */
    public function getDbTableJoin()
    {
        return $this->dbTableJoin;
    }
    
    /**
     * @return mixed
     */
    public function getDbJoinOn()
    {
        return $this->dbJoinOn;
    }
    
    /**
     * @return mixed
     */
    public function getLabel()
    {
        return $this->label;
    }

    /**
     * @return mixed
     */
    public function getDbType()
    {
        return $this->dbType;
    }
    
    /**
     * @return mixed
     */
    public function getSize()
    {
        return $this->size;
    }
    
    /**
     * @return mixed
     */
    public function getUpshift()
    {
        return $this->upshift;
    }
    
    /**
     * @return mixed
     */
    public function getPosition()
    {
        return $this->position;
    }
    
    /**
     * @return mixed
     */
    public function getDefaultValue()
    {
        return $this->defaultValue;
    }
    
    
    /**
     * @return string
     */
    public function getComment()
    {
        return $this->comment;
    }

    /**
     * @return string
     */
    public function getMode()
    {
        return $this->mode;
    }
    
    
    
    /**
     * @return mixed
     */
    public function getRequired()
    {
        return $this->required;
    }

    /**
     * @return mixed
     */
    public function getReadonly()
    {
        return $this->readonly;
    }

    /**
     * @return mixed
     */
    public function getItemID()
    {
        return $this->itemID;
    }

    
    
    /**
     * @return string
     */
    public function getComboDBTable()
    {
        return $this->comboDBTable;
    }

    /**
     * @return multitype:
     */
    public function getItems()
    {
        return $this->items;
    }

    public function __toString() {
        //         echo "<BR>db_host ", $this->db_host,"<BR>db_user ", $this->db_user,
        //         "<BR>db_pwd ", $this->db_pwd, "<BR>database ", $this->database;
        return sprintf("%-20s %2d %10s", $this->columnName, $this->dbTable, $this->dbColumn);
    }
    
}

/**
 *
 * Třída analýzuje elemnt COLUMN z definice formuláře v XML
 *
 */

class FormTableColumn implements FormItem {
    private $columnID;
    private $columnName;
    private $dbTable = null;
    private $dbColumn = null;
    private $dbRefTable = null;
    private $dbRefColumn = null;
    private $dbTableJoin = null;
    private $dbJoinOn = null;
    private $label = null;
    private $dbType;
    private $size;
    private $upshift;
    private $position;
    private $defaultValue;
    private $comment;
    private $mode;
    private $required;
    private $readonly;
    private $comboDBTable = null;
    private $items = array(); //Combo or Radio items
    
    public function __construct($columnID, $data) {
        $this->columnID = $columnID;        
        $this->parse($data);
        
    }
    
    public function parse($data){
        
       
        
        while($data->read()) {
            switch($data->name) {
                case FormStructure::NAME:
                    $data->read();
                    $this->columnName = $data->value;
                    $data->read();
                    break;
                    
                case FormStructure::DB_TABLE:
                    $data->read();
                    $this->dbTable = $data->value;
                    $data->read();
                    break;
                    
                case FormStructure::DB_COLUMN:
                    $data->read();
                    $this->dbColumn = $data->value;
                    $data->read();
                    break;
                    
                case FormStructure::DB_REF_TABLE:
                    $data->read();
                    $this->dbRefTable = $data->value;
                    $data->read();
                    break;
                    
                case FormStructure::DB_REF_COLUMN:
                    $data->read();
                    $this->dbRefColumn = $data->value;
                    $data->read();
                    break;

                case FormStructure::DB_TABLES_JOIN:
                    $data->read();
                    $this->dbTableJoin = $data->value;
                    $data->read();
                    break;

                case FormStructure::DB_JOIN_ON:
                    $data->read();
                    $this->dbJoinOn = $data->value;
                    $data->read();
                    break;
                    
                case FormStructure::LABEL:
                    $data->read();
                    $this->label = $data->value;
                    $data->read();
                    break;
                    
                case FormStructure::TYPE:
                    $data->read();
                    $this->dbType = $data->value;
                    $data->read();
                    break;
                    
                case FormStructure::SIZE:
                    $data->read();
                    $this->size = $data->value;
                    $data->read();
                    break;
                    
                case FormStructure::UPSIFT:
                    $data->read();
                    $this->upshift = $data->value;
                    $data->read();
                    break;
                    
                case FormStructure::POSITION:
                    $data->read();
                    $this->position = $data->value;
                    $data->read();
                    break;
                    
                case FormStructure::DEFAUL_VALUE:
                    $data->read();
                    $this->defaultValue = $data->value;
                    $data->read();
                    break;
                    
                case FormStructure::MODE:
                    $data->read();
                    $this->mode = $data->value;
                    $data->read();
                    break;
                    
                case FormStructure::REQUIRED:
                    $data->read();
                    $this->required = $data->value;
                    $data->read();
                    break;
                    
                case FormStructure::READONLY:
                    $data->read();
                    $this->readonly = $data->value;
                    $data->read();
                    break;
                    
                case FormStructure::COMMENT:
                    $data->read();
                    $this->comment = $data->value;
                    $data->read();
                    break;
                    
                case FormStructure::COMBO:
                    if($data->nodeType == XMLReader::ELEMENT) {
                        $this->comboDBTable = $data->getAttribute('db_table');
                        $formCRItems = new FormCRItems($data);
                        $this->items = $formCRItems->getItems();
                    }
                    break;
                    
                case FormStructure::RADIO:
                    if($data->nodeType == XMLReader::ELEMENT) {
                        $formCRItems = new FormCRItems($data);
                        $this->items = $formCRItems->getItems();
                    }
                    break;
                    
                case FormStructure::CHECK:
                    if($data->nodeType == XMLReader::ELEMENT) {
                        $checked = $data->getAttribute('checked');
                        $this->items[] = new FormCRItem($checked, $data);
                    }
                    break;
                    
                case '#text':
                    break;
                    
                default:
                    return;
            }
        }
        
        
    }
   
    /**
     * @return mixed
     */
    public function getRequired()
    {
        return $this->required;
    }

    /**
     * @return mixed
     */
    public function getReadonly()
    {
        return $this->readonly;
    }

    /**
     * @return string
     */
    public function getColumnName()
    {
        return $this->columnName;
    }

    /**
     * @return string
     */
    public function getDbTable()
    {
        return $this->dbTable;
    }

    
    /**
     * @return mixed
     */
    public function getDbRefTable()
    {
        return $this->dbRefTable;
    }

    /**
     * @return mixed
     */
    public function getDbRefColumn()
    {
        return $this->dbRefColumn;
    }

    
    /**
     * @return mixed
     */
    public function getDbTableJoin()
    {
        return $this->dbTableJoin;
    }

    /**
     * @return mixed
     */
    public function getDbJoinOn()
    {
        return $this->dbJoinOn;
    }

    
    /**
     * @return mixed
     */
    public function getLabel()
    {
        return $this->label;
    }

    /**
     * @return string
     */
    public function getDbColumn()
    {
        return $this->dbColumn;
    }

    /**
     * @return mixed
     */
    public function getDbType()
    {
        return $this->dbType;
    }

    /**
     * @return mixed
     */
    public function getSize()
    {
        return $this->size;
    }

    /**
     * @return mixed
     */
    public function getUpshift()
    {
        return $this->upshift;
    }

    /**
     * @return mixed
     */
    public function getPosition()
    {
        return $this->position;
    }

    /**
     * @return string
     */
    public function getDefaultValue()
    {
        return $this->defaultValue;
    }

    /**
     * @return string
     */
    public function getComment()
    {
        return $this->comment;
    }
    
    /**
     * @return string
     */
    public function getMode()
    {
        return $this->mode;
    }
    
    
    /**
     * @return mixed
     */
    public function getColumnID()
    {
        return $this->columnID;
    }

    
    
    /**
     * @return string
     */
    public function getComboDBTable()
    {
        return $this->comboDBTable;
    }

    /**
     * @return multitype:
     */
    public function getItems()
    {
        return $this->items;
    }

    public function __toString() {
        return sprintf("%-20s %2d %10s", $this->columnName, $this->dbTable, $this->dbColumn);
    }
}

/**
 *
 * Třída analýzuje elemnt COMBO, RADIO nebo CHECK položka radio butonu z definice formuláře v XML
 *
 */
class FormCRItems {
    private $items = array();
    
    
    public function __construct($data) {
        
        while($data->read()) {
            switch($data->name) {
                case FormStructure::R_ITEM:
                    
                    if($data->nodeType == XMLReader::ELEMENT) {
                        $checked = $data->getAttribute('checked');
                        $this->items[] = new FormCRItem($checked, $data);
                    }
                    break;
                    
                case FormStructure::C_ITEM:
                    
                    if($data->nodeType == XMLReader::ELEMENT) {
                        $checked = $data->getAttribute('checked');
                        $this->items[] = new FormCRItem($checked, $data);
                    }
                    break;
                case '#text':
                    break;
                    
                case FormStructure::COMBO:
                    return;
                case FormStructure::RADIO:
                    return;
            }
        }
    }
    
    
    /**
     * @return multitype:
     */
    public function getItems()
    {
        return $this->items;
    }
    
       
    public function __toString() {
        $out = array();
        foreach($this->items as $items) {
            $out[] = $items->__toString();
        }
        return implode("\n", $out);
    }
}

/**
 *
 * Třída analýzuje elemnt C_ITEM (položka comba) z definice formuláře v XML
 *
 */

class FormCRItem{
    
    private $checked = false;
    private $value;
    private $text;
    private $whereText;
    
    public function __construct($checked, $data) {
        $this->checked = $checked;
        $this->parse($data);
        
    }
    
    public function parse($data){
        
        while($data->read()) {
            switch($data->name) {
                case FormStructure::VALUE:
                    $data->read();
                    $this->value = $data->value;
                    $data->read();
                    break;
                    
                case FormStructure::TEXT:
                    $data->read();
                    $this->text = $data->value;
                    $data->read();
                    break;
                    
                case FormStructure::WHERE_TEXT:
                    $data->read();
                    $this->whereText = $data->value;
                    $data->read();
                    break;
                case '#text':
                    break;
                    
                default:
                    return;
            }
        }
        
        
    }
    
    /**
     * @return boolean
     */
    public function getChecked()
    {
        return $this->checked;
    }

    /**
     * @return string
     */
    public function getValue()
    {
        return $this->value;
    }

    /**
     * @return string
     */
    public function getText()
    {
        return $this->text;
    }

    
    /**
     * @return string
     */
    public function getWhereText()
    {
        return $this->whereText;
    }

    public function __toString() {
        return sprintf("%-20s %2d %10s", $this->value, $this->text, $this->checked);
    }
    
}
