<?php
/**
 * @author Petr Ruttkay
 *
 */

require_once "./_class/prHtmlCore.php";
require_once "./_class/prHtmlTable.php";

/**
 * 
 * Třída je určená prácí z databázi informačního systému pomocí PDO 
 *
 */

class isPdo extends PDO
{
    private $namedParams = array ();
    private $debugFlag = false;
    private $debugOnce = false;
    private $fetchNumFlag = false;
    
    private $notfound_flag = false;
    
    
    public function __construct($host, $port, $dbname, $user, $pass)
    {
        $this->engine = 'mysql';
        
        if ($port == null) {
            $dsn_config = array ('host'=>$host, 'dbname'=>$dbname);
        } else {
            $dsn_config = array ('host'=>$host,'port'=>$port,'dbname'=>$dbname);
        }
        
        
        $db_config = array ('driver'=>'mysql','user'=>$user,'password'=>$pass);
        
        $dsn = $db_config['driver'] . ':';
        
        foreach ($dsn_config as $key => $value)
        {
            $dsn .= $key . '=' . $value . ';';
        }
        
        try
        {
            
            
            // ATTR_TIMEOUT in seconds
            parent::__construct($dsn, $db_config['user'], $db_config['password'], array (PDO::ATTR_TIMEOUT=>5,PDO::ATTR_ERRMODE=>PDO::ERRMODE_EXCEPTION));
        }
        catch (PDOException $e)
        {
            throw $e;
        } 
    }
    
    
    public function isNotFound()
    {
        return $this->notfound_flag;
    }
    
    
    public function setDebugOn()
    {
        $this->debugFlag = true;
    }
    
    
    public function setDebugOnce()
    {
        $this->debugOnce = true;
    }
    
    
    public function setDebugOff()
    {
        $this->debugFlag = false;
    }
    
    
    public function setEncodingUTF8()
    {
        $this->query("set client_encoding='UTF-8'");
    }
    
    
    public function setEncoding1250()
    {
        $this->query("set client_encoding='Win-1250'");
    }
    
    
    /**
     * Funkce provádí dotaz do DB zaslaný parametrem sql. Pokud dojde k chybé zobrazí strukturované chybové hlášení 
     * {@inheritDoc}
     * @see PDO::query()
     */
    public function query($sql)
    {
        $this->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
        
        try
        {
            $stmt = parent::prepare($sql);
            
            if ($stmt === false)
            {
                throw new Exception('SQL error: ' . $sql);
            }
            else
            {
                if ($this->fetchNumFlag)
                {
                    $stmt->setFetchMode(PDO::FETCH_NUM);
                    $this->fetchNumFlag = false;
                }
                else
                {
                    $stmt->setFetchMode(PDO::FETCH_ASSOC);
                }
                
                $stmt->execute($this->namedParams);
                
                if ($this->debugFlag || $this->debugOnce)
                {
                    $this->showInfo($sql, null);
                }
                
                $this->namedParams = array ();
                
                return $stmt;
            }
        }
        catch (Exception $e)
        {
            $this->showInfo($sql, $e);
            die();
        }
    }
    
    /**
     * Funkce nastavý dynamické parametry pro DQL příkaz.
     * @param string $name
     * @param string $value
     */
    public function setNamedParam($name, $value)
    {
        if (substr($name, 0, 1) != ":") $name = ":" . $name;
        
        $this->namedParams[$name] = trim($value);
    }
    
    /**
     * Funkce provádí SQL příkaz (např. insert nebo update atd). Pokud dojde k chybé zobrazí strukturované chybové hlášení
     * {@inheritDoc}
     * @see PDO::query()
     */
    
    public function execute(PDOStatement $sth)
    {
        $this->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
        
        try
        {
            $sth->execute();
        }
        catch (Exception $e)
        {
            $this->showInfo(null, $e);
            die();
        }
    }
    
    
    // FETCH_NUM - vrací výsledek jako pole s číselným indexem (0.1.2 ..)
    public function query_num($sql)
    {
        $this->fetchNumFlag = true;
        $this->query($sql);
    }
    
    
    public function exec($sql)
    {
        $result = $this->execParams($sql, $this->namedParams);
        
        if ($this->debugFlag || $this->debugOnce)
        {
            $this->showInfo($sql, null);
        }
        
        $this->namedParams = array ();
        
        return $result;
    }
    
    
    public function execParams($sql, $params)
    {
        $affected = false;
        
        $this->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
        
        try
        {
            $stm = $this->prepare($sql);
            $stm_result = $stm->execute($params);
            
            if ($stm && $stm_result)
            {
                $affected = $stm->rowCount();
                
            }
            else
            {
                $this->showInfo($sql, null);
                die();
            }
            
            if ($affected === false)
            {
                throw new Exception('SQL error: ' . $sql);
            }
            else
            {
                return $affected;
            }
        }
        catch (Exception $e)
        {
            $this->showInfo($sql, $e);
            die();
        }
    }
    
    
    public function fetchRow($sql)
    {
        $stmt = $this->query($sql);
        
        $row = $stmt->fetch();
        
        if ($row === false)
        {
            $this->notfound_flag = true;
            return null;
        }
        
        if ($stmt->fetchColumn() !== false)
        {
            echo '<p>Neunikátní výsledek dotazu';
            $this->showInfo($sql, null);
            die();
        }
        
        $this->notfound_flag = false;
        
        return $row;
    }
    
    
    public function fetchValue($sql)
    {
        $stmt = $this->query($sql);
        
        $value = $stmt->fetchColumn();
        
        if ($value === false)
        {
            $this->notfound_flag = true;
            return null;
        }
        
        if ($stmt->fetchColumn() !== false)
        {
            echo '<p>Neunikátní výsledek dotazu';
            $this->showInfo($sql, null);
            die();
        }
        
        $this->notfound_flag = false;
        
        return $value;
    }
    
    
    public function beginTransaction()
    {
        parent::beginTransaction();
    }
    
    
    public function rollbackTransaction()
    {
        parent::rollback();
    }
    
    
    public function commitTransaction()
    {
        parent::commit();
    }
    
    
    /**
     * Funkce zobrazí v tabulce cgybovou zprávu a StackTrace
     * @param string $sql
     * @param $exception
     */
    private function showInfo($sql, $exception)
    {
        $table = new PrHtmlTable();
        $table->setWidthPercent(80);
        $table->setBorder(1);
        $table->setSpacing(0);
        
        if ($exception != null)
        {
            $table->setHeaderBgColor(prColors::LIGHT_PINK);
            $table->addHeaderCell("SQL error")->setColSpan(2);
        }
        else
        {
            $table->setHeaderBgColor(prColors::GREEN_1);
            $table->addHeaderCell("SQL OK")->setColSpan(2);
        }
        
        if ($sql != null)
        {
            
            if ($this->namedParams != null)
            {
                
                foreach ($this->namedParams as $key => $value)
                {
                    $sql = str_replace($key, "'" . $value . "'", $sql);
                }
            }
            
            $sql = str_replace(" from ", "<br>from ", $sql);
            $sql = str_replace(" where ", "<br>where ", $sql);
            $sql = str_replace(" order ", "<br>order ", $sql);
            $sql = str_replace(" group by ", "<br>group by ", $sql);
            
            $table->addRow();
            $table->addRowCell('Query:')->setAlignRight();
            $table->addRowCell($sql);
        }
        
        if ($exception != null)
        {
            $table->addRow();
            $table->addRowCell('Exception:')->setAlignRight();
            $table->addRowCell($exception->getMessage());
        }
        
        $table->addRow();
        $table->addRowCell('StackTrace:')->setAlignRight()->setWidth(100);
        if ($exception != null)
        {
            $table->addRowCell(PrHtmlCore::publishStackTrace($exception->getTrace()));
        }
        else
        {
            $table->addRowCell(PrHtmlCore::publishStackTraceSkip(debug_backtrace(), 1));
        }
        
        echo '<p>' . $table->publish();
        
        $this->debugOnce = false;
    }
    
}

