<?php
/**
 * @author Petr Ruttkay
 *
 */
/**
 * Třída pro prvek Combo
 *
 */

class prHtmlCombo
{
   private $name = null;
   private $options = array ();
   private $required = false;
   private $disabled = false;
   private $onChange = null;
   private $fontSize = null;

   public function __construct($name)
   {
      $this->name = $name;
   }


   public function setName($name)
   {
      $this->name = $name;
   }


   public function setRequired($required)
   {
      $this->required = $required;
   }


   public function setDisabled()
   {
      $this->disabled = true;
   }


   public function onChange($onChangeScript)
   {
      $this->onChange = $onChangeScript;
   }


   public function addOption($optionValue, $optionText, $optionSelected)
   {
      $optionValue = trim($optionValue);
      $option = array ("value"=>$optionValue,"text"=>$optionText,"selected"=>$optionSelected);
      $this->options[] = $option;
   }


   public function sortOptions()
   {
      uasort($this->options, 'sortFunc');
   }


   public function getCnt()
   {
      return count($this->options);
   }


   public function setSelectedValue($value)
   {
      $value = trim($value);
      
      foreach ($this->options as &$option)
      {
         if ($option["value"] == $value)
         {
            $option["selected"] = true;
         }
         else
         {
            $option["selected"] = false;
         }
      }
   }

   function setFontSize($size)
   {
       $this->fontSize = $size;
       return $this;
   }
   

   public function getDesc($value)
   {
      foreach ($this->options as $option)
      {
         if (trim($option["value"]) == trim($value))
         {
            return trim($option["text"]);
         }
      }
   }


   public function publish()
   {
      if (strlen($this->name) == 0)
      {
         throw new Exception('prHtmlCombo: Name of combo must not be null');
      }
      
      $style = "";
      if ($this->fontSize != null) {
          $style = "STYLE= \"font-size : ".$this->fontSize."px\"";
      }
      $outHtml = "\n<select name=\"" . $this->name . "\" id=\"" . $this->name . "\" " . $style;
      
      if ($this->required)
      {
         $outHtml .= ' required';
      }
      
      if ($this->disabled)
      {
         $outHtml .= ' disabled';
      }
      
      if ($this->onChange != null)
      {
         $outHtml .= " onChange=\"" . $this->onChange . "\"";
      }
      //style=" height: 100%;"><div style="font-weight: bold;  "
          
      $outHtml .= ' style=font-size: 22px; >'; // size=1
                       
      // options
      foreach ($this->options as $option)
      {
         $outHtml .= '<option value="' . trim($option["value"]) . '"';
         if ($option["selected"])
         {
            $outHtml .= " selected";
         }
         $outHtml .= '>' . trim($option["text"]) . '</option>';
      }
      
      $outHtml .= '</select>';
      
      return $outHtml;
   }


   public function addListFromDB($pdo, $sql, $col_code, $col_desc, $col_desc_opt, $optionSelectedValue)
   {
      if (strpos($sql, "order by") <= 0)
      {
         $sql .= " order by " . $col_code;
      }
      
      // echo '<p>SQL=' . $sql;
      
      foreach ($pdo->query($sql) as $data)
      {
         $data[$col_code] = trim($data[$col_code]);
         
         if ($data[$col_code] == trim($optionSelectedValue))
         {
            $optionSelected = true;
         }
         else
         {
            $optionSelected = false;
         }
         
         $optionText = $data[$col_desc];
         if (strlen($col_desc_opt) > 0)
         {
            $optionText .= ' - ' . $data[$col_desc_opt];
         }
         
         $this->addOption($data[$col_code], $optionText, $optionSelected);
      }
   }


   public function addListFromStmt($stmt, $col_code, $col_desc, $col_desc_opt, $optionSelectedValue)
   {
      foreach ($stmt as $data)
      {
         $data[$col_code] = trim($data[$col_code]);
         
         if ($data[$col_code] == trim($optionSelectedValue))
         {
            $optionSelected = true;
         }
         else
         {
            $optionSelected = false;
         }
         
         $optionText = $data[$col_desc];
         if (strlen($col_desc_opt) > 0)
         {
            $optionText .= ' - ' . $data[$col_desc_opt];
         }
         
         $this->addOption($data[$col_code], $optionText, $optionSelected);
      }
   }


   // vlozi volbu nevybréno na začátek seznamu
   public function addOptionNone()
   {
      $option = array ("value"=>"","text"=>"-","selected"=>false);
      array_unshift($this->options, $option);
   }


   // vlozi volbu vše na zčátek seznamu
   public function addOptionAll()
   {
      $option = array ("value"=>"*","text"=>"-vše-","selected"=>false);
      array_unshift($this->options, $option);
   }

}


function sortFunc($va1, $val2)
{
   // echo 'sort ', $val1["text"], ' > ' . $val2["text"];
   return (trim($val1["text"]) > trim($val2["text"]));
}