<?php
/**
 * @author Petr Ruttkay
 *
 */


require_once "./_class/prColors.php";

/**
 * Třída na vytvoření začátku a konce fieldset (skupiny). 
 * Tag <fieldset> slouží k seskupení souvisejících polí ve formuláři. Díky němu může vypadat formulář přehledněji.
 */
class PrHtmlFieldset
{
   private $legendColorText = prColors::FIELDSET_LEGEND_TEXT_DEFAULT;
   private $legendColorBg = prColors::FIELDSET_LEGEND_BG_DEFAULT;
   private $fieldSetColorText = prColors::BLACK;
   private $fieldSetColorBg = prColors::WHITE;
   private $widthPercent = 0;
   private $packedWidthFlag = false;
   private $noPrintFlag = false;


   public function __construct()
   {
   }


   public function setPackedWidth()
   {
      $this->packedWidthFlag = true;
   }


   public function setLegendColorText($color)
   {
      $this->legendColorText = $color;
   }


   public function setLegendColorBg($color)
   {
      $this->legendColorBg = $color;
   }


   public function setFieldsetColorText($color)
   {
      $this->fieldSetColorText = $color;
   }


   public function setFieldsetColorBg($color)
   {
      $this->fieldSetColorBg = $color;
   }


   public function setWidthPercent($widthPercent)
   {
      $this->widthPercent = $widthPercent;
   }


   public function publishStart($title)
   {
      $outHtml = '<fieldset';
      
      if ($this->noPrintFlag)
      {
         $outHtml .= ' class="noprint"';
      }
      
      $outHtml .= ' style="border: 0.5px solid grey;' . ' border-radius: 6px;' .
          ' -webkit-border-radius: 6px; height: 100%; ';
      
      if ($this->widthPercent > 0)
      {
         // velka hodnota zpusobuje prekryti sousednich skupin
         $outHtml .= ' width: ' . $this->widthPercent . '%;';
      }
      
      $outHtml .= ' padding-top: 6px; padding-left: 9px; color: ' .
          $this->fieldSetColorText . '; background-color: ' .
          $this->fieldSetColorBg;
      
      if ($this->packedWidthFlag)
      {
         $outHtml .= '; display:inline-block;';
      }
      
      $outHtml .= '">';
      
      $outHtml .= '<legend style="' . ' border: 0.5px solid grey;' .
          ' border-radius: 3px;' . ' -webkit-border-radius: 3px;' .
          ' padding: 0.1em 0.5em;' . ' color: ' . $this->legendColorText . ';' .
          ' background-color: ' . $this->legendColorBg . ';">';
      
      $outHtml .= $title . '</legend>';
      
      return $outHtml;
   }


   public function publishEnd()
   {
      $outHtml = '</fieldset>';
      
      return $outHtml;
   }


   function setNoPrint()
   {
      $this->noPrintFlag = true;
   }

}
