<?php
/**
 * @author Petr Ruttkay
 *
 */

require_once "./_class/prHtmlTableCell.php";
require_once "./_class/prHtmlTableRow.php";

/**
 * 
 * Třída vytvaří HTML tabulku
 */
class PrHtmlTable
{
   const ALIGN_LEFT = 'left';
   const ALIGN_CENTER = 'center';
   const ALIGN_RIGHT = 'right';
   const VALIGN_TOP = 'top';
   const VALIGN_CENTER = 'middle';
   const VALIGN_BOTTOM = 'bottom';
   private $id = "";
   private $headerPublished = false;
   private $flushedFlag = false;
   private $border = 0;
   private $spacing = 1;
   private $padding = 3;
   private $headerBgColor = null;
   private $headerTextBold = true;
   private $rowBgColor = null;
   private $rowBgColorOdd = null;
   private $rowBgColorEven = null;
   private $headerCells = array ();
   private $tableRows = array ();
   private $tictac = 0;
   private $lastCell = null;
   private $colCnt = 0;
   private $autoNextRow = 0;
   private $current_row_no = 0;
   private $current_column_no = 0;
   private $widthPercent = 0;
   private $widthPixels = 0;
   private $borderAround = false;
   private $borderAroundPadding = 0;
   private $rowUnderline = false;
   private $rowIdFlag = false;
   private $noPrintFlag = false;
   private $pageBreakAvoid = false;
   private $onClickCmd = null;
   private $className = null;
   private $tableFix = null;


   public function __construct()
   {
      $this->id = uniqid();
   }


   function setId($id)
   {
      $this->id = $id;
   }


   function getId()
   {
      return $this->id;
   }


   /**
    *
    * @return PrHtmlTableCell
    */
   function addHeaderCell($cellText)
   {
      $newCell = new PrHtmlTableCell($this, $cellText);
      $newCell->setNoWrap(true);
      $newCell->setValignBottom();
      $this->headerCells[] = $newCell;
      return $newCell;
   }


   function addHeaderCellX($colno, $cellText)
   {
      echo 'function PrHtmlTable.addHeaderCellX not implemented';
      die();
   }


   function setBorderAround($borderAroundPadding)
   {
      $this->borderAround = true;
      $this->borderAroundPadding = $borderAroundPadding;
   }


   function setRowUnderline()
   {
      $this->rowUnderline = true;
   }


   function isRowUnderline()
   {
      return $this->rowUnderline;
   }


   // nastaveni priznaku pro generov�n� ID ��dek tabulky
   function setRowIdFlag()
   {
      $this->rowIdFlag = true;
   }


   function isRowIdFlag()
   {
      return $this->rowIdFlag;
   }


   /**
    *
    * @return PrHtmlTableCell
    */
   function addRowCell($cellText)
   {
      if ($this->autoNextRow > 0)
      {
         if ($this->current_row_no == 0 || $this->current_column_no > $this->autoNextRow)
         {
            $this->addRow();
         }
      }
      
      if ($newCell = $this->getLastRow() == null)
      {
         $this->addRow();
      }
      
      $newCell = $this->getLastRow()->addRowCell($cellText);
      $this->lastCell = $newCell;
      $this->current_column_no++;
      
      
      return $newCell;
   }


   /**
    *
    * @return PrHtmlTableCell
    */
   function addRowCellX($colno, $cellText)
   {
      $save_curr = $this->current_column_no;
      while ($this->current_column_no < $colno)
      {
         $this->addRowCell('');
      }
      return $this->addRowCell($cellText);
   }


   /**
    *
    * @return PrHtmlTableCell
    */
   function addRowCellXY($rowno, $colno, $cellText)
   {
   }


   function appendToCell($cellText)
   {
      if (!isset($this->lastCell))
      {
         echo PrHtmlCore::publishStackTrace(debug_backtrace());
         die();
      }
      $this->lastCell->appendText($cellText);
   }


   /**
    *
    * @return PrHtmlTableRow
    */
   function addRow()
   {
      
      // doplneni chybejicich poli na konec radky
      if ($this->colCnt > 0 && $this->current_row_no > 0)
      {
         if (isset($this->tableRows[$this->current_row_no - 1]))
         {
            $this->tableRows[$this->current_row_no - 1]->addLastEmptyCells($this->colCnt);
         }
      }
      
      
      $this->current_row_no++;
      $this->current_column_no = 1;
      
      $newRow = new PrHtmlTableRow($this, $this->current_row_no);
      
      if ($this->rowBgColorEven == null || $this->rowBgColorOdd == null)
      {
         $newRow->setRowBgColor($this->rowBgColor);
      }
      else
      {
         if ($this->tictac == 0)
         {
            $newRow->setRowBgColor($this->rowBgColorOdd);
            $this->tictac = 1;
         }
         else
         {
            $newRow->setRowBgColor($this->rowBgColorEven);
            $this->tictac = 0;
         }
      }
      
      // po smazani posledni radky muze zustat prazdny zaznam na konci
      if (count($this->tableRows) > 0 && empty($this->tableRows[count($this->tableRows) - 1]))
      {
         $this->tableRows[count($this->tableRows) - 1] = $newRow;
      }
      else
      {
         $this->tableRows[count($this->tableRows)] = $newRow;
      }
      
      return $newRow;
   }


   function removeActiveRow()
   {
      unset($this->tableRows[count($this->tableRows) - 1]);
      
      if ($this->tictac == 0)
      {
         $this->tictac = 1;
      }
      else
      {
         $this->tictac = 0;
      }
      
      $this->current_row_no--;
   }


   function setBorder($border)
   {
      $this->border = $border;
   }


   function setColCnt($colCnt)
   {
      $this->colCnt = $colCnt;
   }


   function setHeaderBgColor($bgColor)
   {
      $this->headerBgColor = $bgColor;
   }


   function setRowBgColor($bgColor)
   {
      $this->rowBgColor = $bgColor;
   }


   function setRowBgColorTwin($bgColorOdd, $bgColorEven)
   {
      $this->rowBgColorOdd = $bgColorOdd;
      $this->rowBgColorEven = $bgColorEven;
   }


   function setRowCellSpan($colSpan, $rowSpan)
   {
   }


   function setSpacing($spacing)
   {
      $this->spacing = $spacing;
   }


   function setPadding($padding)
   {
      $this->padding = $padding;
   }


   function setAutoNextRow($autoNextRow)
   {
      $this->autoNextRow = $autoNextRow;
   }


   function setHeaderTextBold($boldFlag)
   {
      $this->headerTextBold = $boldFlag;
   }


   function setWidth($widthPixels)
   {
      $this->widthPixels = $widthPixels;
   }


   function setWidthPercent($widthPercent)
   {
      $this->widthPercent = $widthPercent;
   }


   /**
    *
    * @return int
    */
   function getRowsCnt()
   {
      return count($this->tableRows);
   }


   function getLastCell()
   {
      return $this->lastCell;
   }


   /**
    *
    * @return PrHtmlTableRow
    */
   function getLastRow()
   {
      $last_index = count($this->tableRows) - 1;
      while (empty($this->tableRows[$last_index]))
      {
         if ($last_index > 0)
         {
            $last_index--;
         }
         else
         {
            return null;
         }
      }
      return $this->tableRows[$last_index];
   }


   function getColToEndCnt()
   {
      return $this->colCnt - $this->current_column_no;
   }


   function publishFlush()
   {
      $outHtml = '';
      $style = '';
      
      if ($this->tableFix != null){
          //Tabulka s fixní velikosti
          $outHtml .= '<div class="tableFix' . $this->tableFix . '">' . "\n";
      }
      
      
      // hlavicka tabulky ?
      if ($this->headerPublished === false)
      {         
         $this->headerPublished = true;
         
         $outHtml .= "\n";
         $outHtml .= "\n";
         $outHtml .= '<table id="' . $this->id . '"';
         
         if ($this->widthPixels > 0)
         {
            $outHtml .= ' width=' . $this->widthPixels;
         }
         
         if ($this->widthPercent > 0)
         {
            $outHtml .= ' width="' . $this->widthPercent . '%"';
            // $style .= " width: 100%; ";
         }
         
         if ($this->pageBreakAvoid)
         {
            $style .= ' page-break-inside: avoid;';
         }
         
         if ($this->borderAround)
         {
            $style .= ' border: thin solid black; border-spacing: ' . $this->borderAroundPadding .
                'px;';
         }
         
         if ($this->rowUnderline)
         {
            $style .= ' border-collapse: collapse; ';
         }
         
         
         if (strlen($style))
         {
            $outHtml .= ' style="' . $style . '"';
         }
         
         if ($this->noPrintFlag)
         {
            $outHtml .= ' class="noprint"';
         }
         
         if ($this->onClickCmd != null)
         {
            $outHtml .= ' onClick="' . $this->onClickCmd . '"';
         }
         
         if ($this->className != null)
         {
            $outHtml .= ' class="' . $this->className . '"';
         }
         
         $outHtml .= ' border=' . $this->border;
         $outHtml .= ' cellspacing=' . $this->spacing;
         $outHtml .= ' cellpadding=' . $this->padding;
         $outHtml .= ' valign=top';
         $outHtml .= '>';
         

         
         if (count($this->headerCells) > 0)
         {
             if ($this->tableFix != null){
                 //Tabulka s fixní velikosti a zafixovanou hlavičkou
                 $outHtml .= "\n<thead>\n";
             }
             
            $outHtml .= "\n";
            $outHtml .= '<tr align=left valign=bottom';
            if ($this->headerBgColor != null)
            {
               $outHtml .= ' bgcolor=' . $this->headerBgColor;
            }
            $outHtml .= '>';
            
            foreach ($this->headerCells as $headerCell)
            {
               $headerCell->setTextBold($this->headerTextBold);
               $outHtml .= $headerCell->publishHead();
            }
            $outHtml .= "\n";
            if ($this->tableFix != null){
                //Tabulka s fixní velikosti a zafixovanou hlavičkou
                $outHtml .= "</thead>\n";
            }
         }
         

      }
      
      
      if ($this->tableFix != null){
          //Tabulka s fixní velikosti a zafixovanou hlavičkou
          $outHtml .= "<tbody>\n";          
      }
      
      foreach ($this->tableRows as $tableRow)
      {
         // doplneni konce posledni radky
         if ($this->colCnt > 0)
         {
            $tableRow->addLastEmptyCells($this->colCnt);
         }
         
         $outHtml .= $tableRow->publish();
      }
      
      
      
      if ($this->tableFix != null){
          //Tabulka s fixní velikosti
          $outHtml .= "</tbody>\n";
      }
      
      $this->tableRows = array ();
      
      $this->flushedFlag = true;
      
      return $outHtml;
   }


   function publish()
   {
      if ($this->getRowsCnt() == 0 && !$this->flushedFlag) return null;
      
      $outHtml = $this->publishFlush();
      
      $outHtml .= "\n";
      $outHtml .= '</table>';
      if ($this->tableFix != null){
          //Tabulka s fixní velikosti
          $outHtml .= "</div>\n";
      }
      
      $outHtml .= "\n";
      
      return $outHtml;
   }


   function setNoPrint()
   {
      $this->noPrintFlag = true;
   }


   function setPageBreakAvoid()
   {
      $this->pageBreakAvoid = true;
   }


   function setOnClick($cmd)
   {
      $this->onClickCmd = $cmd;
   }


   function setClass($className)
   {
      $this->className = $className;
   }


   function skipTwinColors()
   {
      if ($this->tictac == 0)
      {
         $this->tictac = 1;
      }
      else
      {
         $this->tictac = 0;
      }
   }


   function setStyleBorder()
   {
      $this->setBorder(1);
      $this->setSpacing(0);
      $this->setPadding(3);
      $this->setHeaderBgColor(prColors::GREY_MIDDLE);
      $this->setHeaderTextBold(true);
   }


   function setStyleNoBorder()
   {
      $this->setBorder(0);
      $this->setSpacing(2);
      $this->setPadding(3);
      $this->setHeaderBgColor(prColors::GREY_DARK);
      $this->setRowBgColor(prColors::GREY_LIGHT);
      $this->setHeaderTextBold(true);
   }
/**
     * @param mixed $tableFix
     */
    public function setTableFix($tableFix)
    {
        $this->tableFix = $tableFix;
    }


   
}