<?php
/**
 * @author Petr Ruttkay
 *
 */

require_once "./_class/prHtmlTable.php";

/**
 * Třída na vytvoření buňky HTML tabulky 
 *
 */
class PrHtmlTableCell
{

    private $parentTable = null;

    private $cellText = '';

    private $cellBgColor = null;

    private $bubbleText = null;

    private $colSpan = 1;

    private $rowSpan = 1;

    private $textBold = false;

    private $fontSize = null;

    private $align = '';

    private $valign = '';

    private $width = 0;

    private $height = 0;

    private $widthPercent = 0;

    private $noWrapFlag = false;

    private $colSpanToEndFlag = false;

    private $leftLine = false;

    private $rightLine = false;

    public function __construct(PrHtmlTable &$parentTable, $cellText)
    {
        $this->parentTable = $parentTable;
        $this->cellText = $cellText;

        if ($this->colSpanToEndFlag) {
            $this->colSpan = $this->parentTable->getColToEndCnt();
        }
    }

    public function setLeftLine()
    {
        $this->leftLine = true;
        return $this;
    }

    public function setRightLine()
    {
        $this->rightLine = true;
        return $this;
    }

    public function setNoWrap($noWrapFlag)
    {
        $this->noWrapFlag = $noWrapFlag;
        return $this;
    }

    public function setCellBgColor($bgColor)
    {
        $this->cellBgColor = $bgColor;
        return $this;
    }

    function setBubbleText($bubbleText)
    {
        $this->bubbleText = $bubbleText;
        return $this;
    }

    public function setColSpan($colSpan)
    {
        $this->colSpan = $colSpan;
        return $this;
    }

    public function setColSpanToEnd()
    {
        $this->colSpanToEndFlag = true;
        return $this;
    }

    public function setRowSpan($rowSpan)
    {
        $this->rowSpan = $rowSpan;
        return $this;
    }

    public function setHeight($height)
    {
        $this->height = $height;
        return $this;
    }

    public function setWidth($width)
    {
        $this->width = $width;
        return $this;
    }

    public function setWidthPercent($widthPercent)
    {
        $this->widthPercent = $widthPercent;
        return $this;
    }

    public function setText($text)
    {
        $this->cellText = $text;
    }

    public function getText()
    {
        return $this->cellText;
    }

    public function getColSpan()
    {
        return $this->colSpan;
    }

    public function appendText($text)
    {
        $this->cellText .= $text;
    }

    function setTextBold()
    {
        $this->textBold = true;
        return $this;
    }

    function setFontSize($size)
    {
        $this->fontSize = $size;
        return $this;
    }

    function setAlign($align)
    {
        $this->align = $align;
        return $this;
    }

    function setAlignCentered()
    {
        $this->align = PrHtmlTable::ALIGN_CENTER;
        return $this;
    }

    function setAlignRight()
    {
        $this->align = PrHtmlTable::ALIGN_RIGHT;
        return $this;
    }

    function setValign($valign)
    {
        $this->valign = $valign;
        return $this;
    }

    function setValignTop()
    {
        $this->valign = PrHtmlTable::VALIGN_TOP;
        return $this;
    }

    function setValignCentered()
    {
        $this->valign = PrHtmlTable::VALIGN_CENTER;
        return $this;
    }

    function setValignBottom()
    {
        $this->valign = PrHtmlTable::VALIGN_BOTTOM;
        return $this;
    }

    private function publishImpl($head_flag)
    {
        if ($head_flag) {
            $td = "th";
        } else {
            $td = "td";
        }
        $style = '';

        $outHtml = "\n";
        $outHtml .= '<' . $td;

        if (strlen($this->align) > 0) {
            $outHtml .= ' align=' . $this->align;
        }

        if (strlen($this->valign) > 0) {
            $outHtml .= ' valign=' . $this->valign;
        } else {
            // $outHtml .= ' valign=top';
        }

        if ($this->height > 0) {
            $style .= ' height: ' . $this->height . 'px;';
        } else {
            $style .= ' height: 100%;';
        }

        if ($this->leftLine) {
            $style .= ' border-left: 1px solid black;';
        }

        if ($this->rightLine) {
            $style .= ' border-right: 1px solid black;';
        }

        if ($this->width > 0) {
            // $outHtml .= ' width=' . $this->width;
            $style .= ' width: ' . $this->width . 'px;';
        }

        if ($this->widthPercent > 0) {
            $outHtml .= ' width=' . $this->widthPercent . '%';
        }

        $outHtml .= ' colspan=' . $this->colSpan;
        $outHtml .= ' rowspan=' . $this->rowSpan;

        if ($this->cellBgColor != null) {
            $style .= ' background-color : ' . $this->cellBgColor . ';';
        }
        if ($this->bubbleText != null)
            $outHtml .= '" title="' . $this->bubbleText . '"';

        $outHtml .= ' style="' . $style . '"';
        $outHtml .= '>';

        if ($this->noWrapFlag) {
            $noWrapStyle = 'white-space : nowrap; ';
        } else {
            $noWrapStyle = '';
        }

        if ($this->textBold) {
            $weightStyle = 'font-weight: bold; ';
        } else {
            $weightStyle = 'font-weight: normal; ';
        }

        if ($this->fontSize != null) {
            $fontStyle = 'font-size: ' . $this->fontSize . 'px; ';
        } else {
            $fontStyle = '';
        }

        try {

            if (strlen(trim($this->cellText)) > 0) {
                $outHtml .= '<div style="' . $noWrapStyle . $weightStyle . $fontStyle . '">';
                $outHtml .= trim($this->cellText);
                $outHtml .= '</div>';
            }
        } catch (Exception $e) {
            debug_print_backtrace();
            $this->showInfo(null, $e);
            die();
        }

        $outHtml .= '</' . $td . '>';

        return $outHtml;
    }

    public function publishHead()
    {
        return $this->publishImpl(true);
    }

    public function publish()
    {
        return $this->publishImpl(false);
    }

    private function showInfo($sql, $exception)
    {
        $table = new PrHtmlTable();
        $table->setWidthPercent(80);
        $table->setBorder(1);
        $table->setSpacing(0);

        if ($exception != null) {
            $table->setHeaderBgColor(prColors::LIGHT_PINK);
            $table->addHeaderCell("SQL error")->setColSpan(2);
        } else {
            $table->setHeaderBgColor(prColors::GREEN_1);
            $table->addHeaderCell("SQL OK")->setColSpan(2);
        }

        if ($sql != null) {

            if ($this->namedParams != null) {

                foreach ($this->namedParams as $key => $value) {

                    $sql = str_replace($key, "'" . $value . "'", $sql);
                }
            }

            $sql = str_replace(" from ", "<br>from ", $sql);
            $sql = str_replace(" where ", "<br>where ", $sql);
            $sql = str_replace(" order ", "<br>order ", $sql);
            $sql = str_replace(" group by ", "<br>group by ", $sql);

            $table->addRow();
            $table->addRowCell('Query:')->setAlignRight();
            $table->addRowCell($sql);
        }

        if ($exception != null) {
            $table->addRow();
            $table->addRowCell('Exception:')->setAlignRight();
            $table->addRowCell($exception->getMessage());
        }

        $table->addRow();
        $table->addRowCell('StackTrace:')
            ->setAlignRight()
            ->setWidth(100);
        if ($exception != null) {
            $table->addRowCell(PrHtmlCore::publishStackTrace($exception->getTrace()));
        } else {
            $table->addRowCell(PrHtmlCore::publishStackTraceSkip(debug_backtrace(), 1));
        }

        echo '<p>' . $table->publish();

        $this->debugOnce = false;
    }

    function isEmpty()
    {
        return (strlen($this->cellText) == 0);
    }
}