<?php
/**
 * @author Petr Ruttkay
 *
 */
require_once "prHtmlTableCell.php";

/**
 * Třída na vytvoření řádky HTML tabulky
 *
 */

class PrHtmlTableRow
{
   private $htmlTable = null;
   private $rowNo = 0;
   private $rowBgColor = null;
   private $align = 'left';
   private $valign = 'top';
   private $rowCells = array ();
   private $style = null;
   private $borderFlag = false;
   private $onClickCmd = null;


   public function __construct(PrHtmlTable &$htmlTable, $rowNo)
   {
      $this->htmlTable = $htmlTable;
      $this->rowNo = $rowNo;
   }


   /**
    *
    * @return PrHtmlTableCell
    */
   function addRowCell($cellText)
   {
      $newCell = new PrHtmlTableCell($this->htmlTable, $cellText);
      $this->rowCells[] = $newCell;
      return $newCell;
   }


   public function setRowBgColor($bgColor)
   {
      $this->rowBgColor = $bgColor;
      return $this;
   }


   function setAlign($align)
   {
      $this->align = $align;
      return $this;
   }


   function setValign($valign)
   {
      $this->valign = $valign;
      return $this;
   }


   function setValignCentered()
   {
      $this->valign = PrHtmlTable::VALIGN_CENTER;
      return $this;
   }


   function setValignTop()
   {
      $this->valign = PrHtmlTable::VALIGN_TOP;
      return $this;
   }


   function setValignBottom()
   {
      $this->valign = PrHtmlTable::VALIGN_BOTTOM;
      return $this;
   }


   function setBorder()
   {
      $this->borderFlag = true;
      return $this;
   }


   function setStyle($style)
   {
      $this->style = $style;
      return $this;
   }
   

   function getStyle()
   {
      return $this->style;
   }


   function getRowNo()
   {
      return $this->rowNo;
   }


   function getCellCnt()
   {
      return count($this->rowCells);
   }


   function addLastEmptyCells($colCnt)
   {
      $filledColsCnt = 0;
      
      foreach ($this->rowCells as $rowCell)
      {
         $filledColsCnt += $rowCell->getColSpan();
      }
      
      while ($filledColsCnt < $colCnt)
      {
         $this->addRowCell("");
         $filledColsCnt++;
      }
   }


   function setOnClick($cmd)
   {
      $this->onClickCmd = $cmd;
      return $this;
   }


   public function publish()
   {
      if ($this->htmlTable->isRowIdFlag())
      {
         $idText = " id=\"tr_" . $this->rowNo . "\"";
      }
      else
      {
         $idText = "";
      }
      
      $outHtml = "\n";
      $outHtml .= "<tr" . $idText;
      
      if ($this->rowBgColor != null)
      {
         $outHtml .= ' bgcolor=' . $this->rowBgColor;
      }
      $outHtml .= ' align=' . $this->align;
      $outHtml .= ' valign=' . $this->valign;
      
      if ($this->htmlTable->isRowUnderline())
      {
         $this->style .= ' border-bottom:1px solid gray;';
      }
      
      if ($this->borderFlag)
      {
         $this->style .= ' outline: thin solid;';
      }
      
      if ($this->style != null)
      {
         $outHtml .= ' style="' . $this->style . '"';
      }
      
      if ($this->onClickCmd != null)
      {
         $outHtml .= ' onClick="' . $this->onClickCmd . '"';
      }
      
      $outHtml .= '>';
      
      foreach ($this->rowCells as $rowCell)
      {
         $outHtml .= $rowCell->publish();
      }
      
      $outHtml .= "\n";
      $outHtml .= '</tr>';
      $outHtml .= "\n";
      
      return $outHtml;
   }

}