<?php
/**
 * @author Petr Ruttkay
 *
 */

require_once "./_func/editFactory.php";
require_once "./_class/queryConv.php";


/**
 * Instance této třídy vytváří podle zadaných hodnot ($values) - SQL
 * dotaz ($query).
 * 
 */

class QueryBuild {


	const TYPE_CHAR = 1;
	const TYPE_INTEGER = 2;
	const TYPE_FLOAT = 3;
	const TYPE_DATE = 4;
	const FORMAT_WIZARD = 1;
	const FORMAT_OTHER = 2;

	/* Regular Expressions */

	const isNullExp = "/^\\s*=\\s*$/";
	const isNotNullExp = "/^\\s*(!=|<>)\\s*$/";
	const relExp = "/^\\s*(>=|<=|!=|<>|>|<|=)\\s*(\\S+.*)\\s*$/";
	const betweenExp = "/^((?:[^\\:\\\\]|\\\\.)*)\\:(.*)$/";
	const inExp = "/^((?:[^\\|\\\\]|\\\\.)*)\\|(.*)$/";
	const wildExp = "/^((?:[^\\*\\?\\[\\]\\\\]|\\\\.)*)[\\*\\?\\[\\]](.*)$/";
    
	const integerExp = "/^\\s*([+\\-]?[0-9]+)\\s*$/";
	const floatExp = "/^\\s*([+\\-]?[0-9]+(\\.[0-9]+|\\s*))\\s*$/";
	const floatExpNotZero = "{(^\\s*([+]?[1-9][0-9]+(\\.[0-9]+|\\s*))\\s*$)|(^\\s*([+]?[1-9]+(\\.[0-9]+|\\s*))\\s*$)|(^\\s*([+]?[0][\\.]+(([1-9]|0[1-9]|00[1-9]|0[1-9][0-9]|[1-9][0-9][0-9])|\\s*))\\s*$)}";
    
	const quoteExp = "'";
	const blanksExp = "{\\s*}";
    
	const rTrimExp = "{^\\s+}";
	const lTrimExp = "{\\s+$}";

	/**
	 * Database type INFORMIX
	 */
	const DBTYPE_IFX = 1;

	/**
	 * Database type POSTGRESS
	 */
	const DBTYPE_PGS = 2;

	/**
	 * Database type MYSQL
	 */
	const DBTYPE_MYSQL = 3;

	/* Global variable for error detection */
	private $dbType = 3;
	
	private $ctrl_flag = false;
	
	private $cancel_flag = false;
	
	private $queryText = array();
	
	/**
	 * Returns the input subsequence captured by the given group for a regular
	 * expression from string.
	 */
	static function getGroupForRegExp( $value,  $regExp,
			 $group) {

		$matches = array(); 
		preg_match_all($regExp, $value, $matches);
        
		$idx = 0;
		foreach ($matches as $items){
		    $item = $items[0];
// 		    echo "<BR>idx = ".$idx . " " . $item;
		    if ($idx == $group)
		        return $item;
		    $idx++;
		    
		    
		}
		return $item;

	}

	/**
	 * Returning $query text for index $qid
	 * 
	 * @param $qid
	 *            index for array
	 * @return string
	 */
	function getQuery( $qid) {
		return $this->queryText[$qid];
	}

	/**
	 * Zkontrolujte, zda formát hodnoty odpovída typu
	 * <dl>
	 * <dt><b>Types:</b></dt>
	 * <dd>TYPE_CHAR, TYPE_INTEGER,TYPE_FLOAT,TYPE_DATE,</dd>
	 * </dl>
	 * <b>Například:</b> Typ Date musí být ve formátu "dd.mm.yyyy"
	 * (31.12.2021) @ param <b>$value</b> SQL $condition <b>type</b> data type
	 * <b>$quotef</b> true - $value je v uvózovkách <b>$isQuery</b> true -
	 * $value hodnota je připravená pro AQL 
	 * 
	 * @exception Exception
	 *                <ul>
	 *                <li>Převod znaku na numerickou hodnotu se nezdařil.</li>
	 *                <li>Chybný formát datumu.</li>
	 *                <li>Neznámy typ</li>
	 *                </ul>
	 */

	static function check_type( $value,  $type,  $quotef,
	    $isQuery) {
		$adaptedValue = "";
		switch ($type) {
		    case QueryBuild::TYPE_CHAR:
    			if ($quotef)
    				$value = "'" . $value . "'";
    			break;
    		    case QueryBuild::TYPE_INTEGER:
    			
    		    $adaptedValue = preg_replace(QueryBuild::blanksExp, "", $value);
    		    
    			if (preg_match_all(QueryBuild::integerExp, $adaptedValue))			    
    			    $value = QueryBuild::getGroupForRegExp($adaptedValue, QueryBuild::integerExp, 1);
    			else
    			    throw new Exception(
    						"Převod znaku na numerickou hodnotu se nezdařil.");
    			break;
			
		    case QueryBuild::TYPE_FLOAT:
    			$adaptedValue = preg_replace(QueryBuild::blanksExp, "", $value);
    			if (preg_match_all(QueryBuild::floatExp, $adaptedValue))	
    			    $value = QueryBuild::getGroupForRegExp($adaptedValue, QueryBuild::floatExp, 1);
    			else
    				throw new Exception("Chybný formát čísla");
    			break;
    			
    		case QueryBuild::TYPE_DATE:
    
    			try {
    				if (isDate($value)) {
    					if ($isQuery) {
    						// Převod formátu na ISO 8601/SQL standard
    						$value = getDBDate($value);
    					} else {
    					    $value = getFormDate($value);
    
    					}
    					if ($quotef) {
    						$value = "'" . $value . "'";
    					} else {
    						// $value = $value;
    					}
    				} else {
    					throw new Exception("Chybný formát datumu.");
    				}
    			} catch (Exception $e) {
    			    throw new Exception($e->getMessage());
    			}
    			break;
    		default:
    			throw new Exception("Neznámy typ");
		}

		return $value;
	}

	static function parseInStr( $value,  $inStr,  $type,
			 $format,  $quotef)  {
		$str1=$str2 = null;

		if (preg_match_all(QueryBuild::inExp, $value)) {
		    $str1 = QueryBuild::getGroupForRegExp($value, QueryBuild::inExp, 1);
		    $str2 = QueryBuild::getGroupForRegExp($value, QueryBuild::inExp, 2);
			if ($type == QueryBuild::TYPE_DATE) {
				$str1 = getFormDate($str1);
			}
			$inStr = QueryBuild::parseInStr($str1, $inStr, $type, $format, $quotef);
			$inStr = QueryBuild::parseInStr($str2, $inStr, $type, $format, $quotef);
		} else {
		    if ($format == QueryBuild::FORMAT_WIZARD)
				try {
				    $inStr .= QueryBuild::check_type(QueryConv::fld2wiz_inlist($value), $type,
							$quotef, false) . ',';
				} catch (Exception $e) {
				    throw new Exception($e->getMessage());
				}
			else
				try {
				    if ($type == QueryBuild::TYPE_DATE) {
						$value = getFormDate($value);
					}
					$inStr .= QueryBuild::check_type(QueryConv::fld2DB_nomatch($value), $type,
							$quotef, false) . ',';
				} catch (Exception $e) {
				    throw new Exception($e->getMessage());
				}
		}

		return $inStr;
	}

	/**
	 * Vrátí podmínku v upraveném formátu
	 * 
	 * @param $value
	 *            $condition
	 * @param type
	 *            data types
	 * @return string
	 
	 */
	static function showFormatCondition( $value,  $type) {
		$str1=$str2=$condition = "";


		if (trim($value) != "") {
		    if (preg_match_all(QueryBuild::isNullExp, $value)) {

				$condition = $value;
			} 
			else if (preg_match_all(QueryBuild::isNotNullExp, $value)) {			
				$condition = $value;
			} 
			else if (preg_match_all(QueryBuild::relExp, $value)) {			
			    $str1 = QueryBuild::getGroupForRegExp($value, QueryBuild::relExp, 1);
			    $str2 = QueryBuild::getGroupForRegExp($value, QueryBuild::relExp, 2);
				switch ($type) {
				    case QueryBuild::TYPE_CHAR:
					$condition = $str1 . " " . $str2;
					break;
				    case QueryBuild::TYPE_INTEGER:
					try {
						if (isInteger($str2))
							$condition = $str1 . " " . $str2;
					} catch (Exception $e) {
					    echo "<BR>Chyba 1: queryBuild.showFormatCondition - ".$e->getMessage();
					}
					break;
				    case QueryBuild::TYPE_FLOAT:
					try {
						if (isFloat($str2))
							$condition = $str1 . " " . $str2;
					} catch (Exception $e) {
					    echo "<BR>Chyba 2: queryBuild.showFormatCondition - ".$e->getMessage();
					}
					break;
				    case QueryBuild::TYPE_DATE:
					try {
					    if (isDate($str2)) {
							$condition = $str1 . " " . getFormDate($str2);
						}
					} catch (Exception $e) {
					    echo "<BR>Chyba 3: queryBuild.showFormatCondition - ".$e->getMessage();

					}
					break;
				}

			} else 
			    if (preg_match_all(QueryBuild::wildExp, $value)) {	
			    if ($type != QueryBuild::TYPE_CHAR) {
					try {
						throw (new Exception("Pole není typu text"));
					} catch (Exception $e) {
					    echo "<BR>Chyba 1: queryBuild.showFormatCondition - ".$e->getMessage();
					}
				} else
					$condition = $value;

			} else 
			    if (preg_match_all(QueryBuild::betweenExp, $value)) {	
			        $str1 = QueryBuild::getGroupForRegExp($value, betweenExp, 1);
			        $str2 = QueryBuild::getGroupForRegExp($value, betweenExp, 2);
				try {
				    if (isDate($str1))
						$str1 = ShowFormat.showDate($str1);
						if (isDate($str2))
						$str2 = ShowFormat.showDate($str2);
				} catch (Exception $e) {
					echo "<BR>Chyba 4: queryBuild.showFormatCondition - ".$e->getMessage();
				}

				$condition = $str1 . ":" . $str2;
			} else 
			    if (preg_match_all(QueryBuild::inExp, $value)) {	
				$inStr = "";
				try {
				    $inStr = QueryBuild::parseInStr($value, $inStr, $type, QueryBuild::FORMAT_OTHER, false);
				} catch (Exception $e) {
					echo "<BR>Chyba 5: queryBuild.showFormatCondition - ".$e->getMessage();;
				}
				$inStr = $inStr.replaceAll(",", "|");
				$inStr = substr($inStr, 0, $inStr.length() - 1);
				$condition = $inStr;
			} else {
				switch ($type) {
				    case QueryBuild::TYPE_DATE:
					try {
					    if (isDate($value)) {
							$condition = ShowFormat.showDate($value);
						}
					} catch (Exception $e) {
						echo "<BR>Chyba 6: queryBuild.showFormatCondition - ".$e->getMessage();;

					}
					break;
				default:
					$condition = $value;
				}
			}
		}
		return $condition;
	}

	/**
	 * Vrací <b>true</b> pokud podmínka neobsahuje žádné chyby
	 * 
	 * @param $value
	 *            
	 * @param type
	 *            data type
	 * @param $exactf
	 *            <b>true</b> V tomto poli musí být přesná hodnota.
	 * @param $notnullf
	 *            <b>true</b> Toto pole vyžaduje zadanou hodnotu
	 * @return true all OK
	 * @throws Exception
	 * @exception Exception
	 *                <ul>
	 *                <li>Převod znaku na numerickou hodnotu se nezdařil.</li>
	 *                <li>Chybný formát datumu.</li>
	 *                <li>Neznámy typ</li>
	 *                </ul>
	 *  @return boolean
	 */
	static function validationFormatCondition( $value,  $type,
			 $exactf,  $notnullf)  {
		$str1=$str2 = "";
		$exactmatch = false;
		$okFlag = true;

		if (strlen(trim($value)) > 0) {
		    if (preg_match_all(QueryBuild::isNullExp, $value)) {	
				$okFlag = true;
			} else 
			    if (preg_match_all(QueryBuild::isNotNullExp, $value)) {
				$okFlag = true;
			} else 
			    if (preg_match_all(QueryBuild::relExp, $value)) {
			        $str1 = QueryBuild::getGroupForRegExp($value, QueryBuild::relExp, 1);
			        $str2 = QueryBuild::getGroupForRegExp($value, QueryBuild::relExp, 2);
				switch ($type) {
				    case QueryBuild::TYPE_CHAR:
					$okFlag = true;
					break;
				    case QueryBuild::TYPE_INTEGER:
					try {
						if (isInteger($str2))
							$okFlag = true;
					} catch (Exception $e) {
					    throw new Exception($e->getMessage());
					}
					break;
				    case QueryBuild::TYPE_FLOAT:
					try {
						if (isFloat($str2))
							$okFlag = true;
					} catch (Exception $e) {
					    throw new Exception($e->getMessage());
					}
					break;
				    case QueryBuild::TYPE_DATE:
					try {
					    if (isDate($str2)) {
							$okFlag = true;
						}
					} catch (Exception $e) {
					    throw new Exception($e->getMessage());
					}
					break;
				}

			} else 
			    if (preg_match_all(QueryBuild::wildExp, $value)) {
			    if ($type != QueryBuild::TYPE_CHAR) {
					throw (new Exception("Pole není typu text"));
				} else
					$okFlag = true;

			} else 
			    if (preg_match_all(QueryBuild::betweenExp, $value)) {
			        $str1 = QueryBuild::getGroupForRegExp($value, betweenExp, 1);
			        $str2 = QueryBuild::getGroupForRegExp($value, betweenExp, 2);
				if ($type == QueryBuild::TYPE_DATE) {
					try {
					    if (isDate($str1))
							$str1 = ShowFormat.showDate($str1);
							if (isDate($str2))
							$str2 = ShowFormat.showDate($str2);
					} catch (Exception $e) {
					    throw (new Exception($e->getMessage()));
					}
				}
				$okFlag = true;
			} else 
			    if (preg_match_all(QueryBuild::inExp, $value)) {
				
				$inStr = " in (";
				try {
				    $inStr = QueryBuild::parseInStr($value, $inStr, $type, QueryBuild::FORMAT_OTHER, true);
				} catch (Exception $e) {
				    throw (new Exception($e->getMessage()));
				}
				$inStr = substr($inStr, 0, strlen($inStr) - 1) . ")";

				$okFlag = true;
			} else {
				switch ($type) {
				    case QueryBuild::TYPE_DATE:
					try {
					    if (isDate($value)) {
							$okFlag = true;
						}
					} catch (Exception $e) {
					    throw (new Exception($e->getMessage()));

					}
					break;
				default:
					try {
					    QueryBuild::check_type($value, $type, true, false);
						$okFlag = true;
					} catch (Exception $e) {
					    throw (new Exception($e->getMessage()));

					}
				}
				$exactmatch = true;
			}
		}
		if ($exactf && !$exactmatch) {
			$okFlag = false;
			throw (new Exception("V tomto poli musí být přesná hodnota."));
		}
		if ($exactf && $notnullf && $value == "") {
			$okFlag = false;
			throw (new Exception("Toto pole vyžaduje zadanou hodnotu."));
		}

		return $okFlag;
	}

	
	/**
	 * Přidá text $query do pole
	 * 
	 * @param $qid
	 *            index for array
	 * @param $query
	 *            $query text
	 */
	public function addQuery( $qid,  $query) {
	    $query = trim($query);

	    if (strlen($query) > 0)
	        if ($this->queryText[$qid] == "1=1"){
	            $this->queryText[$qid] = $query;	        
	    } else {
	        $this->queryText[$qid] = $this->queryText[$qid]. " and " . $query;
	    }
	}

	public function buildExactQuery( $name,  $rel,  $value,
			 $type,  $notnullf)  {
			    $str = $this->buildQuery("", $value, $type, true, $notnullf, false, true,
			        QueryBuild::FORMAT_OTHER);
		if ($str != "")
			$str = name . $rel . $str;
		return $str;
	}

	/**
	 * Volaná funkce bulidQuery s parametry: <b>buildQuery</b>(name, $value,
	 * type, false, false, FORMAT_OTHER)
	 * 
	 * @param name
	 *            column name
	 * @param $value
	 *            
	 * @param type
	 *            data type ()
	 *
	 * @throws Exception
	 * @exception Exception
	 *                <ul>
	 *                <li>Převod znaku na numerickou hodnotu se nezdařil.</li>
	 *                <li>Chybný formát datumu.</li>
	 *                <li>Neznámy typ</li>
	 *                </ul>
	 */

	public function buildQuery( $name,  $value, $type)
			 {
			     return $this->buildQueryImpl($name, $value, $type, false, false, false, true,
				QueryBuild::FORMAT_OTHER);
	}

	/**
	 * Vytvoří SQL dotaz pro sloupec databázové tabulky pro zadanou hodnotu .
	 * <dl>
	 * <dt><b>Types:</b></dt>
	 * <dd>TYPE_CHAR, TYPE_INTEGER,TYPE_FLOAT,TYPE_DATE</dd>
	 * </dl>
	 * 
	 * @param name
	 *            column name
	 * @param $value
	 *            $query text
	 * @param type
	 *            data type ()
	 * @param $exactf
	 *            <b>true</b> V tomto poli musí být přesná hodnota.
	 * @param $notnullf
	 *            <b>true</b> Toto pole vyžaduje zadanou hodnotu
	 * @param $format
	 *            $format text $query
	 *            <dl>
	 *            <dt><b>Formats:</b></dt>
	 *            <dd>QueryBuild::FORMAT_WIZARD, FORMAT_OTHER</dd>
	 *            </dl>
	 * 
	 * @throws Exception
	 * @exception Exception
	 *                <ul>
	 *                <li>Převod znaku na numerickou hodnotu se nezdařil.</li>
	 *                <li>Chybný formát datumu.</li>
	 *                <li>Neznámy typ</li>
	 *                </ul>
	 */

	public function buildQueryImpl( $name,  $value,  $type,
			 $exactf,  $notnullf,  $negation,
			 $caseSensitive,  $format) {
		$str1=$str2=$query = "";
		$exactmatch = false;

		$name = QueryConv::getCorrectColumnName($name);
		

		if ($format == QueryBuild::FORMAT_WIZARD || trim($value) != "") {
			if (preg_match_all(QueryBuild::isNullExp, $value)) {
				switch ($format) {
				case QueryBuild::FORMAT_WIZARD:
					$query = "fldname=" . $name . "&check=3&val1=0";
					break;
				default:
					$query = $name . " is null";
				}
			} else 
			    if (preg_match_all(QueryBuild::isNotNullExp, $value)) {
				switch ($format) {
				case QueryBuild::FORMAT_WIZARD:
					$query = "fldname=" . $name . "&check=3&val1=1";
					break;
				default:
					$query = $name . " is not null";
				}
			} else 
			    if (preg_match_all(QueryBuild::relExp, $value)) {
			        $str1 = $this->getGroupForRegExp($value, QueryBuild::relExp, 1);
			        $str2 = $this->getGroupForRegExp($value, QueryBuild::relExp, 3);
				switch ($format) {
				case QueryBuild::FORMAT_WIZARD:
					$query = "fldname=" . $name . "&check=0&val1=";
					if ($str1.equals(">"))
						$query .= "gt";
					else if ($str1.equals(">="))
						$query .= "gte";
					else if ($str1.equals("="))
						$query .= "eq";
					else if ($str1.equals("<="))
						$query .= "lte";
					else if ($str1.equals("<"))
						$query .= "lt";
					else
						$query .= "neq";
					$query .= "&val2=" . QueryConv::fld2wiz_nomatch($str2);
					break;
				default:
					try {
						if ($caseSensitive)						    
							$query = $name
									. " "
									. $str1
									. " "
									    . $this->check_type(
											QueryConv::fld2DB_nomatch($str2),
											$type, true, true);
						else
						    $query = $this->toLower($name)
									. " "
									. $str1
									. " "
									    . $this->toLower($this->check_type(
											QueryConv::fld2DB_nomatch($str2),
											$type, true, true));
					} catch (Exception $e) {
					    echo "<BR>**************************************************************";
					    echo "<BR>".$e->getTraceAsString();
						throw (new Exception($e->getMessage()));
					}
				}
			} else 
			    if (preg_match_all(QueryBuild::wildExp, $value)) {

				switch ($format) {
				case QueryBuild::FORMAT_WIZARD:
					$query = "fldname=" . $name . "&check=4&val1="
					    . trim(QueryConv::fld2wiz_inmatch($value));
					break;
				default:
					switch ($this->dbType) {
					    case QueryBuild::DBTYPE_IFX:
						if ($caseSensitive)
							$query = $name . " matches \""
							    . trim(QueryConv::fld2DB_inmatch($value))
									. "\"";
						else
						    $query = $this->toLower($name)
									. " matches "
									    . $this->toLower("\""
									    . trim(QueryConv::fld2DB_inmatch($value)) . "\"");
						break;
					    case QueryBuild::DBTYPE_MYSQL:
					        $value = str_replace("*", "%", $value);
					        $value = str_replace("?", "_", $value);
						if ($caseSensitive)
							$query = $name . " like '"
							    . trim(QueryConv::fld2DB_inmatch($value))
									. "'";
						else
						    $query = $this->toLower($name)
									. " like "
									    . $this->toLower("'"
									    . trim(QueryConv::fld2DB_inmatch($value)) . "'");
						break;
					    case QueryBuild::DBTYPE_PGS:
					        $value = str_replace("*", "%", $value);
					        $value = str_replace("?", "_", $value);
						if ($caseSensitive)
							$query = $name . " like '"
							    . trim(QueryConv::fld2DB_inmatch($value))
									. "'";
						else
						    $query = $this->toLower($name)
									. " like "
									    . $this->toLower("'"
									    . trim(QueryConv::fld2DB_inmatch($value)) . "'");
						break;
					}
				}
				if ($type != QueryBuild::TYPE_CHAR){
				    throw (new Exception("Field is not type char"));
				}
					
			} else 
			    if (preg_match_all(QueryBuild::betweenExp, $value)) {
			        
			        $str1 = $this->getGroupForRegExp($value, QueryBuild::betweenExp, 1);
			        $str2 = $this->getGroupForRegExp($value, QueryBuild::betweenExp, 2);
				switch ($format) {
				case QueryBuild::FORMAT_WIZARD:
					$query = "fldname=" . $name . "&check=2&val1="
							. QueryConv::fld2wiz_nomatch($str1) . "&val2="
							. QueryConv::fld2wiz_nomatch($str2);
					break;
				default:
					try {

						if ($caseSensitive)
							$query = $name
									. " between "
									    . $this->check_type(
											QueryConv::fld2DB_nomatch($str1),
											$type, true, true)
									. " and "
									    . $this->check_type(
											QueryConv::fld2DB_nomatch($str2),
											$type, true, true);
						else
						    $query = $this->toLower($name)
									. " between "
									    . $this->toLower($this->check_type(
											QueryConv::fld2DB_nomatch($str1),
											$type, true, true))
									. " and "
									    . $this->toLower($this->check_type(
											QueryConv::fld2DB_nomatch($str2),
											$type, true, true));
					} catch (Exception $e) {
						throw (new Exception($e->getMessage()));
					}
				}
			} else 
			    if (preg_match_all(QueryBuild::inExp, $value)) {
				
				switch ($format) {
				case QueryBuild::FORMAT_WIZARD:
					$inStr = "fldname=" . $name . "&check=1&val1=";
					try {
						$inStr = QueryBuild::parseInStr($value, $inStr, $type, $format, false);
					} catch (Exception $e) {
					    throw (new Exception($e->getMessage()));
					}
					$inStr = substr($inStr, 0, strlen($inStr) - 1);
					break;

				default:
					if ($caseSensitive) {
						$inStr = $name . " in (";
						try {
							$inStr = QueryBuild::parseInStr($value, $inStr, $type, $format, true);
						} catch (Exception $e) {
						    throw (new Exception($e->getMessage()));
						}
						$inStr = substr($inStr, 0, strlen($inStr) - 1) . ")";
					} else {
					    $inStr = $this->toLower($name) . " in LOWER(";
						try {
							$inStr = QueryBuild::parseInStr($value, $inStr, $type, $format, true);
						} catch (Exception $e) {
						    throw (new Exception($e->getMessage()));
						}
						
						$inStr = substr($inStr, 0, strlen($inStr) - 1) . "))";
					}
				}
				$query = $inStr;
			} else {
				switch ($format) {
				case QueryBuild::FORMAT_WIZARD:
					$query = "fldname=" . $name . "&check=0&val1=eq&val2="
							. QueryConv::fld2wiz_nomatch($value);
					break;
				default:
					if ($exactf)
						try {
						    $query = $this->check_type(QueryConv::fld2DB_nomatch($value),
									$type, true, true);
						} catch (Exception $e) {
						    throw (new Exception($e->getMessage()));
						}
					else
						try {
							if ($caseSensitive)
								$query = $name
										. " = "
										. $this->check_type(
												QueryConv::fld2DB_nomatch($value),
												$type, true, true);
							else
							    $query = $this->toLower($name)
										. " = "
										    . $this->toLower($this->check_type(
												QueryConv::fld2DB_nomatch($value),
												$type, true, true));
						} catch (Exception $e) {
						    throw (new Exception($e->getMessage()));
						}
				}
				$exactmatch = true;
			}
		}

		if ($exactf && !$exactmatch)
			throw (new Exception("V tomto poli musí být přesná hodnota $value."));

		if ($exactf && $notnullf && $query == "")
			throw (new Exception("Toto pole vyžaduje zadanou hodnotu $value."));

			if ($negation && strlen($query) > 0)
			$query = " not(" . $query . ")";

		return $query;
	}

	/**
	 * Inicializace dotazu v indexu pole $qid na "1 = 1"
	 * 
	 * @param $qid
	 *            index for array
	 */

	public function initQuery($qid) {
	    $this->queryText[$qid] = "1=1";
	}

	public function setDbType($newDbType) {
	    $this->dbType = $newDbType;
	}

	private function toLower( $value) {
	    
	    return "LOWER(" . trim($value) . ")";
	}

}
