<?php

/**
 * @author Petr Ruttkay
 *
 */

require_once "./_class/queryBuild.php";

/**
 * Funkce vrací ID pro zápis nového údaje pro zápis do DB
 * @param string $name
 * @param string $num
 * @return string
 */
function getEditNewName($name, $num)
{
   return $name . "_i_" . $num;
}

/**
 * Funkce vrací ID pro aktualizaci údaje
 * @param string $name
 * @param string $num
 * @return string
 */
function getEditUpdName($name, $num)
{
   return $name . "_u_" . $num;
}

/**
 * Funkce vrací ID pro původní hodnotu  
 * @param string $name
 * @param string $num
 * @return string
 */
function getEditOldName($name, $num)
{
   return $name . "_o_" . $num;
}

/**
 * Funkce vytváří ID pro filtr dat z DB
 * @param string $name
 * @return string
 */
function getFilterName($name)
{
   return $name . "_f";
}

/**
 * Funkce inicializuje sesion údaje  
 */
function initForm() {
    
    $_SESSION["updateSQL"]       = null;
    $_SESSION["noFiltred"]       = null;   //N=Data nejsou fitrovaná 
    $_SESSION["existsFilterBox"] = false;  //N Data nejsou fitrovaná 
    $_SESSION["primaryKey"]      = null;
    $_SESSION["save_primaryKey"] = null;
    $_SESSION["whereSQL"]        = null;  //podmínka zadaná uživatele
    $_SESSION["wherePartRow"]    = null;  //podmínka zadaná programátorem pro řádky dokladu
    $_SESSION["show_last_data"]  = null;
    $_SESSION["insRow"]          = null;
    $_SESSION["tempFlag"]        = null;
    $_SESSION["head_ID"]         = null;
    $_SESSION["detl_ID"]         = null;
    $_SESSION["showNewRec"]      = false; //Pro zobrazení informace "NOVÝ ZÁZNAM"
    $_SESSION["print"]           = false; //Režím tisku
    
}

/**
 * Fukce vytváří ID klíč pro aktualizaci údaje v DB 
 * @return string
 */
function getUpdateIdKey($dbTable, $dbPrimaryKey, $key_code, 
    $tableID, $dbColumn, $value)
{
    $OldVvalue = str_replace (" " , "#$#" ,  $value );
    
    $updeteKey = "updateTable_#_" .$dbTable."_#_PrimCol_#_".$dbPrimaryKey.
    "_#_PrimKey_#_".trim($key_code) .
    "_#_OldVal_#_" . $OldVvalue.
    "_#_tableID_" . $tableID. "_#_" . $dbColumn;
    
    return $updeteKey;
}

/**
 * Funkce nastavuje atributy pro editovatelnu položku formuláře
 * @param FormItem $formGridItem
 * @param PrHtmlText $editText
 * @param boolean $readonly
 * @param boolean $filterFlag
 */
function setEditTextAttribute (FormItem $formGridItem, PrHtmlText $editText, $readonly, $filterFlag){ 
    
      
    $editText->setUpperCase($formGridItem->getUpshift() == "Y");
    $editText->setRequired($formGridItem->getRequired() == "Y");  

    if ($readonly)
        $editText->setReadonly($readonly);    //Vynuceno ve funkci např. pro primární klíč
    else
        $editText->setReadonly($formGridItem->getReadonly() == "Y"); //Dle definice v XML
    
    if (!$filterFlag){
        if ($formGridItem->getDbType() == FormStructure::TYPE_INTEGER ||
            $formGridItem->getDbType() == FormStructure::TYPE_INT)
        {
            $editText->setPatternIntegerUnsign();
        }
        if ($formGridItem->getDbType() == FormStructure::TYPE_DECIMAL2 ||
            $formGridItem->getDbType() == FormStructure::TYPE_DEC2)
        {
            $editText->setPatternDecimal2();
        }   
        if ($formGridItem->getDbType() == FormStructure::TYPE_DATE)
        {
            $editText->setCalendar();
        } 
    }
    
}

/**
 * Funkce vytváří SQL příkaz pro zápis do DB
 * @param string $nameRow
 * @param isPdo $pdo
 * @param boolean $tempFlag
 * @return NULL|string
 */
function InsertIntoDB($nameRow, $pdo, $tempFlag)
{
    $pdo->beginTransaction();
    
    
    $msg = null;
    
    
    $insertSql = "insert into ". $_SESSION["database"] . ".";
    $valuesSql =  " values (";
    $carka = "";
    
    foreach ($_REQUEST as $key => $value)
    {
        //ABOH_#_tableID_1_#_city_text
        if (strlen($value) > 0 && strpos($key, "EW_REC_gridID_") > 0){
            
            list ($akceID, $primaryColumn, $table, $column) = explode('_#_', $key);
            
            if ($primaryColumn == $column){
                $primaryKeyValue = $value;
            }
            
            if ($insertSql == "insert into ". $_SESSION["database"] . ".") {
                $insertSql .= $table." (";
            }
            
            $insertSql .= $carka . $column;
            $valuesSql .= $carka . ":" . $column;
            
            if (isFormDate($column, $value)) {
                //Jedná se o datum musí se konvertovat na SQL formát
                $value = getDBDate($value);
            }
            $pdo->setNamedParam($column, $value);
            $carka = ", ";
            //                    }
        }
    }
    
    if ($carka == ", "){ //Byl nastaven alespoň jeden sloupec
        if ($tempFlag){
            $insertSql .= ", valid_flag)" . $valuesSql . ",0)";
        } else {
            $insertSql .= ", valid_flag)" . $valuesSql . ",1)";
            
        }

         $pdo->exec($insertSql);
        $newPrimaryKeyValue = $pdo->lastInsertId();
        $_SESSION["newID"] =  $newPrimaryKeyValue;
        
        if ($primaryKeyValue != "0" && $newPrimaryKeyValue == "0"){ //Manuálně zadný klíč
            $newPrimaryKeyValue = $primaryKeyValue;
        }
        
        $msg = $nameRow." ".$newPrimaryKeyValue." uspěšně zapsán.";
    }
    
    $pdo->commitTransaction();
    
    return $msg;
    
}

/**
 * Funkce vytváří kontrolní vzor (regulární výraz) pro kontrolu formátu datumu
 */
function isFormDate($column, $value){
    $pattern = "(([12][0-9]|3[01]|0?[1-9])\.(0?[1-9]|1[012])\.(?:19|20)\\d\\d)";
    if (strpos($column, "date" ) > 0 || preg_match($pattern, $value)) {
        return true;
    } else {
        return false;
    }
}

/**
 * Funkce vrací datum ve fomátu "yyyy-mm-dd" určený pro DB
 * @param string $value
 * @return string
 */
function getDBDate($value){
    return date("Y-m-d", strtotime($value));
}

/**
 * Funkce vrací datum ve fomátu "dd.mm.yyyy" určený pro zobrazení ve formuláři
 * @param string $value
 * @return string
 */
function getFormDate($value){
    return date("d.m.Y", strtotime($value));
}

/**
 * Funkce vrací datum a čas ve fomátu "dd.mm.yyyy HH:MM:SS" určený pro zobrazení ve formuláři
 * @param string $value
 * @return string
 */
function getFormDateTime($value){
    return date("d.m.Y H:i:s", strtotime($value));
}

/**
 * Funkce kontroluje zda-li se jedná o datum.
 *
 * @param inputString
 * @return <b>true</b> if yes,
 * @throws Exception
 *             if not
 */
function isDate($inputString) {
    
    try {
        $dt = date("d.m.Y", $inputString);
        if ($dt === false) {
            throw new Exception("Chybný formát datumu ".$dt);
        }
    } catch (Exception $e) {
    throw (new Exception($e->getMessage()));
}
    
    return true;
}

/**
 * Funkce kontroluje zda-li se jedná o Float
 *
 * @param inputString
 * @return <b>true</b> if yes
 * @throws Exception
 *             if not
 */
function isFloat($inputString)  {
    if (!is_float($inputString)){
        throw new Exception("Chybný formát realného čísla");
    }
    return true;
}

/**
 * Funkce kontroluje zda-li se jedná o Integer
 *
 * @param inputString
 * @return <b>true</b> if yes
 * @throws Exception
 *             if not
 */
function isInteger($inputString) {
    if (!is_int($inputString)){
        throw new Exception("Chybný formát celého čísla");
    }
    return true;
}

/**
 * Funkce vytváří pomocnou tabulku dle tabulky <i>table</i>  
 * @param isPdo $pdo
 * @param string $table
 */
function crtTempTable($pdo, $table)
{

    $crtSQL = "CREATE TEMPORARY TABLE IF NOT EXISTS tmp_" . $table .
    " select * from " . $table . " where 1=0";
    $pdo->exec($crtSQL);
    
}

/**
 * Funkce provede zápis původního záznamu v DB tabulce pod novým kódem <i>$newKeyCode</i>  
 * @param isPdo $pdo
 * @param string $id - Púvodní ID
 * @param string $newKeyCode - Nový kód
 * @return string - Informační zpráva
 */
function cloneDBRow($pdo, $id, $newKeyCode)
{
    if ($newKeyCode == null || strlen($newKeyCode) == 0){
        return "Nový kod nebyl vypněn. Kopie nebyla provedena!";
    }
    if (strpos($id, 'COPY_DB_ROW') > 0){
        
        list($akceID, $tableFlag,$table, $columnFlag, $column, $primaryKeyFlag, $primaryKey) = explode('_X_', $id);
      
        $fillSQL = "CREATE TEMPORARY TABLE IF NOT EXISTS tmp_" . $table . 
                    " select * from " . $table . " where " . $column . "= :" . $column;


        $updateSQL = "update tmp_" . $table . " set " . $column . " = '".$newKeyCode."' where " . $column . "= :" . $column;
        
        $insertSQL = "insert into " . $table .
                    " select * from tmp_" . $table ;
        
        $pdo->beginTransaction();

        $dropSQL = "drop table if exists tmp_" . $table;
        $pdo->exec($dropSQL);
        
        //TODO Doplnit kontrolu na existenci klíče
        
        $pdo->setNamedParam($column, $primaryKey);
        $pdo->exec($fillSQL);

        $pdo->setNamedParam($column, $primaryKey);
        $pdo->exec($updateSQL);
        
        $pdo->setNamedParam($column, $primaryKey);
        $pdo->exec($insertSQL);
        
        $dropSQL = "drop table tmp_" . $table;
        $pdo->exec($dropSQL);
        
        $pdo->commitTransaction();
        
        return "Kopie údajů uspešně provedena";
    }
}
    
/**
 * Funkce provede aktualizaci v DB změněných údajů ve formuláři.
 * @param isPdo $pdo
 * @return string - Informační zpráva 
 */
function saveChanges($pdo)
{    
    $pdo->beginTransaction();
    
    
    foreach ($_REQUEST as $key => $value)
    {
        
        $strpos = strpos($key, "pdateTable_");
        
        if ($strpos > 0) {
            
            
            // updateTable_#_customer_#_PrimCol_#_cust_code_#_PrimKey_#_ABOH_#_OldVal_#_Klatovy#$#3_#_tableID_1_#_city_text = Klatovy 3
            
            list ($akceID, $table, $paramID, $primaryColumn, $paramID, $primaryKey, $paramID, $oldVal, $tableID, $columnName) = explode('_#_', $key);
            $oldVal = str_replace("#$#", " ", $oldVal);
            
            if ($value != $oldVal) {
                if ($value == null){
                    $updateSQL = "update " . $table . " set " . $columnName . " = null where " . $primaryColumn . "= :" . $primaryColumn;
                }else {
                    
                    if (isFormDate($columnName, $value)) {
                        //Jedná se o datum musí se konvertovat na SQL formát
                        $value = getDBDate($value);
                    }
                    
                    $updateSQL = "update " . $table . " set " . $columnName . " = :" . $columnName . " where " . $primaryColumn . "= :" . $primaryColumn;
                    $pdo->setNamedParam($columnName, $value);   
                }
                
                $pdo->setNamedParam($primaryColumn, $primaryKey);
                
                $pdo->exec($updateSQL);
            }
        }
    }
    
    
    $pdo->commitTransaction();
    
    return "Aktualizace údajů uspešně provedena";
}

/**
 * Funkce nastaví primární klič ($_SESSION["primaryKey"]) pro zobrazení detailu formukáře 
 */
function setSesionPrimaryKeyFordetail()
{
    //_form_send_editAction_edit_detail = #Detailrow3_#_customer_#_cust_code_#_XXXX112
    
    $_SESSION["primaryKey"] = null;
    foreach ($_REQUEST as $key => $value){
        if (strpos($key, 'Action_edit_detail') > 0){
            list($akceID, $table, $column, $area, $tableID, $primaryKey) = explode('_#_', $value);
            $_SESSION["primaryKey"] = $primaryKey;
        }
    }
    
}
/**
 * Funkce vrací ID klíče pro požadovaný grid a oblast formuláře
 * @return string|NULL
 */
function getIDKey4FormGrid($area)
{
    if (isset($_SESSION["_AreaKey_Grid_".$area."_key"])){
        return $_SESSION["_AreaKey_Grid_".$area."_key"];
    }
    return null;
    
}
/**
 * Funkce vrací ID klíče pro požadovanou tabulku a oblast formuláře
 * @return string|NULL
 */
function getIDKey4FormTable($area, $tableID)
{

     if (isset($_SESSION["_AreaKey_Table_".$area."_key"])){
         return $_SESSION["_AreaKey_Table_".$area."_key"];
     }
    
    return null;
    
}

/**
 * Funkce vrací název sloupce klíče pro požadovanou tabulku a oblast formuláře
 * @return string|NULL
 */

function getColumn4TableDetail($area)
{
    if (isset($_SESSION["_AreaKey_Table_".$area."_column"])){
        return $_SESSION["_AreaKey_Table_".$area."_column"];
    }
    
    return null;
}

/**
 * Funkce vrací ID pro kolonování řádky tabulky
 * @return string|NULL
 */
function getID4Clone()
{
    //_form_send_editAction_edit_detail = #Detailrow3_#_customer_#_cust_code_#_XXXX112
    
    foreach ($_REQUEST as $key => $value){
        //            echo "<BR>".$key." = ".$value;
        if (strpos($key, 'Action_edit_detail') > 0){
            list($akceID, $table, $column, $area, $tableID, $primaryKey) = explode('_#_', $value);
            $buttonName = "COPY_DB_ROW" .
                "_X_TABLE" .
                "_X_" . $table .
                "_X_COL_NAME" .
                "_X_" . $column .
                "_X_KEY" .
                "_X_" . $primaryKey ;
            return $buttonName;
        }
    }
    return null;
    
}
/**
 * Funkce převadí DB typ v XML na typ v QueryBuild
 * @param int
 */
function convertType2Query($dbtype){
    switch ($dbtype) {
        case FormStructure::TYPE_TEXT     : $dbTypeQuery = QueryBuild::TYPE_CHAR; break;
        case FormStructure::TYPE_DEC2     : $dbTypeQuery = QueryBuild::TYPE_FLOAT; break;
        case FormStructure::TYPE_INTEGER  : $dbTypeQuery = QueryBuild::TYPE_INTEGER; break;
        case FormStructure::TYPE_INT      : $dbTypeQuery = QueryBuild::TYPE_INTEGER; break;
        case FormStructure::TYPE_DECIMAL2 : $dbTypeQuery = QueryBuild::TYPE_FLOAT; break;
        case FormStructure::TYPE_DATE     : $dbTypeQuery = QueryBuild::TYPE_DATE; break;
        default: $dbTypeQuery = QueryBuild::TYPE_CHAR; break;        
    }
    return $dbTypeQuery;
}

/**
 * Funkce ruší zaznamy v DB del označených záznamu ve formuláři
 * @param isPdo $pdo
 * @return string
 */
function deleteRows($pdo)
{
    
    
    $pdo->beginTransaction();
    
    foreach ($_REQUEST as $key => $value)
    {
        
        //#delrow_u_customer_cust_code
        if (strpos($key, 'delrow_u_') > 0){
            list($akceID, $table, $primaryKey) = explode('_#_', $key);
            $deleteSQL = "delete from ".$table." where ".$primaryKey."= :" .$primaryKey;
            $pdo->setNamedParam($primaryKey, $value);
            $pdo->exec($deleteSQL);
        }
        
    }
    
    $pdo->commitTransaction();
    
    // $pdo->setDebugOff();
    return "Smazání rádek uspešně provedeno";
}

/**
 * Funkce vytvoří výběrovou podmínku ze zadaného filtru ve formuláří a provede zápis do DB tab. filter_data
 */
function createQuery(isPDO $pdo, FormStructure $formStructure)
{
    
    $pdo->beginTransaction();    

    $sql = "delete from filter_data where user = :user and form_id = :form_id";
    $pdo->setNamedParam("user", $_SESSION["is_user"]);
    $pdo->setNamedParam("form_id", $formStructure->getFormID());
    if ($pdo->exec($sql) === false){
        return "Chyba filtru dat";
    }
    
    $whereSQL = " 1=1 ";
    
    $negace = array();
    $caseSensitive = array();
    
    $okFlag = true;
    $queryBuild = new QueryBuild();
    $queryBuild->setDbType(QueryBuild::DBTYPE_MYSQL);
    
    $queryBuild->initQuery(1);
    
    foreach ($_REQUEST as $key => $value)
    {
        if (strpos($key, 'negace') > 0){
            list($akceID, $table, $column, $requiredText, $name, $dbType) = explode('_#_', $key);
            $negace[$column] = $value;            
        }
        if (strpos($key, 'caseSensitive') > 0){
            list($akceID, $table, $column, $requiredText, $name, $dbType) = explode('_#_', $key);
            $caseSensitive[$column] = $value;
        }

    }
    
    foreach ($_REQUEST as $key => $value)
    {
        
        //_filter_#_customer_#_cust_code_#_required_TRUE_#_Odběratel_#_char
        if (strpos($key, 'filter') > 0){
            
            
            list($akceID, $table, $column, $requiredText, $name, $dbType) = explode('_#_', $key);
            
            $dbType = str_replace ("#$#", " " , $dbType);
            $name = str_replace ("#$#", " " , $name);
            
            //TODO doplnit test z QueryBuild
            $quotef = false;
            $isQuery = true;
                
            if ($requiredText == "required_TRUE" && $value == null){
                return "2. Položka '". $name ."' musí být vyplněná pro výběr dat";
            }

            
            if ($value != null){                
                
                
                $sql = "insert into filter_data values (:user, :form_id, :tabname, :colname, :value, :dbtype, false, #required#, #negace#, #caseSensitive#)";
                
                $exact = false;
                $required = false;
                $negation = false;
                $caseSens = false;
                
                //Boolean se v PHP převádí na String proto tato opičarna. 
                if ($requiredText == "required_TRUE"){
                    $sql = str_replace("#required#", "true", $sql);
                    $required = true;
                } else {
                    $sql = str_replace("#required#", "false", $sql);
                }
                if (isset($negace[$column])){
                    if ($negace[$column] == "on"){
                        $sql = str_replace("#negace#", "true", $sql);
                        $negation = true;
                    } else {
                        $sql = str_replace("#negace#", "false", $sql);
                    }
                } else {
                    $sql = str_replace("#negace#", "false", $sql);
                }
                if (isset($caseSensitive[$column])){
                    if ($caseSensitive[$column] == "on"){
                        $sql = str_replace("#caseSensitive#", "true", $sql);
                        $caseSens = true;
                    } else {
                        $sql = str_replace("#caseSensitive#", "false", $sql);
                    }
                } else {
                    if ($dbType == FormStructure::TYPE_DATE){
                        //aby se pro datum nepoužila funkce LOWER
                        $sql = str_replace("#caseSensitive#", "true", $sql);
                        $caseSens = true;
                    } else {
                        $sql = str_replace("#caseSensitive#", "false", $sql);
                    }                    
                }
                try {
                    
                    $okFlag = QueryBuild::validationFormatCondition($value, convertType2Query($dbType), false, $required);
                } catch (Exception $e) {
                    return "3. Položka '". $name ."' Hodnota '".$value."' : " . $e->getMessage();
                }
                
                try {
                    $queryText = $queryBuild->buildQueryImpl($table.".".$column, $value, convertType2Query($dbType),
                        $exact, $required, $negation, $caseSens, QueryBuild::FORMAT_OTHER);
                    
                    $queryBuild->addQuery(1, $queryText);
                    
                } catch (Exception $e) {
                    $okFlag = false;
                    echo "<BR>".$e->getMessage();
                    if ($value == "*" || strpos($value, '*') > 0){
                        $whereSQL .= " and " . $table . "." . $column . " like '" . str_replace("*", "%", $value) . "'";
                    } else {
                        $whereSQL .= " and " . $table . "." . $column . " = '" . $value . "'";
                    }
                }
                $pdo->setNamedParam("user", $_SESSION["is_user"]);
                $pdo->setNamedParam("form_id", $formStructure->getFormID());
                $pdo->setNamedParam("tabname", $table);
                $pdo->setNamedParam("colname", $column);
                $pdo->setNamedParam("value", $value);
                $pdo->setNamedParam("dbtype", $dbType);
                
                if ($pdo->exec($sql) === false){
                    return "Chyba filtru dat";
                }
                
                
            }
            
        }
        
    }
    
    if ($okFlag){
        $whereSQL .= " and " . $queryBuild->getQuery(1);
        
    }
    
    $_SESSION["whereSQL"] = $whereSQL;
    
    $pdo->commitTransaction();
    
    return null;
}

/**
 * Funkce vytvoří výběrovou podmínku ze zapsaného filtru v DB tab. filter_data
 */
function createWhereSQL(isPDO $pdo, $formID)
{
   
    $sql = "select tabname, colname, value, dbtype, exact, required, negation, caseSensitive from filter_data where user = :user and form_id = :form_id";
    $pdo->setNamedParam("user", $_SESSION["is_user"]);
    $pdo->setNamedParam("form_id", $formID);
   
    $whereSQL = " 1=1 ";
    
    //$idx = 0;
    $okFlag = true;
    $queryBuild = new QueryBuild();
    $queryBuild->setDbType(QueryBuild::DBTYPE_MYSQL);
    
    $queryBuild->initQuery(1);
    
    foreach ($pdo->query($sql) as $dataFilter)
    {
        //$idx++;
        $table = $dataFilter["tabname"];
        $column = $dataFilter["colname"];
        $value = $dataFilter["value"];
        $dbtype = $dataFilter["dbtype"];
        $exact = $dataFilter["exact"];
        $required = $dataFilter["required"];
        $negation = $dataFilter["negation"];
        $caseSensitive = $dataFilter["caseSensitive"];
        
        
        $dbTypeQuery = QueryBuild::TYPE_CHAR;
        
        $dbTypeQuery = convertType2Query($dbtype);
        if ($dbtype == FormStructure::TYPE_DATE){
            //aby se pro datum nepoužila funkce LOWER
            $caseSensitive = true;
        } 
                 
        if ($value != null){            
            try {
                $queryText = $queryBuild->buildQueryImpl($table.".".$column, $value, $dbTypeQuery,
                    $exact, $required, $negation, $caseSensitive, QueryBuild::FORMAT_OTHER);
                
                $queryBuild->addQuery(1, $queryText);                
                
            } catch (Exception $e) {
                $okFlag = false;
                echo "<BR>".$e->getMessage();
                if ($value == "*" || strpos($value, '*') > 0){
                    $whereSQL .= " and " . $table . "." . $column . " like '" . str_replace("*", "%", $value) . "'";
                } else {
                    $whereSQL .= " and " . $table . "." . $column . " = '" . $value . "'";
                }
            }
            
            
            
        }
    }
    
    if ($okFlag){
        $whereSQL .= " and " . $queryBuild->getQuery(1);
        
    }
    
    $_SESSION["whereSQL"] = $whereSQL;
    
    return;
}

/**
 * Funkce zruší filtr v DB tab. filter_data
 */
function deleteFilter(isPDO $pdo, FormStructure $formStructure)
{
    
    $pdo->beginTransaction();
    
    $sql = "delete from filter_data where user = :user and form_id = :form_id";
    $pdo->setNamedParam("user", $_SESSION["is_user"]);
    $pdo->setNamedParam("form_id", $formStructure->getFormID());
    if ($pdo->exec($sql) === false){
        return "Chyba rušení filtru dat";
    }
    
    $pdo->commitTransaction();
    
    return null;
}

function generateFormButtons($noFiltred){
    $formInsertAction = new PrHtmlForm("editAction", null);
    $formInsertAction->setNoPrint();
    if ($noFiltred){
        $sendButtonHtml = $formInsertAction->publishSendButtonNamed(FormGridCreator::ACTION_GOTO_QUERY_OK, "OK");
    } elseif ($_SESSION["primaryKey"] == null) {
        $sendButtonHtml = $formInsertAction->publishSendButtonNamed(FormGridCreator::ACTION_GOTO_EDITOR_INS_SAVE, "Zapsat");
    } else  {
        $sendButtonHtml = $formInsertAction->publishSendButtonNamed(FormGridCreator::ACTION_GOTO_EDITOR_UPD_SAVE, "Uložit změny");
    }

    
    $back = '<input class="noprint" type=button onclick="history.back()" value="Zpět">';

    $tableFooter = new PrHtmlTable();
    $tableFooter->setWidthPercent(100);
    $tableFooter->addRow();
    $tableFooter->addRowCell( $sendButtonHtml ." ".$back)->setAlignCentered();
    
    return $tableFooter->publish();
}

function generateCancelButton(){
    
    
    $formStornoAction = new PrHtmlForm("editAction", null);
    $formStornoAction->setNoPrint();
    echo $formStornoAction->publishStart();
    
    echo '<div class="noprint" style="text-align:right">' . $formStornoAction->publishSendButtonNamedImage(FormGridCreator::ACTION_GOTO_STORNO,
        "Storno", "Storno formuláře", "./_img/small/cross.png") . '</div>';
    echo $formStornoAction->publishEnd();    
}

function generateInsertDoclButton($bubbleText){
    
    
    $formInsertAction = new PrHtmlForm("editAction", null);
    $formInsertAction->setNoPrint();
    echo $formInsertAction->publishStart();
    
    echo '<div class="noprint" style="text-align:right">' . $formInsertAction->publishSendButtonNamedImage(FormGridCreator::ACTION_GOTO_INS_DOC,
        "Storno", $bubbleText, "./_img/small/disk.png") . '</div>';
    echo $formInsertAction->publishEnd();
}

function generateTitle($titleText){
    $title = '<p style="font-weight: bold;background-color : '.prColors::GREEN_GRAY_MIDDLE.';"><font color=yellow><I>'.$titleText.'</I><br></p>';
    
    $tableTitle = new PrHtmlTable();
    $tableTitle->addRow();
    $tableTitle->addRowCell($title)
    ->setAlignCentered();
    $tableTitle->setWidthPercent(20);
    $title = $tableTitle->publish();
    
    return $title;
}

function generateActionText($titleText, $backgroundColor, $color){
    $title = '<p style="font-weight: bold;background-color : '.$backgroundColor.';"><font color='.$color.'><I>'.$titleText.'</I><br></p>';
    
    $tableTitle = new PrHtmlTable();
    
    $tableTitle->addRow();
    $tableTitle->addRowCell($title)->setAlignCentered();
    
    $tableTitle->setWidthPercent(100);
    
    $title = $tableTitle->publish();
    
    return $title;
}

/**
 * Funkce vrací alias DB sloupce který je nastavený v XML
 * Příklad: prodstat.wgted_cost_amt as wgted vrátí wgted
 */
function geColumnAlias($columnTable){
    $value = $columnTable;
        $strPos = strpos($columnTable, " _as_");
        if ($strPos > 0) {
            $value = substr($columnTable, $strPos + 5, strlen($columnTable));
        }
        $value = trim($value);
    return $value;
}

/**
 * Funkce vrací název DB sloupce který je nastavený v XML 
 * Příklad: _DBC.prodstat.wgted_cost_amt vrátí prodstat.wgted_cost_amt
 */
 
function getDefaultValueDBC($defaultValue){
    $value = null;
    $strPos = strpos($defaultValue, "DBC.");
    if ($strPos > 0) {
        $value = substr($defaultValue, $strPos + 4, strlen($defaultValue));
        $value = trim($value);
        $value = str_replace("_as_", "as", $value); //Kvůli použití "as" v CAST (přetypování) se alias v definici píše jako _as_
    }   
    return $value;
}

/**
 * Funkce vrací alias DB sloupce který je nastavený v XML
 * Příklad: _DBC.prodstat.wgted_cost_amt as wgted vrátí wgted
 */
function getDefaultValueAliasDBC($defaultValue){
    $value = null;
    $strPos = strpos($defaultValue, "DBC.");
    if ($strPos > 0) {
        $value = substr($defaultValue, $strPos + 4, strlen($defaultValue));
        $strPos = strpos($defaultValue, " _as_");
        if ($strPos > 0) {
            $value = substr($defaultValue, $strPos + 5, strlen($defaultValue));
        }
        $value = trim($value);
    }
    return $value;
}

/**
 *  Funkce převádi makra filtru do realné hodnoty 
 *  Parametrické výrazy - Význam
 *  $TIME	Aktuální čas
 *  $USER	Přihlašovací jméno uživatele
 *  $TODAY	Aktuální datum
 *  $YEST    Včerejší datum
 *  $TOMM    Zítřejší datum
 *  $YEAR    Aktuální rok
 *  $PER     Aktuální měsíc
 *  $LPYEAR  Rok minulého měsíce
 *  $LPPER   Minulí měsíc
 * @param string $i
 * @return NULL|string
 */
function getDefaultValue($i){
    

    if (getDefaultValueDBC($i) != null){
        #Nejedná se o konstantu 
        return null;
    }
    
    switch ($i) {
        case "\$TIME":
            return date('H.i.s');
            break;
        case "\$TODAY":
            return date('d.m.Y');
            break;
        case "\$YEST":
            return date('d.m.Y',strtotime("-1 days"));
            break;
        case "\$TOMM":
            return date('d.m.Y',strtotime("+1 days"));
            break;
        case "\$YEAR":
            return date('Y');
            break;
        case "\$PER":
            return date('m');
            break;
        case "\$LPYEAR":
            return date('Y',strtotime("-1 months"));
            break;
        case "\$LPPER":
            return date('m',strtotime("-1 months"));
            break;
          
        default:
            return $i;
    }
    

    
    
}

